;;; GAMS.EL --- Major mode for editing GAMS program files.

;; Copyright (C) 2001, 2002 Shiro Takeda

;; Version: 1.3
;; $Id: gams.el,v 1.3.1.2 2002/04/02 10:11:19 ged9203 Exp $
;; Time-stamp: <2002-04-02 19:10:41 Shiro Takeda>
;; Time stamp: <2001-12-24 22:56:55 Shiro Takeda>

;; Author: Shiro Takeda <zbc08106@park.zero.ad.jp>
;; Maintainer: Shiro Takeda <zbc08106@park.zero.ad.jp>
;; First Created: Sun Aug 19, 2001 12:48 PM

;; This file is not part of any Emacs.

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; A copy of the GNU General Public License can be obtained from this
;; program's author (send electronic mail to
;; zbc08106@park.zero.ad.jp) or from the Free Software Foundation,
;; Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:
;;
;;
;; 			See README file!
;;
;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code starts here.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(require 'easymenu)

;; `oddp' is defined in `cl.el'.
(require 'cl)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Define variables.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defconst gams-mode-version "1.3"
  "Version of GAMS mode.")

;;;;; Define groups.

(defgroup gams nil
  "Group of GAMS mode for Emacs."
  :group 'applications)

(defgroup gams-faces nil
  "Group of faces for GAMS mode."
  :group 'gams
  :group 'faces)

(defgroup gams-keys nil
  "Group of keybindings for GAMS mode."
  :group 'gams
  :group 'keyboard)

;;;;; Customizable variables start here.

;;; Variables for GAMS mode.

;; from epop.el
(defcustom gams:process-command-name "gams"
  "*GAMS program file name.
If you do not include the GAMS system directory in PATH variable, you
must set the full path to GAMS in this variable like
c:/GAMS20.0/gams.exe."
  :type 'file
  :group 'gams)

(defcustom gams:process-command-option "ll=0 lo=3 pw=100 ps=9999"
  "*Command line options passed to GAMS"
  :type 'string
  :group 'gams)

(defcustom gams-statement-file "~/.gams-statement"
  "*The name of the file in which user specific statements are stored."
  :type 'file
  :group 'gams)

(defvar gams-statement-file-already-read nil)
;; Load gams-statement-file. 
(if (and (null gams-statement-file-already-read)
	 (file-exists-p gams-statement-file))
    (progn (load-file gams-statement-file)
	   (setq gams-statement-file-already-read t)))

(defcustom gams-system-directory "c:/GAMS20.0/"
  "The GAMS system directory."
  :type 'file
  :group 'gams)

(defcustom gams-statement-upcase nil
  "*Non-nil means that statement is inserted in upper case.
If you want to use lower case, set nil to this variable."
  :type 'boolean
  :group 'gams)

(defcustom gams-dollar-control-upcase nil
  "*Non-nil means that dollar control option is inserted in upper case.
If you want to use lower case, set nil to this variable."
  :type 'boolean
  :group 'gams)

(defcustom gams-use-mpsge nil
  "*If you use MPSGE, set this variable to non-nil.
Non-nil enables MPSGE statement completion and colorization."
  :type 'boolean
  :group 'gams)

(defcustom gams-fill-column 74
  "*The column number used for fill-paragraph and auto-fill-mode."
  :type 'number
  :group 'gams)

(defcustom gams-recenter-font-lock nil
"Non-nil means that font-lock-fontify buffer when recentering.
If your computer is slow, you may better set this to nil."
  :type 'boolean
  :group 'gams)

(defcustom gams-file-extension '("gms")
  "*List of gams program file extensions.
If you open a file with an extension included in this list, GAMS mode
starts automatically.  It doen't matter whether upper case or lower
case."
  :type '(repeat (string :tag "value"))
  :group 'gams)

(defcustom gams-multi-process t
  "*Non-nil enables multiple GAMS processes.
Non-nil means that you can run multiple GAMS processes at the same time
in an Emacs.  If you rarely run multiple processes, you had better set it
to nil."
  :type 'boolean
  :group 'gams)
 
(defvar gams-mode-hook  nil
  "*Hook run when gams-mode starts.")

;;; from yatex.el
(defcustom gams-close-paren-always t
  "*Non-nil means that close parenthesis."
  :type 'boolean
  :group 'gams)

(defcustom gams-close-double-quotation-always t
  "*Non-nil means that close double quotation."
  :type 'boolean
  :group 'gams)

(defcustom gams-close-single-quotation-always nil
  "*Non-nil means that close quotation."
  :type 'boolean
  :group 'gams)

(defcustom gams-statement-name "set"
  "*The initial value of statement."
  :type 'string
  :group 'gams)

(defcustom gams-dollar-control-name "title"
  "*The initial value of dollar control."
  :type 'string
  :group 'gams)
  
(defcustom gams-user-comment
  "
*------------------------------------------------------------------------	
* %       
*------------------------------------------------------------------------
"
  "*User defined comment template.
You can insert the comment template defined in this variable by executing
`gams-insert-comment'.  % in the string indicates the cursor place and will
disappear after template insertion.
NB: You cannot include double quoatations and backslashes in this variables!"
  :type 'string
  :group 'gams)

(defcustom gams-comment-column 40
  "The default value of `comment-column' in GAMS mode."
  :type 'number
  :group 'gams)

(defcustom gams-inlinecom-symbol-start-default "{"
  "The default value for inline comment start symbol."
  :type 'string
  :group 'gams)

(defcustom gams-inlinecom-symbol-end-default "}"
  "The default value for inline comment end symbol."
  :type 'string
  :group 'gams)

(defcustom gams-eolcom-symbol-default "!"
  "The default value for eol comment symbol."
  :type 'string
  :group 'gams)

(setq-default gams-eolcom-symbol nil)
(setq-default gams-inlinecom-symbol-start nil)
(setq-default gams-inlinecom-symbol-en nil)

;; from epolib.el
(defcustom gams-default-pop-window-height 10
  "The default GAMS process buffer height.
If integer, sets the window-height of process buffer.  If string, sets the
percentage of it.  If nil, use default pop-to-buffer."
  :type 'number
  :group 'gams)

(defcustom gams-docs-dir "c:/GAMS20.0/docs"
      "The directory of GAMS PDF manuals.

If the GAMS system directory is c:/GAMS20.0, then set c:/GAMS20.0/docs in
this variable."
  :type 'directory
  :group 'gams)

(defcustom gams-docs-view-program "c:/Program Files/Adobe/Acrobat 4.0/Reader/AcroRd32.exe"
  "The full path to the pdf file viewer."
  :type 'file
  :group 'gams)


(defvar gams-manuals-alist
      '(("User-Manual" . "GAMSUsersGuide")
	("Tutorial" . "Tutorial")
	("PC-Install" . "pc-install")
	("Unix-Install" . "unix-install")
	("Solver-BDMLP" . "bdmlp")
	("Solver-CONOPT" . "conopt")
	("Solver-CPLEX" . "cplex")
	("Solver-DECIS" . "decis")
	("Solver-DICOPT" . "dicopt")
	("Solver-GAMSBAS" . "gamsbas")
	("Solver-GAMSCHK" . "gamschk")
	("Solver-MILES" . "miles")
	("Solver-MINOS" . "minos")
	("Solver-MPSGE" . "mpsge")
	("Solver-MPSWRITE" . "mpswrite")
	("Solver-OSL" . "osl")
	("Solver-OSLSE" . "oslse")
	("Solver-PATH" . "path")
	("Solver-SBB" . "sbb")
	("Solver-SNOPT" . "snopt")
	("Solver-SOLVERINTRO" . "solverintro")
	("Solver-XA" . "xa")
	("Solver-XPRESS" . "xpress")
	("Solver-XPRESSLICENSING" . "xpresslicensing"))
      "Alist of GAMS manuals.
(label . pdf-file-name)
")

;;; Variables for GAMS-LST mode.

(defvar gams-lst-mode-hook  nil
  "*GAMS-LST mode hooks.")

(defvar gams-lst-gms-extention  "gms"
  "*GAMS program file extention.")

;;; Key for GAMS-LST mode.

(defcustom gams-lk-1 "i"
  "Key for `gams-lst-jump-to-input-file'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-lk-2 "u"
  "Key for `gams-lst-jump-to-error-file'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-lk-3 "y"
  "Key for `gams-lst-view-error'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-lk-4 "b"
  "Key for `gams-lst-jump-to-input-file-2'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-lk-5 "L"
  "Key for `gams-lst-jump-to-line'."
  :type 'string
  :group 'gams-keys)

;;; Other customizable variables.

(defvar gams-statement-up
      '("SET" "SETS" "SCALAR" "SCALARS" "TABLE" "PARAMETER" "PARAMETERS"
	"EQUATION" "EQUATIONS" "VARIABLE" "VARIABLES"
	"POSITIVE VARIABLE" "POSITIVE VARIABLES"
	"NEGATIVE VARIABLE" "NEGATIVE VARIABLES"
	"INTEGER VARIABLE" "INTEGER VARIABLES"
	"BINARY VARIABLE" "BINARY VARIABLES"
	"ALIAS"
	"OPTION"
	"SOLVE" "MODEL" "DISPLAY" "LOOP" "IF" "SUM" "PROD")
      "The default list of GAMS statements.  Used for candidate of statement inserting")

(defvar gams-dollar-control-up
  '("BATINCLUDE" "EXIT" "INCLUDE" "LIBINCLUDE"
    "OFFTEXT" "ONTEXT" "SETGLOBAL" "SYSINCLUDE"
    "TITLE")
  "The default list of GAMS dollar control options.")

(defvar gams-statement-mpsge
    ; MPSGE
  '("MODEL:" "COMMODITIES:" "CONSUMERS:" "SECTORS:" "PROD:"
    "DEMAND:" "REPORT:" "CONSTRAINT:" "AUXILIARY:")
  "The default list of MPSGE statements.")

;;;;; Customizable variables end here.

;;;;; Non-customizable variables.

(defvar gams-run-key ?s
  "*GAMS run key")

(defvar gams-kill-key ?k
  "*GAMS kill key")

(defvar gams-option-key ?o
  "*GAMS option key")

(defvar gams-xemacs (string-match "XEmacs" emacs-version))
(defvar gams-emacs (if gams-xemacs nil t))
(defvar gams-win32
  (memq system-type '(ms-dos windows-nt)))
(defvar gams-dos (memq system-type '(ms-dos windows-nt OS/2)))
(defvar gams-emacs-19 (and gams-emacs (= emacs-major-version 19)))
(defvar gams-emacs-20 (and gams-emacs (= emacs-major-version 20)))
(defvar gams-emacs-21 (and gams-emacs (= emacs-major-version 21)))
(defvar gams-emacs-21.2 (and gams-emacs (string-match "21.2" emacs-version)))
(defvar gams-xemacs-21 (and gams-xemacs (= emacs-major-version 21)))

(defvar gams-simple-messages nil
  "Non-nil makes minibuffer messages simpler.")

(defvar gams-fill-prefix nil
  "*fill-prefix used for auto-fill-mode.
The default value is nil.")

(defvar gams-lst-extention "lst"
  "GAMS LST file extention.")

(defvar gams-fill-prefix nil
  "*fill-prefix used for auto-fill-mode.
The default value is nil.")

(defun gams-list-upcase (list)
  "Make each element of a LIST to upper case
and return a new list."
  (let* ((temp-list list) list-new ele)
    (while temp-list
      (setq ele (upcase (car temp-list))
	    list-new (cons ele list-new)
	    temp-list (cdr temp-list)))
    list-new))

(defun gams-list-downcase (list)
  "Make each element of a LIST to lower case
and return a new list."
  (let* ((temp-list list) list-new ele)
    (while temp-list
     (setq ele (downcase (car temp-list))
	   list-new (cons ele list-new)
	   temp-list (cdr temp-list)))
    list-new))

(defvar gams-user-statement-list nil)
(defvar gams-user-dollar-control-list nil)
(defvar gams-paragraph-start "[ \t]*$\\|^[\f\n]")
(defvar gams*command-process-buffer "*GAMS")
(defvar gams-statement-down
  (gams-list-downcase gams-statement-up))
(defvar gams-dollar-control-down
  (gams-list-downcase gams-dollar-control-up))
(defvar gams-statement-alist nil)
(defvar gams-dollar-control-alist nil)
(defvar gams-statement-regexp nil)

;(defvar gams:current-process-buffer nil)

;;; From EPO. 
(defconst gams:frame-feature-p
  (and (fboundp 'make-frame) window-system))

;;; I don't understand the meaning of this variable.
(defvar gams:shell-c
  (or (and (boundp 'shell-command-switch) shell-command-switch)
      (and (boundp 'shell-command-option) shell-command-option)
      (and (string-match "command.com\\|cmd.exe\\|start.exe" shell-file-name)
	   "/c")
      "-c")
  "*Command option for shell")

;; Set `gams*buffer-substring' to `buffer-substring-no-properties' if it
;; exits.  Otherwise set to `buffer-substring'.
(if (fboundp 'buffer-substring-no-properties)
    (fset 'gams*buffer-substring 'buffer-substring-no-properties)
  (fset 'gams*buffer-substring 'buffer-substring))

(cond
 ((fboundp 'screen-height)
  (fset 'gams*screen-height 'screen-height)
  (fset 'gams*screen-width 'screen-width))
 ((fboundp 'frame-height)
  (fset 'gams*screen-height 'frame-height)
  (fset 'gams*screen-width 'frame-width))
 (t (error "I don't know how to run GAMS on this Emacs...")))

;;; Autoload setting.

; For autoloading.
(setq auto-mode-alist
	(cons
	 (cons
	  (format "\\.\\(xyz%s\\)$" (regexp-opt
				     (append (gams-list-downcase gams-file-extension)
					     (gams-list-upcase gams-file-extension))))
	  'gams-mode) auto-mode-alist))
(autoload 'gams-mode "gams" "Enter GAMS mode" t)

; For GAMS-LST mode.
(setq auto-mode-alist
	(cons (cons "\\.\\(LST\\|lst\\)$" 'gams-lst-mode) auto-mode-alist))
(autoload 'gams-lst-mode "gams" "Enter GAMS-LST mode" t)

;; Load the values of various variables.
;(require 'gams-var)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code for font-lock.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; New variables.

(defvar gams-mpsge-face 'gams-mpsge-face
  "Face for MPSGE statements.")
(defvar gams-misc-face	'gams-misc-face
  "Face for misc.")
(defvar gams-comment-face 'gams-comment-face
  "Face for comment.")
(defvar gams-dollar-face 'gams-dollar-face
  "Face for dollar control options.")
(defvar gams-statement-face 'gams-statement-face
  "Face for GAMS statments.")

(defvar gams-lst-par-face 'gams-lst-par-face
  "Face for PARAMETER in GAMS-LST mode.")
(defvar gams-lst-set-face 'gams-lst-set-face
  "Face for PARAMETER in GAMS-LST mode.")
(defvar gams-lst-var-face 'gams-lst-var-face
  "Face for VAR in GAMS-LST mode.")
(defvar gams-lst-equ-face 'gams-lst-equ-face
  "Face for EQU in GAMS-LST mode.")
(defvar gams-lst-vri-face 'gams-lst-vri-face
  "Face for VARIABEL in GAMS-LST mode.")
(defvar gams-lst-oth-face 'gams-lst-oth-face
  "Face for OTH entry in GAMS-OUTLINE mode.")
(defvar gams-lst-warning-face 'gams-lst-warning-face
  "Face for warning in GAMS-LST mode.")
(defvar gams-lst-program-face 'gams-lst-program-face
  "Face for program listing in GAMS-LST mode.")
(defvar gams-ol-loo-face 'gams-ol-loo-face
  "Face for program listing in GAMS-LST mode.")
(defvar gams-string-face 'gams-string-face
  "Face for string.")
(defvar gams-operator-face 'gams-operator-face
  "Face for operator.")
(defvar gams-slash-face 'gams-slash-face
  "Face for set and parameter elements lying between slashes.")
(defvar gams-explanation-face 'gams-explanation-face
  "Face for explanatory texts in GAMS mode.")
(defvar gams-oth-cont-face 'gams-oth-cont-face
  "Face for the content of OTH item in GAMS-OUTLINE mode.")

;; This regular expression
(defvar gams-dollar-regexp
  (concat "\\(^\\|[^a-zA-Z0-9]+\\)\\([$]\\)[ \t]*"
  (regexp-opt
   (list "comment" "eolcom" "inlinecom" "maxcol" "mincol" "offeolcom"
"offinline" "offmargin" "offnestcom" "offtext" "onelcom" "oninline"
"onmargin" "onnestcom" "ontext" "dollar" "offdigit" "offempty" "offend"
"offeps" "offglobal" "offwarning" "ondigit" "onempty" "onend" "oneps"
"onglobal" "onwarning" "use205" "use225" "use999" "double" "eject"
"hidden" "lines" "offdollar" "offinclude" "offlisting" "offupper"
"ondollar" "oninclude" "onlisting" "onupper" "single" "stars" "stitle"
"title" "offsymlist" "offsymxref" "offuellist" "offuelxref" "onsymlist"
"onsymxref" "onuellist" "onuelxref" "abort" "batinclude" "call" "clear"
"echo" "error" "exit" "goto" "if" "include" "kill" "label" "libinclude"
"onglobal" "onmulti" "offglobal" "offmulti" "phantom" "setglobal" "shift"
"sysinclude") t)
"[^a-zA-Z0-9]+")
    "Regular expression for dollar control options.
It is used for font-lock.")

(defvar gams-statement-regexp-base
      (concat 
      (regexp-opt
       (list "abort" "acronym" "acronyms" "alias" "all" "and" "assign"
"binary" "card" "diag" "display" "eps" "eq" "equation" "equations" "ge"
"gt" "inf" "integer" "le" "loop" "lt" "maximazing" "minimizing" "model"
"models" "na" "ne" "negative" "not" "option" "options" "or" "ord"
"parameter" "parameters" "positive" "prod" "sameas" "scalar" "scalars"
"set" "sets" "smax" "smin" "sos1" "sos2" "sum" "system" "table" "using"
"variable" "variables" "xor" "yes" "repeat" "until" "while" "if" "then"
"else" "semicont" "semiint" "file" "files" "put" "putpage" "puttl" "free"
"no" "solve" "for" "abort" "abs" "arctan" "ceil" "cos" "errorf" "exp"
"floor" "log" "log10" "mapval" "max" "min" "mod" "normal" "power" "round"
"sign" "sin" "sqr" "sqrt" "trunc" "uniform" "putclose" ) t)
      "[^a-zA-Z0-9_:]+")
      "Regular expression for dollar control options.
It is used for font-lock.")      
      

(defvar gams-statement-regexp-1
      (concat "^[ \t]*" gams-statement-regexp-base)
      "Regular expression for GAMS statements
It is used for font-lock of level 1.")
      
(defvar gams-statement-regexp-2
      (concat "\\(^\\|[\n]\\|[^$a-zA-Z0-9_]+\\)" gams-statement-regexp-base)
      "Regular expression for GAMS statements
It is used for font-lock of level 2.")

(defvar gams-statement-regexp-base-2
      (concat 
      (regexp-opt
       (list "abort" "acronym" "acronyms" "alias" "assign" "binary" "diag"
"display" "equation" "equations" "integer" "loop" "model" "models"
"negative" "option" "options" "parameter" "parameters" "positive" "sameas"
"scalar" "scalars" "set" "sets" "sos1" "sos2" "system" "table" "variable"
"variables" "xor" "repeat" "until" "while" "if" "then" "else" "semicont"
"semiint" "file" "files" "put" "putpage" "puttl" "free" "solve" "for"
"errorf" "floor" "mapval" "mod" "putclose" ) t)
      "[^a-zA-Z0-9_:;]+")
      "Regular expression for reserved words.")

;;; GAMS mode.
(defface gams-comment-face
    '((((class color) (background light)) (:bold nil :foreground "limegreen"))
      (((class color) (background dark)) (:bold t :foreground "lawn green")))
  "Face for commented out texts."
  :group 'gams-faces)

(defface gams-mpsge-face
    '((((class color) (background light)) (:bold nil :foreground "gold"))
      (((class color) (background dark)) (:bold t :foreground "hot pink")))
  "Face for MPSGE statements."
  :group 'gams-faces)

(defface gams-statement-face
  '((((class color) (background light)) (:bold nil :foreground "DodgerBlue"))
    (((class color) (background dark)) (:bold t :foreground "cyan")))
  "Face for GAMS statements."
  :group 'gams-faces)

(defface gams-dollar-face
  '((((class color) (background light)) (:bold nil :foreground "hot pink"))
    (((class color) (background dark)) (:bold t :foreground "yellow")))
  "Face for dollar control options."
  :group 'gams-faces)

(defface gams-misc-face
  '((((class color) (background light)) (:foreground "red" :bold nil))
    (((class color) (background dark)) (:foreground "red" :bold t)))
  "Face for misc."
  :group 'gams-faces)


;;; GAMS-LST mode.
(defface gams-lst-par-face
  '((((class color) (background light)) (:bold t :foreground "DodgerBlue"))
    (((class color) (background dark)) (:bold t :foreground "yellow")))
  "Faces for PARAMETER entry in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-lst-set-face
  '((((class color) (background light)) (:bold t :foreground "light blue"))
    (((class color) (background dark)) (:bold t :foreground "sandy brown")))
  "Face for SET entry in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-lst-var-face
  '((((class color) (background light)) (:bold t :foreground "hot pink"))
    (((class color) (background dark)) (:bold t :foreground "cyan")))
  "Face for VAR endtry in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-lst-equ-face
  '((((class color) (background light)) (:bold t :foreground "lawn green"))
    (((class color) (background dark)) (:bold t :foreground "pink")))
  "Face for EQU entry in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-lst-vri-face
    '((((class color) (background light)) (:bold t :foreground "purple"))
      (((class color) (background dark)) (:bold t :foreground "pale green")))
  "Face for VARIABLE entry in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-lst-oth-face
  '((((class color) (background light)) (:bold t :foreground "gray60"))
    (((class color) (background dark)) (:bold t :foreground "gray60")))
  "Face for ?"
  :group 'gams-faces)

(defface gams-lst-warning-face
  '((((class color) (background light)) (:bold t :foreground "red"))
    (((class color) (background dark)) (:bold t :foreground "red")))
  "Face for warnings in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-lst-program-face
  '((((class color) (background light)) (:foreground "goldenrod"))
    (((class color) (background dark)) (:foreground "khaki")))
  "Face for copied program listing in GAMS-LST mode."
  :group 'gams-faces)

(defface gams-ol-loo-face
  '((((class color) (background light)) (:bold t :foreground "maroon"))
    (((class color) (background dark)) (:bold t :foreground "#7777ff")))
  "Face for LOO entry in GAMS-OUTLINE mode."
  :group 'gams-faces)

;;; New face.
(defface gams-string-face
  '((((class color) (background light)) (:bold nil :foreground "violet red"))
    (((class color) (background dark)) (:bold nil :foreground "khaki")))
  "Face for quoted string in GAMS mode."
  :group 'gams-faces)

(defface gams-operator-face
  '((((class color) (background light)) (:bold nil :foreground "red"))
    (((class color) (background dark)) (:bold nil :foreground "#ccaaff")))
  "Face for operators in GAMS mode."
  :group 'gams-faces)

(defface gams-slash-face
  '((((class color) (background light)) (:bold nil :foreground "deep pink"))
    (((class color) (background dark)) (:bold nil :foreground "pink")))
  "Face for set and parameter elements lying between slashes."
  :group 'gams-faces)

(defface gams-explanation-face
  '((((class color) (background light)) (:bold nil :foreground "goldenrod"))
    (((class color) (background dark)) (:bold nil :foreground "orange")))
  "Face for explanatory texts in GAMS mode."
  :group 'gams-faces)

(defface gams-oth-cont-face
  '((((class color) (background light)) (:bold nil :foreground "gray50"))
    (((class color) (background dark)) (:bold nil :foreground "khaki")))
  "Face for the content of OTH item in GAMS-OUTLINE mode."
  :group 'gams-faces)

;;;
(defcustom gams-font-lock-level 2
  "The level of decoralization of font-lock in GAMS mode.
0 => no color.
1 => minimum.
2 => maximize."
  :group 'gams
  :type 'number)

(defcustom gams-lst-font-lock-level 2
  "The level of decoralization of font-lock in GAMS-LST mdoe.
0 => no color.
1 => minimum.
2 => maximize."
  :group 'gams
  :type 'number)

(defcustom gams-ol-font-lock-level 2
  "The level of decoralization of font-lock in GAMS-OUTLINE mode.
0 => no color.
1 => minimum.
2 => maximize."
  :group 'gams
  :type 'number)

(defvar gams-font-lock-keywords nil)
(defvar gams-lst-font-lock-keywords nil)
(defvar gams-ol-font-lock-keywords nil)

(defvar gams-regexp-declaration-2
      "\\(parameter\\|set\\|scalar\\|table\\|\\(free\\|positive\\|negative\\|binary\\|integer\\)*[ ]*variable\\|equation\\|model\\|file\\)[s]?")

(defvar gams-font-lock-keywords-1
      (list
       ;; MPSGE dollar control options.
       (list "\\($model\\|$commodities\\|$consumer[s]?\\|$sectors\\|$prod\\|$demand\\|$report\\|$constraint\\|$auxiliary\\|$funlog\\|$echop\\|$peps\\|$eulchk\\|$walchk\\)"
	     '(0 gams-mpsge-face))
       ;; the ontext - offtext pair.
       '(gams-store-point-ontext . gams-comment-face)
       ;; Commented out texts by *
       '(gams-store-point-comment . gams-comment-face)
       ;; texts in slash pair.
       '(gams-store-point-slash . gams-slash-face)
       ;; Text in double quoatations.
       '(gams-store-point-single-quote . gams-string-face)
       ;; Text in double quoatations.
       '(gams-store-point-double-quote . gams-string-face)
       ;; Dollar control options.
       '(gams-store-point-dollar . gams-dollar-face)
       ;; Standard GAMS statements.
       '(gams-store-point-statement-1 . gams-statement-face)
       ;; Commented out text by !
       (list "[!].*$" '(0 gams-comment-face))
       ;; inline comment.
       '(gams-store-point-inlinecom . gams-comment-face)
       ;; end-of-line comment.
       '(gams-store-point-eolcom . gams-comment-face)
       ;; Conditional dollar.
       (list "[$]" '(0 gams-dollar-face))
       "Font lock keyboards for GAMS mode.  Level 1."))

(defvar gams-font-lock-keywords-2
      (list
	;; MPSGE dollar control options.
       (list "\\($model\\|$commodities\\|$consumer[s]?\\|$sectors\\|$prod\\|$demand\\|$report\\|$constraint\\|$auxiliary\\|$funlog\\|$echop\\|$peps\\|$eulchk\\|$walchk\\)"
	     '(0 gams-mpsge-face)) 
       ;; the ontext - offtext pair.
       '(gams-store-point-ontext . gams-comment-face)
       ;; Commented out texts by *
       '(gams-store-point-comment . gams-comment-face)
       ;; Inline comment.
       '(gams-store-point-inlinecom . gams-comment-face)
       ;; End-of-line comment.
       '(gams-store-point-eolcom . gams-comment-face)
       ;; title and stitle.
       (list "^$title[^\n]*$" '(0 gams-dollar-face))
       (list "^$stitle[^\n]*$" '(0 gams-dollar-face))
       ;; texts in slash pair.
       '(gams-store-point-slash . gams-slash-face)
       ;; Text in double quoatations.
       '(gams-store-point-single-quote . gams-string-face)
       ;; Text in double quoatations.
       '(gams-store-point-double-quote . gams-string-face)
       ;; Commented out text by !
       (list "[!].*$" '(0 gams-comment-face))
       ;; Dollar control options.
       '(gams-store-point-dollar . gams-dollar-face)
       ;; Explanatory texts.
       '(gams-store-point-explanation . gams-explanation-face)
       ;; Standard GAMS statements.
       '(gams-store-point-statement-2 . gams-statement-face)
       ;; Conditional dollar.
       (list "[$]" '(0 gams-dollar-face))
       ;; Semicolon
       (list ";" '(0 gams-misc-face))
       ;; Operator
       (list "=\\(e\\|g\\|l\\)=" '(0 gams-operator-face)))
      "Font lock keyboards for GAMS mode.  Level 1.")

(defvar gams-lst-font-lock-keywords-1
  (list
    (list "^[*][*][*][*][^\n]+" '(0 gams-lst-warning-face))
    (list "^----[ \t]+[0-9]+[ ]PARAMETER[ ]+" '(0 gams-lst-par-face))
    (list "^[ \t]+\\(PARAMETER\\)[ ]+" '(1 gams-lst-par-face))
    (list "^----[ ]+[0-9]+[ ]SET[ ]+" '(0 gams-lst-set-face))
    (list "^----[ ]+[0-9]+[ ]VARIABLE[ ]+" '(0 gams-lst-vri-face))
    (list "^[ \t]+\\(VARIABLE\\)[ ]+" '(1 gams-lst-vri-face)))
  "Regular expression for font-lock in GAMS-LST mode.  Level 1.")

(defvar gams-lst-font-lock-keywords-2
      (append
       gams-lst-font-lock-keywords-1
       (list
	(list "\\(----[ ]+VAR[ ]+[^ ]+\\)[ ]*[^\n]+" '(1 gams-lst-var-face))
	(list "\\(----[ ]+EQU[ ]+[^ ]+\\)[ ]*[^\n]+" '(1 gams-lst-equ-face))
	;; Copy of program file
	'(gams-store-point-copied-program . gams-lst-program-face)))
      "Regular expression for font-lock in GAMS-LST mode.  Level 2.")

(defvar gams-ol-font-lock-keywords-1
  (list
    '(gams-store-point-rep-sum . gams-lst-warning-face)
    '(gams-store-point-sol-sum . gams-lst-warning-face)
    (list "^\\(COM: \\).*" '(0 gams-comment-face))
    (list "^[ ][ ]\\(OTH\\)[ \t]+\\(.*\\)" '(1 gams-lst-oth-face) '(2 gams-oth-cont-face))
    (list "^[ ][ ]\\(SUM\\)" '(1 gams-lst-warning-face)))
  "Regular expression for font-lock in GAMS-OUTLINE mode.  Level 1.")

(defvar gams-ol-font-lock-keywords-2
  (append
   gams-ol-font-lock-keywords-1
   (list
    (list "^[ ][ ]\\(PAR\\)" '(1 gams-lst-par-face))
    (list "^[ ][ ]\\(SET\\)" '(1 gams-lst-set-face))
    (list "^[ ][ ]\\(VAR\\)" '(1 gams-lst-var-face))
    (list "^[ ][ ]\\(VRI\\)" '(1 gams-lst-vri-face))
    (list "^[ ][ ]\\(EQU\\)" '(1 gams-lst-equ-face))
    (list "^[ ][ ]\\(LOO\\)" '(1 gams-ol-loo-face))
    (list "^[*] \\(.*\\)" '(0 gams-mpsge-face))))
  "Regular expression for font-lock in GAMS-OUTLINE mode.  Level 2.")

;;;;; To turn off jit-lock-mode.
(if gams-emacs-21
    (if (equal font-lock-support-mode 'jit-lock-mode)
	(setq font-lock-support-mode
	      '((gams-mode . nil) (t . jit-lock-mode)))))

;;;;; Functions for storing points for font-lock.

;; From `font-latex.el'.
(defun gams-store-point-statement-1 (limit)
  "Store points for font-lock for GAMS statements.  Level 1."
  (when (re-search-forward
	 gams-statement-regexp-1 limit t)
    (let ((beg (match-beginning 1))
	  (end (match-end 1)))
      (goto-char end)
      (store-match-data (list beg end))
      t)))

(defun gams-store-point-statement-2 (limit)
  "Store points for font-lock for GAMS statements.  Level 2."
  (when (re-search-forward
	 gams-statement-regexp-2 limit t)
    (let ((beg (match-beginning 2))
	  (end (match-end 2)))
      (goto-char end)
      (store-match-data (list beg end))
      t)))

(defun gams-store-point-comment (limit)
  "Store points for font-lock for comment."
  (when (re-search-forward
	 (concat "^\\([" gams-comment-prefix "].*\\)$") limit t)
    (let ((beg (match-beginning 1))
	  (end (match-end 1)))
      (store-match-data (list beg end))
      t)))

(defun gams-store-point-ontext (limit)
  "Store points for font-lock for ontext-offtext."
  (let (beg end)
    (when (re-search-forward "^$ontext" limit t)
      (setq beg (match-beginning 0))
      (when (re-search-forward "^$offtext" limit t)
	(setq end (match-end 0))
	(store-match-data (list beg end))
	t))))

(defun gams-store-point-dollar (limit)
  "Store points for font-lock for dollar control options."
  (when (re-search-forward gams-dollar-regexp limit t)
    (let ((beg (match-beginning 2))
	  (end (match-end 3)))
      (goto-char end)
      (store-match-data (list beg end)))
    t))

(defun gams-store-point-single-quote (limit)
  "Store points for font-lock for texts in single quotations."
  (when (re-search-forward "[ \t(,]?\\(\'[^\n\']+\'\\)[), ;\t\n]" limit t)
    (let ((beg (match-beginning 1))
	  (end (match-end 1)))
      (store-match-data (list beg end))
      t)))

(defun gams-store-point-double-quote (limit)
  "Store points for font-lock for texts in double quotations."
  (when (re-search-forward "[ \t(,]?\\(\"[^\n\"]+\"\\)[), ;\t\n]" limit t)
    (let ((beg (match-beginning 1))
	  (end (match-end 1)))
      (store-match-data (list beg end))
      t)))

(defun gams-judge-in-comment ()
  "Judge whether the current point is in eol comment or inline comment.
If in, return t.  Otherwise nil."
  (let ((cur-po (point))
	(eol gams-eolcom-symbol)
	(inl gams-inlinecom-symbol-start)
	beg end cont flag reg)
    (save-excursion
      (beginning-of-line)
      (setq beg (point))
      (end-of-line)
      (setq end (point)))
    (save-excursion
      (cond
       ((and eol inl)
	(setq reg (concat (concat "[" gams-eolcom-symbol "]")
			  "\\|"
			  (concat "[" gams-inlinecom-symbol-start "]"))))
       (eol
	(setq reg (concat "[" gams-eolcom-symbol "]")))
       (inl
	(setq reg (concat "[" gams-inlinecom-symbol-start "]"))))
      (if reg
	  (if (re-search-backward reg beg t)
	      (progn
		(setq cont (gams*buffer-substring (match-beginning 0)
						  (match-end 0)))
		(if (equal cont gams-inlinecom-symbol-start)
		    (if (and (re-search-forward (concat "[" gams-inlinecom-symbol-end "]") end t)
			     (<= cur-po (point)))
			(setq flag t))
		  (setq flag t)))
	    )))
    flag))

(defun gams-judge-in-quote ()
  "Judge whether the current point is in quoted text.
If in, return t.  Otherwise nil."
  (let ((cur-po (point))
	beg end cont flag)
    (save-excursion
      (beginning-of-line)
      (setq beg (point))
      (end-of-line)
      (setq end (point)))
    (save-excursion
      (if (re-search-backward "\"\\|'" beg t)
	  (progn
	    (setq cont (gams*buffer-substring (match-beginning 0)
					      (match-end 0)))
	    (goto-char (match-end 0))
	    (if (re-search-forward cont end t)
		(if (<= cur-po (point))
		    (setq flag t))))))
    flag))

(defun gams-check-decl-eol ()
  "If there is nothing after the current point, return t.  Otherwise nil."
  (let ((cur-po (point)) end flag)
    (save-excursion
      (end-of-line)
      (setq end (point)))
    (if (re-search-forward "[^ \t\n]" end t)
	(progn
	  (goto-char cur-po)
	  (if (looking-at
	       (concat "[ \t]*\\([;]"
		       (if gams-inlinecom-symbol-start
			   (concat "\\|[" gams-inlinecom-symbol-start "]"))
		       (if gams-eolcom-symbol
			   (concat "\\|[" gams-eolcom-symbol "]"))
		       "\\)"))
	      ;; end of line.
	      (setq flag t)
	    ;; Identifier exits.
	    (setq flag nil)))
      (setq flag t))
    flag))
	    
(defun gams-store-explanation ()
  "Store the points of explanatory text if it exits."
  (let ((cur-po (point)) beg end cont flag)
    (save-excursion
      (end-of-line)
      (setq end (point)))
    (if (re-search-forward "[^ \t\n]" end t)
	;; if something exists.
	(progn
	  (goto-char cur-po)
	  (if (re-search-forward
	       (concat "[ \t]*\\([;]\\|[/]"
		       (if gams-inlinecom-symbol-start
			   (concat "\\|[" gams-inlinecom-symbol-start "]"))
		       (if gams-eolcom-symbol
			   (concat "\\|[" gams-eolcom-symbol "]"))
		       "\\)") end t)
	      ;; if eol symbol exits
	      (setq end (match-beginning 0))
	    ;; if eol symbol does not exit.
	    (setq end end))
	  (setq cont (gams*buffer-substring cur-po end))
	  (if (string-match "[^ \t]" cont)
	      (setq flag (list cur-po end))
	    (setq flag (list nil end))))
      (setq flag (list nil end)))
    flag))

(defun gams-store-point-slash (limit)
  "Store points for font-lock for texts in slash pair."
  (let (beg end flag flag-find ontext)
    (catch 'found
      (while t
	(if (re-search-forward "/" limit t)
	    (progn
	      (if (and (null (setq ontext (gams-judge-in-on-off-text)))
		       (gams-judge-in-declaration)
		       (null (gams-judge-in-quote))
		       (null (gams-judge-in-comment)))
		  (progn
		    (setq beg (1- (point)))
		    (cond
		     ((null (save-excursion (re-search-forward "/" limit t)))
		      (throw 'found t))
		     (t
		      (while (null (and (re-search-forward "/" limit t)
					(setq end (match-end 0))
					(null (gams-judge-in-quote))
					(null (gams-judge-in-comment))))
			nil)
		      (store-match-data (list beg end))
		      (setq flag t)
		      (throw 'found t))))
		;; If conditions are not satisfied, search the next slash.
		;; i.e. do nothing here.
		nil))
	  ;; If not found, throw t.
	  (throw 'found t))))
    flag))

(defun gams-check-decl-type ()
  "Check declaration type for coloring explanatory texts."
  (let (type beg end temp)
    (looking-at (concat gams-regexp-declaration-2 "[ \t]*"))
    (goto-char (match-end 0))
    ;;
    (if (null (gams-check-decl-eol))
	;; There is identifier.
	(progn
	  ;; skip identifier.
	  (cond
	   ((looking-at "[^ \t(\n]+[ \t]*[(][^)]+[)][ \t]*")
	    (goto-char (match-end 0)))
	   ((looking-at "[^ \t\n]+[ \t]*")
	    (goto-char (match-end 0))))
	  ;; store point.
	  (setq beg (point))
	  ;; Search end of explanation.
	  (setq temp (gams-store-explanation))
	  (if (car temp)
	      ;; Explanation exits.
	      (progn (setq beg (car temp))
		     (setq end (car (cdr temp))))
	    ;; Does not exist.
	    (setq beg (car temp))
	    (setq end (car (cdr temp)))
	    ))
      (forward-line 1)
      (setq temp (gams-check-decl-type-2)
	    beg  (car temp)
	    end  (car (cdr temp))))
    (list beg end)))
	    
(defun gams-check-decl-type-2 ()
  "Check declaration type for coloring explanatory texts."
  (let (beg end)
    ;; skip irrelevant lines.
    (skip-chars-forward "[ \t\n]")
    (beginning-of-line)
    (while (and (null (eobp)) (gams-check-line-type))
      (forward-line 1))
    ;;
    (if (null (gams-check-decl-eol))
	;; There is identifier.
	(progn
	  ;; skip spaces.
	  (skip-chars-forward "[ \t]")
	  ;; skip identifier.
	  (cond
	   ((looking-at "[^ \t(\n]+[ \t]*[(][^)]+[)][ \t]*")
	    (goto-char (match-end 0)))
	   ((looking-at "[^ \t\n]+[ \t]*")
	    (goto-char (match-end 0))))
	  ;; store point.
	  (setq beg (point))
	  ;; Search end of explanation.
	  (setq temp (gams-store-explanation))
	  (if (car temp)
	      ;; Explanation exits.
	      (progn (setq beg (car temp))
		     (setq end (car (cdr temp))))
	      ;; Explanation not exist.
	    (setq beg nil)
	    (setq end (car (cdr temp)))))
      (save-excursion
	(end-of-line)
	(setq beg nil)
	(setq end (point))))
    (list beg end)))

(defun gams-jump-next-slash (begin)
  "Return the point of the next slash if the current point is in a slash
pair.  If the current point is not in a slash pair, do nothing.  BEGIN is
the begin point of declaration."
  (let ((count 0) (cur-po (point)) po)
    (save-excursion
      (goto-char begin)
      (while (re-search-forward "/" cur-po t)
	(when (and (null (gams-judge-in-comment))
		   (null (gams-judge-in-quote)))
	  (setq count (+ 1 count))))
      (when (and (> count 0) (oddp count))
	(while (null
		(and (re-search-forward "/" nil t)
		     (null (gams-judge-in-comment))
		     (null (gams-judge-in-quote))))
	  t)
	(setq po (point))))
    po))

(defun gams-store-point-explanation (limit)
  "Store points for font-lock for explanatory text."
  (let (flag cont beg end ontext po-a po-b)
    ;; Use catch-throw pair.
    (catch 'found
      (while t
	;; In an ontext-offtext pair?
	(setq ontext (gams-judge-in-on-off-text))
	(cond
	 ;; If not in an ontext-offtext pair and if in declaration.
	 ((and (null ontext)
	       (setq po-b (gams-judge-in-declaration)))
  	  (while (and (null (gams-judge-slash-end po-b))
 		      (<= (point) limit))
  	    (forward-line 1))
 	  (if (null (<= (point) limit))
 	      (throw 'found t)
	    (setq cont (gams-check-decl-type-2))
	    (setq beg (car cont))
	    (setq end (car (cdr cont)))
	    (if (null beg)
		(progn (goto-char end) (forward-line 1))
	      ;;
	      (store-match-data (list beg end))
	      (goto-char end)
	      (forward-line 1)
	      (setq flag t)
	      (throw 'found t))))
	 ;; 
	 ((>= (point) limit)
	  (throw 'found t)
	  (setq flag nil))
	 ;;
	 ((and (if (re-search-forward (concat "^[ \t]*" gams-regexp-declaration-2 "[ \t\n]+") limit t)
		   (setq po-a (match-beginning 1))
		 nil)
	       (null (setq ontext (gams-judge-in-on-off-text))))
	  (progn
	    (setq po-b (point))
	    (goto-char po-a)
	    (setq cont (gams-check-decl-type))
	    (setq beg (car cont))
	    (setq end (car (cdr cont)))
	    (if (null beg)
		;;
		(progn (goto-char end)
		       (forward-line 1))
		;;
	      (store-match-data (list beg end))
	      (goto-char end)
	      (forward-line 1)
	      (setq flag t)
	      (throw 'found t))))
	 ;;
	 (ontext
	  (if (re-search-forward "^$offtext" limit t)
	      nil
	    (throw 'found t)
	    (setq flag nil)))
	 ;;
	 (t
	  (throw 'found t)
	  (setq flag nil)))))
    ;; If item is found, flag is t.
    flag))

(defun gams-store-point-inlinecom (limit)
  "Store points for font-lock for inline comment."
  (let (beg end)
    (if (null gams-inlinecom-symbol-start)
	nil
      (when (re-search-forward (concat "[" gams-inlinecom-symbol-start "]") limit t)
	(setq beg (match-beginning 0))
	(save-excursion (end-of-line)
			(setq end (point)))
	(when (re-search-forward (concat "[" gams-inlinecom-symbol-end "]") end t)
	  (setq end (match-end 0))
	  (store-match-data (list beg end))
	  t)))))

;; gams-lst
(defun gams-store-point-eolcom (limit)
  "Store points for font-lock for end of line comment."
  (if (null gams-eolcom-symbol)
      nil
    (when (re-search-forward
	   (concat "\\([" gams-eolcom-symbol "].*\\)$") limit t)
      (let ((beg (match-beginning 1))
	    (end (match-end 1)))
	(store-match-data (list beg end))
	t))))
(defun gams-store-point-sol-sum (limit)
  "Store points for font-lock for SOLVER SUMMARY in OUTLINE mode."
  (let (beg end)
    (when (re-search-forward "SUM[ \t]+\\(SOLVER SUMMARY[ \t]+SOLVER[ \t]+STATUS[ \t]+=\\( [^1]\\| 1, MODEL STATUS = [^128]\\)\\)" limit t)
      (setq beg (match-beginning 1))
      (setq end (save-excursion (end-of-line) (point)))
      (store-match-data (list beg end))
      t)))

(defun gams-store-point-rep-sum (limit)
  "Store points for font-lock for REPORT SUMMARY in OUTLINE mode."
  (let (beg end)
    (when (re-search-forward "SUM[ \t]+\\(REPORT SUMMARY[ \t]+[[]\\([^0]\\|0, [^0]\\|0, 0, [^0]\\|0, 0, 0, [^0]\\|0, 0, 0, 0, [^0]\\)\\)" limit t)
      (setq beg (match-beginning 1))
      (setq end (save-excursion (end-of-line) (point)))
      (store-match-data (list beg end))
      t)))

(defun gams-store-point-copied-program (limit)
  "Store points for font-lock for copied program in LST mode."
  (let (flag cont)
    (when (re-search-forward "\\(^[ ]?[ ]?[ ]?[ ]?[ ]?[ ]?\\([0-9]+[ ][ ].*\\)\\|^\\(COMPILATION\\) TIME\\|^\\(Error\\) Messages\\|^\\(Include\\) File Summary\\|^\\(E x e c u t i o n\\)\\)" limit t)
      (setq cont
	    (cond
	     ((match-beginning 2)
	      (buffer-substring (match-beginning 2) (match-end 2)))
	     ((match-beginning 3)
	      (buffer-substring (match-beginning 3) (match-end 3)))
	     ((match-beginning 4)
	      (buffer-substring (match-beginning 4) (match-end 4)))
	     ((match-beginning 5)
	      (buffer-substring (match-beginning 5) (match-end 5)))
	     ((match-beginning 6)
	      (buffer-substring (match-beginning 6) (match-end 5)))))
      (if (or (equal "COMPILATION" cont)
	      (equal "Error" cont)
	      (equal "Include" cont)
	      (equal "E x e c u t i o n" cont))
	  (setq flag nil)
	(let ((beg (match-beginning 1))
	      (end (match-end 1)))
	  (store-match-data (list beg end))
	  (setq flag t))))
    flag))

;;; Functions for changing font-lock level.
(defun gams-update-font-lock-keywords (mode level)
  "Change the font lock level in MODE to LEVEL."
  (cond
   ((equal mode "g")
    (setq gams-font-lock-level level)
    (cond
     ((equal level 0) (setq gams-font-lock-keywords nil))
     ((equal level 1) (setq gams-font-lock-keywords gams-font-lock-keywords-1))
     ((equal level 2) (setq gams-font-lock-keywords gams-font-lock-keywords-2))))
   ((equal mode "l")
    (setq gams-lst-font-lock-level level)
    (cond
     ((equal level 0) (setq gams-lst-font-lock-keywords nil))
     ((equal level 1) (setq gams-lst-font-lock-keywords gams-lst-font-lock-keywords-1))
     ((equal level 2) (setq gams-lst-font-lock-keywords gams-lst-font-lock-keywords-2))))
   ((equal mode "o")
    (setq gams-ol-font-lock-level level)
    (cond
     ((equal level 0) (setq gams-ol-font-lock-keywords nil))
     ((equal level 1) (setq gams-ol-font-lock-keywords gams-ol-font-lock-keywords-1))
     ((equal level 2) (setq gams-ol-font-lock-keywords gams-ol-font-lock-keywords-2))))
   ))

(defun gams-check-font-lock-level-mode (&optional mode)
  "Check the font-lock level in MODE."
  (cond
   ((equal mode "g")
    gams-font-lock-level)
    ((equal mode "l")
    gams-lst-font-lock-level)
   ((equal mode "o")
    gams-ol-font-lock-level)
   (t
    (let ((cur-mode (gams-return-mode)))
      (cond
       ((equal cur-mode "g") gams-font-lock-level)
       ((equal cur-mode "l") gams-lst-font-lock-level)
       ((equal cur-mode "o") gams-ol-font-lock-level))))))

(defun gams-return-mode-name (&optional mode)
  "Return the mode name.
If MODE is g, return GAMS mode,
If MODE is l, return GAMS-LST mode,
If MODE is o, return GAMS-OUTLINE mode.
Otherwise, return the mode name of current buffer."
  (cond
   ((equal mode "g")
    "GAMS mode")
   ((equal mode "l")
    "GAMS-LST mode")
   ((equal mode "o")
    "GAMS-OUTLINE mode")
   (t mode-name)))

(defun gams-return-mode ()
  "Return the current mode name."
  (let ((cur-mode mode-name))
    (cond
     ((equal cur-mode "GAMS")
      "g")
     ((equal cur-mode "GAMS-LST")
      "l")
     ((equal cur-mode "GAMS-OUTLINE")
      "o"))))

(defun gams-choose-font-lock-level ()
  "Choose the level of decoralization."
  (interactive)
  (let ((cur-mode (gams-return-mode))
	(level 0)
	cur-level temp-mode)
    (message
     (format "Choose [g]ms, [l]st, [o]utline, RET = current mode."))
    (let ((mode (char-to-string (read-char))))
      (if (null (string-match "[glo\r]" mode))
	  (message "Push g, l, o, or RET!")
	(when (equal mode "\r")
	  (setq mode (gams-return-mode)))
	(setq temp-mode (gams-return-mode-name mode))
	;; 
	(message (format "Current font-lock level in %s = %d:  Choose 0, 1, or 2"
			 temp-mode
			 (setq cur-level (gams-check-font-lock-level-mode mode))))
	(setq level (char-to-string (read-char)))
	(if (null (string-match "[012\r]" level))
	    (message "Push 0, 1, 2!")
	  ;;
	  (if (equal level "\r")
	      (setq level (gams-check-font-lock-level-mode))
	    (setq level (string-to-number level)))
	  ;;
	  (gams-choose-font-lock-level-internal level mode cur-mode)
	  ;;
	  (message (format "The font-lock level in %s is changed from %d to %d."
			   temp-mode cur-level level))
	  )))))

(defun gams-choose-font-lock-level-internal (level mode cur-mode)
  ""
  ;; Update keywords for font-lock.
  (gams-update-font-lock-keywords mode level)
  (cond 
   ((equal mode "g")
    (setq font-lock-keywords gams-font-lock-keywords)
    (setq font-lock-defaults '(gams-font-lock-keywords t t)))
   ((equal mode "l")
    (setq font-lock-keywords gams-lst-font-lock-keywords)
    (setq font-lock-defaults '(gams-lst-font-lock-keywords t t)))
   ((equal mode "o")
    (setq font-lock-keywords gams-ol-font-lock-keywords)
    (setq font-lock-defaults '(gams-ol-font-lock-keywords t t))))
  (when (equal cur-mode mode)
    (if (null (equal level 0))
	(progn (font-lock-mode -1)
	       (font-lock-mode 1)
	       (when (null font-lock-fontified)
		 (font-lock-fontify-buffer)))
      (font-lock-mode -1))))

(defun gams-judge-in-declaration ()
  "Judge whether the cursor is in declaration environment.
Return nil if not in declaration environment.
Return the point if in declaration environment."
  (let ((cur-po (point))
	temp-po	beg-po temp-con)
    (save-excursion
      ;; Search reserved expression backward.
      (if (re-search-backward
	   (concat "^[ \t]*\\("
		   gams-regexp-declaration-2
		   "\\|"
		   gams-regexp-loop
		   "\\|"
		   gams-regexp-other
		   "\\|"
		   gams-regexp-mpsge
 		   "\\|$offtext\\|$ontext\\)") nil t)
	  ;; Store the matched.
	  (progn
	    (setq temp-con (gams*buffer-substring (match-beginning 0)
						  (match-end 0)))
	    (setq temp-po (point))
	    (skip-chars-forward " \t")
	    (forward-char 1)
	    (cond
	     ;; If the matched is table, do nothing.
	     ((string-match "table" temp-con) t)
	     ;; If the matched is declaration.
	     ((string-match gams-regexp-declaration-2 temp-con)
	      ;; Search ; forward.
	      (when (null (re-search-forward ";" cur-po t))
		;; If not found.
		(goto-char cur-po)
		;; Move to the next line.
		(while (and (gams-check-line-type) (null (eobp)))
		  (forward-line 1))
		(when (null (eobp))
		  (when (null (looking-at (concat "^[ \t]*" gams-regexp-declaration-2)))
		      (setq beg-po temp-po)))))))))
    beg-po))

(defun gams-font-lock-mark-block-function ()
  "The function for mark block in GAMS mode."
  (let ((cur-po (point))
	(regexp (concat "^[ \t]*\\(" gams-regexp-declaration "\\|" gams-regexp-loop "\\|"
			gams-regexp-other "\\|" gams-regexp-mpsge
			"\\|$offtext\\|$ontext\\)")))
    (push-mark (point))
    (if (gams-judge-in-on-off-text)
	(progn (re-search-forward "^$offtext" nil t)
	       (push-mark (point) nil t)
	       (re-search-backward "^$ontext" nil t)
	       (goto-char (match-beginning 0)))
      (let ((count-1 4) (count-2 4))
	(while (< 0 count-1)
	  (if (re-search-forward regexp nil t)
	      (setq count-1 (- count-1 1))
	    (setq count-1 -1)))
	(if (equal count-1 -1)
	    (push-mark (point-max) nil t)
	  (beginning-of-line)
	  (when (gams-judge-in-on-off-text)
	    (re-search-backward "^$ontext" cur-po t))
	  (push-mark (point) nil t))
	(goto-char cur-po)
	(while (< 0 count-2)
	  (if (re-search-backward regexp nil t)
	      (setq count-2 (- count-2 1))
	    (setq count-2 -1)))
	(if (equal count-2 -1)
	    (goto-char (point-min))
	  (when (gams-judge-in-on-off-text)
	    (re-search-forward "^$offtext" cur-po t)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code for GAMS mode.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defun gams-insert-tab ()
  "Insert a tab."
  (interactive)
  (insert "\t"))

(setq gams-comment-prefix-default "*")
(setq-default gams-comment-prefix gams-comment-prefix-default)

;;; gams-insert-dollar-on
(defvar gams-insert-dollar-control-on nil
  "Non-nil means that typing $ is binded to inserting dollar control options.
If nil, typing $ is binded to inserting dollar itself.")
  
;; Key assignment.
(defvar gams-mode-map (make-keymap) "keymap for gams-mode")
(let ((map gams-mode-map))
  (define-key map "\C-ck" 'gams-insert-statement)
  (define-key map "\C-cd" 'gams-insert-dollar-control)
  (define-key map "\C-cv" 'gams-view-lst)
  (define-key map "\C-cj" 'gams-jump-to-lst)    
  (define-key map "\C-ct" 'gams-start-menu)
  (define-key map "\C-ce" 'gams-template)

  (define-key map "(" 'gams-insert-parens)
  (define-key map "\"" 'gams-insert-double-quotation)
  (define-key map "'" 'gams-insert-single-quotation)

  (define-key map "\C-l" 'gams-recenter)
  (define-key map "\C-co" 'gams-insert-comment)

  (define-key map "\C-cg" 'gams-jump-on-off-text)
  (define-key map "\C-cG" 'gams-remove-on-off-text)
  (define-key map "\C-cC" 'gams-comment-on-off-text)
  
  (define-key map "\C-cm" 'gams-view-docs)
  (define-key map "\C-cz" 'gams-modlib)  
  (define-key map "\t" 'gams-insert-tab)

  (define-key map "\C-cf" 'gams-choose-font-lock-level)

  (define-key map "\M-;" 'gams-comment-dwim)
  (define-key map [(control \;)] 'gams-comment-dwim-inline)
  )

;;; Menu for GAMS mode.
(easy-menu-define 
  gams-menu gams-mode-map "Menu keymap for GAMS mode."
  '("GAMS"
    ["Insert GAMS statement" gams-insert-statement t]
    ["Insert GAMS dollar control" gams-insert-dollar-control t]
    ["Insert parenthesis" gams-insert-parens t]
    ["Insert double quotations" gams-insert-double-quotation t]
    ["Insert single quotations" gams-insert-single-quotation t]
    ["Insert a comment template" gams-insert-comment t]
    "--"
    ["Switch to the LST file and show error" gams-view-lst t]
    ["Switch to the LST file" gams-jump-to-lst t]
    "--"
    ["Evoke the TEMPLATE mode" gams-template t]
    "--"
    ("Process"
     ["Start GAMS" (gams-start-menu nil ?s) t]
     ["Kill GAMS process" (gams-start-menu nil ?k) t]
     ["Process menu" (gams-start-menu) t]
     )
    "--"
    ["Choose font-lock level." gams-choose-font-lock-level t]
    ["Fontify block." font-lock-fontify-block t]
    "--"
    ["Recentering" gams-recenter t]
    ["Jump between ontext-offtext" gams-jump-on-off-text t]
    ["(Un)comment a ontext-offtext pair" gams-comment-on-off-text t]
    ["Remove a ontext-offtext pair" gams-remove-on-off-text t]
    ["Indent line" gams-indent-line t]
    ["Indent region" indent-region t]
    "--"
    ["View GAMS pdf manuals." gams-view-docs t]
    ["Extract a model from Model library." gams-modlib t]
    "--"
    ["Insert end-of-line comment." gams-comment-dwim t]
    ["Insert inline comment." gams-comment-dwim-inline t]
    ))

;;; 
(defun gams-mode ()
  "Major mode for editing GAMS program file.

The following commands are available in the GAMS mode:

\\[gams-insert-statement]		Insert GAMS statement with completion.
\\[gams-insert-dollar-control]		Insert GAMS dollar control option.
\\[gams-view-lst]		Switch to the LST file and show errors if exist.
\\[gams-jump-to-lst]		Switch to the LST file.
\\[gams-start-menu]		Run GAMS on a file you are editing or Kill GAMS process.
\\[gams-template]		Evoke the TEMPLATE mode.

\\[gams-insert-parens]		Insert parenthesis.
\\[gams-insert-double-quotation]		Insert double quotations.
\\[gams-insert-single-quotation]		Insert single quotations.

\\[gams-recenter]		Recenter.
\\[gams-insert-comment]		Insert comment template.
\\[gams-jump-on-off-text]		Jump between ontext and offtext.
\\[gams-comment-on-off-text]		(Un)comment a ontext-offtext pair.
\\[gams-remove-on-off-text]		Remove a ontext-offtext pair.
\\[gams-view-docs]		View GAMS pdf manuals.

\\[gams-comment-dwim]		Insert end-of-line comment.
\\[gams-comment-dwim-inline]		Insert inline comment."
  (interactive)
  (kill-all-local-variables)  
  (setq major-mode 'gams-mode)
  (setq mode-name "GAMS")
  (use-local-map gams-mode-map)
;  (setq paragraph-separate "\*/\*")
  (setq fill-prefix "\t\t")
;  (setq outline-regexp "\\*/\\*")
;  (outline-minor-mode 1)
;  (hide-other)
;  (auto-fill-mode 1)
  (mapcar
   'make-local-variable
   '(fill-column
     fill-prefix
     paragraph-start
     indent-line-function
     comment-start
     comment-start-skip
     comment-column
     font-lock-mark-block-function
     gams-comment-prefix
     gams-eolcom-symbol
     gams-inlinecom-symbol-start
     gams-inlinecom-symbol-end
     comment-indent-function
;     paragraph-separate
     ))
  ;; Variables.
  (setq fill-column gams-fill-column
	fill-prefix gams-fill-prefix
	paragraph-start gams-paragraph-start
	comment-indent-function 'gams-comment-indent-function
	comment-column gams-comment-column
	comment-end ""
	comment-start-skip (concat "^[" gams-comment-prefix "]+[ \t]*")
;;   paragraph-separate gams-paragraph-separate
   )
  ;; Behavior of $ key.
  (if gams-insert-dollar-control-on
      (define-key gams-mode-map "$" 'gams-insert-dollar-control))
  ;; Use automatic indentation?
  (when gams-indent-on
    (setq indent-line-function 'gams-indent-line)
    (define-key gams-mode-map "\t" 'gams-indent-line)
    (define-key gams-mode-map "\C-m" 'gams-newline-and-indent)
    (substitute-all-key-definition
     'newline-and-indent 'gams-newline-and-indent gams-mode-map))
  ;; Make `gams-comment-prefix' a buffer-local variable.
  (let (temp)
    (if (setq temp (gams-search-dollar-comment))
	(setq comment-prefix temp
	      gams-comment-prefix temp
	      comment-start temp
	      comment-start-skip (concat "^[" temp "]+[ \t]*"))
      (setq comment-prefix gams-comment-prefix-default
	    gams-comment-prefix gams-comment-prefix-default
	    comment-start-skip (concat "^[" gams-comment-prefix-default "]+[ \t]*")
	    comment-start gams-comment-prefix-default)))
  ;; Make `gams-eolcom-symbol' a buffer-local variable.
  (let (temp)
    (if (setq temp (gams-search-dollar-com t))
	(setq gams-eolcom-symbol temp)
      (setq gams-eolcom-symbol nil)))
  ;; Make `gams-inlinecom-symbol-start' and `gams-inlinecom-symbol-end'
  (let (temp)
    (if (setq temp (gams-search-dollar-com))
	(progn (setq gams-inlinecom-symbol-start (car temp))
	       (setq gams-inlinecom-symbol-end (cdr temp)))
      (setq gams-inlinecom-symbol-start nil)))
  ;; Create the alist of statements.  Is this necessary?  See
  ;; `gams-statement-update'.
  (setq gams-statement-alist
	(gams-statement-to-alist gams-statement-up gams-statement-upcase))
  ;; Create the alist of dollar control options.  Is this necessary?  See
  ;; `gams-statement-update'.
  (if gams-use-mpsge
      ;; Use mpsge.
      (progn (setq gams-dollar-control-alist
		   (gams-statement-to-alist
		    (append gams-dollar-control-up gams-statement-mpsge)
		    gams-dollar-control-upcase)))
    ;; Not use mpsge
    (setq gams-dollar-control-alist
	  (gams-statement-to-alist gams-dollar-control-up gams-dollar-control-upcase)))
  ;; Setting for font-lock.
  (make-local-variable 'font-lock-defaults)
  (gams-update-font-lock-keywords "g" gams-font-lock-level)
  (setq font-lock-defaults '(gams-font-lock-keywords t t))
  (setq font-lock-mark-block-function 'gams-font-lock-mark-block-function)
  ;; Local variables to store window configurations.
  (make-local-variable 'gams-temp-window)
  ;; Update statements and dollar control options.
  (gams-statement-update)
  ;; Setting for menu.
  (easy-menu-add gams-menu)
  ;; Run hook
  (run-hooks 'gams-mode-hook)
  ;; Turn on font-lock.
  (if (and (null (equal gams-font-lock-keywords nil))
	   font-lock-mode)
      (font-lock-fontify-buffer)
    (if (equal gams-font-lock-keywords nil)
	(font-lock-mode -1)))
  ) ;;; gams-mode ends.

(defun gams-statement-to-alist (list flag)
  "Transform a LIST to an alist.
IF FLAG is non-nil, use upper case."
    (let ((list-name list)
	  gams-alist)
      (if (null flag)
	  (setq list-name (gams-list-downcase list-name))
	nil)
      (while list-name
	(setq gams-alist (cons (list (car list-name)) gams-alist))
	(setq list-name (cdr list-name)))
      ;; Return the alist.
      gams-alist))

(defun gams-statement-update ()
  "Update gams-statement-alist and gams-dollar-control-alist."
  ;; Update `gams-statement-alist'.
  (setq gams-statement-alist
	(gams-statement-to-alist
	 (append gams-statement-up gams-user-statement-list) gams-statement-upcase))
  ;; Update `gams-dollar-control-alist'.
  (setq gams-dollar-control-alist
	(gams-statement-to-alist
	 ;; If you use MPSGE
	 (if gams-use-mpsge		
	     (append gams-dollar-control-up gams-statement-mpsge
		     gams-user-dollar-control-list)
	   (append gams-dollar-control-up gams-user-dollar-control-list))
	 gams-dollar-control-upcase)))

;;; From yatexlib.el

;;;###autoload
(defun gams-minibuffer-complete ()
  "Complete in minibuffer.
  If the symbol 'delim is bound and is string, its value is assumed to be
the character class of delimiters.  Completion will be performed on
the last field separated by those delimiters.
  If the symbol 'quick is bound and is 't, when the try-completion results
in t, exit minibuffer immediately."
  (interactive)
  (save-restriction
    (narrow-to-region
     (if (fboundp 'field-beginning) (field-beginning (point-max)) (point-min))
     (point-max))
    (let ((md (match-data)) beg word compl
	  (quick (and (boundp 'quick) (eq quick t)))
	  (displist ;function to display completion-list
	   (function
	    (lambda ()
	      (with-output-to-temp-buffer "*Completions*"
		(display-completion-list
		 (all-completions word minibuffer-completion-table)))))))
      (setq beg (if (and (boundp 'delim) (stringp delim))
		    (save-excursion
		      (skip-chars-backward (concat "^" delim))
		      (point))
		  (point-min))
	    word (gams*buffer-substring beg (point-max))
	    compl (try-completion word minibuffer-completion-table))
      (cond
       ((eq compl t)
	(if quick (exit-minibuffer)
	  (let ((p (point)) (max (point-max)))
	    (unwind-protect
		(progn
		  (goto-char max)
		  (insert " [Sole completion]")
		  (goto-char p)
		  (sit-for 1))
	      (delete-region max (point-max))
	      (goto-char p)))))
       ((eq compl nil)
	(ding)
	(save-excursion
	  (let (p)
	    (unwind-protect
		(progn
		  (goto-char (setq p (point-max)))
		  (insert " [No match]")
		  (goto-char p)
		  (sit-for 2))
	      (delete-region p (point-max))))))
       ((string= compl word)
	(funcall displist))
       (t (delete-region beg (point-max))
	  (insert compl)
	  (if quick
	      (if (eq (try-completion compl minibuffer-completion-table) t)
		  (exit-minibuffer)
		(funcall displist)))))
      (store-match-data md))))

;;; From yatex.el

(defvar gams-statement-completion-map nil
  "*Key map used at gams completion of statements in the minibuffer.")
(if gams-statement-completion-map nil
   (setq gams-statement-completion-map
	(copy-keymap (or (and (boundp 'gmhist-completion-map)
			      gmhist-completion-map)
			 minibuffer-local-completion-map)))
  (define-key gams-statement-completion-map
    " " 'gams-minibuffer-complete)
  (define-key gams-statement-completion-map
    "\C-i" 'gams-minibuffer-complete))

;;; ???
(defvar gams-read-statement-history nil "Holds history of statement.")
(put 'gams-read-statement-history 'no-default t)
(defun gams-read-statement (prompt &optional predicate initial)
  "Read a GAMS statements with completion."
;  (YaTeX-sync-local-table 'tmp-section-table)
  (let ((minibuffer-completion-table
	 (append gams-alist)))
;	 (append tmp-section-table user-section-table section-table)))
    (read-from-minibuffer
     prompt initial gams-statement-completion-map nil
     'gams-read-statement-history)))

(defun gams-register (name &optional flag)
  "Register a new statement or dollar-control.

NAME is the name of a new statement or dollar-control registered.  If FLAG is
non-nil, it is a dollar-control."
  (interactive)
  (let* ((curr-buff (current-buffer))
	 (temp-buff " *gams-register*")
	 (temp-file gams-statement-file)
	 (temp-list (if flag
			gams-user-dollar-control-list
		      gams-user-statement-list))
	 (old-list temp-list)
	 (list-name
	  (if flag
	      "gams-user-dollar-control-list"
	    "gams-user-statement-list"))
	 new-list)
    (save-excursion
      ;; Make a new list.
      (setq new-list (append (list name) temp-list))
      ;; Switch to the temporary buffer.
      (get-buffer-create temp-buff)
      (set-buffer temp-buff)
      (erase-buffer)
      ;; Write the content of the list.
      (gams-stat-write-list new-list flag)
      ;; Check whether the variable is defined correctly.
      (eval-buffer)
      ;; Store the content of buffer
      (setq temp-cont (gams*buffer-substring (point-min) (point-max)))
      ;; Delete the list-name part.
      (set-buffer (find-file-noselect temp-file))
      (goto-char (point-min))
      ;; Check whether the list-name part exists or not.
      (if (null (re-search-forward
		 (concat
		  "\\(setq\\) " list-name)
		 nil t))
	  ;; If it doesn't exists, do nothing.
	  nil
	;; If it exists, delete it.
	(let (point-beg point-en)
	  (goto-char (match-beginning 1))
	  (beginning-of-line)
	  (setq point-beg (point))
	  (forward-sexp 1)
	  (forward-line 1)
	  (setq point-en (point))
	  (delete-region point-beg point-en)))
      ;; Insert the content.
      (goto-char (point-min))
      (insert temp-cont)
      ;;
      (eval-buffer)
      ;; Save buffer of gams-statement-file.
      (save-buffer (get-file-buffer temp-file))
      (kill-buffer (get-file-buffer temp-file))
      ;; kill the temporary buffer.
      (kill-buffer temp-buff)
      ;; Replace the old list with the new list.
      (setq old-list new-list)
      (gams-statement-update)
;;      (gams-regexp-update)
      (set-buffer curr-buff)
      )))

(defun gams-stat-write-list (list &optional flag)
  "Write the content of LIST in a buffer.
If FLAG is non-nil, the list of dollar control."
  (let ((list-name (if flag
		       "gams-user-dollar-control-list"
		     "gams-user-statement-list")))
    (erase-buffer)
    (insert-string (concat "(setq " list-name " '(\n"))
    (goto-char (point-max))
    ;; Repeat.
    (while list
      (insert (concat "\"" (car list) "\"\n"))
      (goto-char (point-max))
      (setq list (cdr list)))
    ;; Last.
    (insert "))\n")))

(defun gams-insert-statement (&optional cmd)
  "Insert GAMS statement with completion.
List of candidates is created from elements of `gams-statement-up'
and `gams-user-statement-list'."
  (interactive)
  (gams-statement-update)
  (unwind-protect
      (let*
	  ((gams-alist gams-statement-alist)
	   (completion-ignore-case t)
	   key1
	   (source-window (selected-window))
	   guess
	   (statement
	    (or cmd
		(progn
		  (setq guess
			(if gams-statement-upcase
			    (upcase gams-statement-name)
			  (downcase gams-statement-name)))
		  (gams-read-statement
		   (if gams-simple-messages
		       (format "Statement (default %s): " guess)
		     (if (> (minibuffer-depth) 0)
			 (format "(default %s)%s: "
				 guess
				 (format "[level:%d]" (minibuffer-depth)))
		       (format "Insert statement (default = %s): " guess)))
		   nil))))
	   (statement (if (string= statement "") guess statement))
	   );;let

	(if gams-statement-upcase
	    (setq statement (upcase statement))
	  (setq statement (downcase statement)))
	(setq gams-statement-name statement)
	;; Register or not?
	(if (null (member (list statement) gams-statement-alist))
	    (progn
	      (message "Store `%s' for future use?  Type `y' if yes: " statement)
	      (setq key1 (read-char))
	      (if (equal key1 ?y)
		  (progn
		    (setq statement (upcase statement))
		    (gams-register statement))
		nil))
	  nil)
	;; Insert.
	(if gams-statement-upcase
	    (setq statement (upcase statement))
	  (setq statement (downcase statement)))
	(insert-string statement))
    (if (<= (minibuffer-depth) 0) (use-global-map global-map))
    (insert "")))	;insert dummy string to fontify(Emacs20)

(defvar gams-dollar-completion-map nil
  "*Key map used at gams completion of dollar operation in the minibuffer.")
(if gams-dollar-completion-map nil
   (setq gams-dollar-completion-map
	(copy-keymap (or (and (boundp 'gmhist-completion-map)
			      gmhist-completion-map)
			 minibuffer-local-completion-map)))
  (define-key gams-dollar-completion-map
    " " 'gams-minibuffer-complete)
  (define-key gams-dollar-completion-map
    "\C-i" 'gams-minibuffer-complete)
  (define-key gams-dollar-completion-map
    "$" 'gams-minibuffer-insert-dollar)
  (define-key gams-dollar-completion-map
    "@" 'gams-minibuffer-insert-dollar))

(defvar gams-flag-dollar nil)
(defun gams-minibuffer-insert-dollar ()
  "???"
  (interactive)
  (setq gams-flag-dollar t)
  (exit-minibuffer))

(defvar gams-read-dollar-history nil "Holds history of dollar control.")
(put 'gams-read-dollar-history 'no-default t)
(defun gams-read-dollar-control (prompt &optional predicate initial)
  "Read a GAMS dollar control operation with completion."
  (let ((minibuffer-completion-table
	 (append gams-alist)))
    (read-from-minibuffer
     prompt initial gams-dollar-completion-map nil
     'gams-read-dollar-history)))

(defun gams-insert-dollar-control (&optional cmd)
  "Insert GAMS dollar control option with completion.
List of candidates is created from elements of `gams-dollar-control-up'
and `gams-user-dollar-control-list' (and `gams-statement-mpsge'
if `gams-use-mpsge' is non-nil)."
  (interactive)
  (gams-statement-update)
  ;; Need to modify this.
  (setq gams-flag-dollar nil)
  (unwind-protect
      (let*
	  ((gams-alist gams-dollar-control-alist)
	   (completion-ignore-case t)
	   key1
	   (source-window (selected-window))
	   guess
	   (statement
	    (or cmd
		(progn

		  (setq guess
			(if gams-dollar-control-upcase
			    (upcase gams-dollar-control-name)
			  (downcase gams-dollar-control-name)))

		  (gams-read-dollar-control
		   (if gams-simple-messages
		       (format "Dollar control (default $%s): " guess)
		     (if (> (minibuffer-depth) 0)
			 (format "(default %s)%s: "
				 guess
				 (format "[level:%d]" (minibuffer-depth)))
		       (if gams-insert-dollar-control-on
			   (format "Insert dollar control ($ or @ = $, default = $%s): $" guess)
			 (format "Insert dollar control (default = $%s): $" guess))
		       ))
		   nil))))
	   (statement (if (string= statement "") guess statement))
	   (statement (if gams-flag-dollar "" statement))
	   );;let
	
	;;
	(if (null (equal statement ""))
	    (setq gams-dollar-control-name statement))
	;;
	(if gams-dollar-control-upcase
	    (setq statement (upcase statement))
	  (setq statement (downcase statement)))
	;; Register or not?
	(if (null (or (member (list statement) gams-dollar-control-alist)
		      (equal statement "")))
	    (progn
	      (message "Store `%s' for future use?  Type `y' if yes: " statement)
	      (setq key1 (read-char))
	      (if (equal key1 ?y)
		  (progn (setq statement (upcase statement))
			 (gams-register statement t))
		nil))
	  nil)
	;; Insert.
	(if gams-dollar-control-upcase
	    (setq statement (upcase statement))
	  (setq statement (downcase statement)))
	(insert-string (concat "$" statement)))
    (if (<= (minibuffer-depth) 0) (use-global-map global-map))
    (insert "")))	;insert dummy string to fontify(Emacs20)

(defun gams-get-lst-filename ()
"Return the LST file name corresponding to the current GMS file buffer."
  (let ((file-buffer-gms (buffer-file-name))
	(ext-up (concat "." (upcase gams-lst-extention)))
	(ext-down (concat "." (downcase gams-lst-extention)))
	dir-gms	file-noext file-lst file-gms)
    ;; Store the GMS file name.
    (setq dir-gms (file-name-directory file-buffer-gms))
    (setq file-gms (file-name-nondirectory file-buffer-gms))
    (setq file-noext (file-name-sans-extension file-gms))
    ;; Search the LST file name
    (cond
     ((file-exists-p
       (concat dir-gms (upcase file-noext) ext-up))
      (setq file-lst (concat dir-gms (upcase file-noext) ext-up)))
     ((file-exists-p
       (concat dir-gms file-noext ext-down))
      (setq file-lst (concat dir-gms file-noext ext-down)))
     ((file-exists-p
       (concat dir-gms file-noext ext-up))
      (setq file-lst (concat dir-gms file-noext ext-up)))
     ((file-exists-p
       (concat dir-gms (upcase file-noext) ext-down))
      (setq file-lst (concat dir-gms (upcase file-noext) ext-down)))
     ((file-exists-p
       (concat dir-gms (downcase file-noext) ext-down))
      (setq file-lst (concat dir-gms (downcase file-noext) ext-down)))
     ((file-exists-p
       (concat dir-gms (downcase file-noext) ext-up))
      (setq file-lst (concat dir-gms (downcase file-noext) ext-up)))
     (t
      (message "LST file does not exist!")))
    ;; Return the name.
    file-lst))

(defun gams-view-lst ()
  "Switch to the LST file buffer and show the error message if any."
  (interactive)
  (let ((file-lst (gams-get-lst-filename)))
    ;;
    (if file-lst
	;; If the LST file exists.
	(progn
	 (let ((lst-buffer))
	   (if (get-file-buffer file-lst)
	       ;; If file-lst is already opened.
	       (progn
		 (set-buffer (get-file-buffer file-lst))
		 (if (verify-visited-file-modtime (current-buffer))
		     ;; If lst file is not changed
		     (progn
		       (switch-to-buffer (current-buffer))
		       ;; View error.
		       (gams-lst-view-error))
		   
		   ;; If lst file is chenged, kill-buffer.
		   (set-buffer-modified-p nil)
		   (kill-buffer (get-file-buffer file-lst))
		   (find-file file-lst)
		   (goto-char (point-min))
		   (gams-lst-mode)
		   (gams-lst-view-error)))
	     ;; if file-lst isn't opened.
	     (find-file file-lst)
	     (goto-char (point-min))
	     (gams-lst-mode)
	     (gams-lst-view-error))))
      ;; If the LST file not exits. 
      (message "The LST file does not exist!"))))

(defun gams-jump-to-lst ()
  "Switch to the LST file buffer."
  (interactive)
  (let ((file-lst (gams-get-lst-filename)))
    (if file-lst
	;; If lst file exists
	(progn
	  (let ((lst-buffer))
	    ;; lst file is already opened?
	    (if (get-file-buffer file-lst)
		;; If file-lst is already opened.

		;; lst file is modified?
		(if (verify-visited-file-modtime
		     (get-file-buffer file-lst))
		    ;; If not modified.
		    (pop-to-buffer (get-file-buffer file-lst))
		  ;; If modified.
		  (set-buffer-modified-p nil)
		  (kill-buffer (get-file-buffer file-lst))
		  (find-file find-file)
		  (gams-lst-mode))
	      ;; If file-lst isn't opened, open it.
	      (find-file file-lst)
	      (gams-lst-mode)))
	  (recenter))
      ;; LST file does not exits.
      (message "The LST file does not exist!"))))

;;; Comment insertion.
(defun gams-insert-comment ()
  "Insert a comment template defined by `gams-user-comment'."
  (interactive)
  (let ((point-a (point))
	(use-comment gams-user-comment)
	point-b point-c)
    (insert-string gams-user-comment)
    (setq point-b (point))
    (goto-char point-a)
    (if (re-search-forward "%" point-b t)
	(progn (setq point-c (match-beginning 0))
	       (replace-match ""))
      (goto-char point-b))))

;;; From yatex.el
(defun gams-insert-parens (arg)
  "Insert parenthesis pair."
  (interactive "p")
  (if gams-close-paren-always
      (progn (insert "()")
	     (backward-char 1))
    (insert "(")))

(defun gams-insert-double-quotation (arg)
  "Insert double quotation pair."
  (interactive "p")
  (if gams-close-double-quotation-always
      (progn (insert "\"\"")
	     (backward-char 1))
    (insert "\"")))

(defun gams-insert-single-quotation (arg)
  "Insert single quotation pair."
  (interactive "p")
  (if gams-close-single-quotation-always
      (progn (insert "''")
	     (backward-char 1))
    (insert "'")))

;;;;; fill-paragraph.

;;; Fill paragraph function.  This is from "lisp-mode.el"
;;; (`lisp-fill-paragraph').  I changed ";" in the original function to
;;; "\\(*\\)".  This function is likely not to work well in many cases.

(defun gams-fill-paragraph (&optional justify)
  "Like \\[fill-paragraph], but handle GAMS comment.
If any of the current line is a comment, fill the comment or the
paragraph of it that point is in, preserving the comment's indentation
and initial *."
  (interactive "P")
  (let (
	;; Non-nil if the current line contains a comment.
	has-comment
	;; Non-nil if the current line contains code and a comment.
	has-code-and-comment
	;; If has-comment, the appropriate fill-prefix for the comment.
	comment-fill-prefix
	)

    ;; Figure out what kind of comment we are looking at.
    (save-excursion
      (beginning-of-line)
      (cond
       ;; A line with nothing but a comment on it?
       ((looking-at (concat "^\\([" gams-comment-prefix "]\\)[" gams-comment-prefix " \t]*"))
	(setq has-comment t
	      comment-fill-prefix (gams*buffer-substring (match-beginning 0)
						    (match-end 0))))
       ))
    (if (not has-comment)
        ;; `paragraph-start' is set here (not in the buffer-local
        ;; variable so that `forward-paragraph' et al work as
        ;; expected) so that filling (doc) strings works sensibly.
        ;; Adding the opening paren to avoid the following sexp being
        ;; filled means that sexps generally aren't filled as normal
        ;; text, which is probably sensible.  The `;' and `:' stop the
        ;; filled para at following comment lines and keywords
        ;; (typically in `defcustom').
	(let ((paragraph-start (concat paragraph-start "")))
          (fill-paragraph justify))
      ;; Narrow to include only the comment, and then fill the region.
      (save-excursion
	(save-restriction
	  (beginning-of-line)
	  (narrow-to-region
	   ;; Find the first line we should include in the region to fill.
	   (save-excursion
	     (while (and (zerop (forward-line -1))
			 (looking-at (concat "^\\([" gams-comment-prefix "]\\)"))))
	     ;; We may have gone too far.  Go forward again.
	     (or (looking-at (concat "^\\([" gams-comment-prefix "]\\)"))
		 (forward-line 1))
	     (point))
	   ;; Find the beginning of the first line past the region to fill.
	   (save-excursion
	     (while (progn (forward-line 1)
			   (looking-at (concat "^\\([" gams-comment-prefix "]\\)"))))
	     (point)))
	  ;; Lines with only * on them can be paragraph boundaries.
	  (let* ((paragraph-start (concat paragraph-start "\\|^\\([" gams-comment-prefix "]\\)$"))
		 (paragraph-separate (concat paragraph-start "\\|^\\([" gams-comment-prefix "]\\)$"))
		 (paragraph-ignore-fill-prefix nil)
		 (fill-prefix comment-fill-prefix)
		 (after-line (if has-code-and-comment
				 (save-excursion
				   (forward-line 1) (point))))
		 (end (progn
			(forward-paragraph)
			(or (bolp) (newline 1))
			(point)))
		 ;; If this comment starts on a line with code,
		 ;; include that like in the filling.
		 (beg (progn (backward-paragraph)
			     (if (eq (point) after-line)
				 (forward-line -1))
			     (point))))
	    (fill-region-as-paragraph beg end
				      justify nil
				      (save-excursion
					(goto-char beg)
					(if (looking-at fill-prefix)
					    nil
					  (re-search-forward comment-start-skip)
					  (point))))))))
    t))


;;; Process handling.

;;; Most of the codes for process handling are from epo.el ,epolib.el,
;;; epop.el in the `EPO' package written by Yuuji Hirose.  I modified
;;; them.

;;; From epolib.el
(defun gams*window-list ()
  (let*((curw (selected-window)) (win curw) (wlist (list curw)))
    (while (not (eq curw (setq win (next-window win))))
      (or (eq win (minibuffer-window))
	  (setq wlist (cons win wlist))))
    wlist))

(defun gams*smart-split-window (height)
  "Split current window wight specified HEIGHT.
If HEIGHT is number, make a new window that has HEIGHT lines.
If HEIGHT is string, make a new window that occupies HEIGT % of screen height.
Otherwise split window conventionally."
  (if (one-window-p t)
      (split-window
       (selected-window)
       (max
        (min
         (- (gams*screen-height)
            (if (numberp height)
                (+ height 2)
              (/ (* (gams*screen-height)
                    (string-to-int height))
                 100)))
         (- (gams*screen-height) window-min-height 1))
        window-min-height))))

(defun gams*showup-buffer (buffer &optional select)
  "Make BUFFER show up in certain window (except selected window).
Non-nil for optional argument SELECT keeps selection to the target window."
  (let (w)
    (or
     ;;if already visible
     (if gams:frame-feature-p
	 (if (setq w (get-buffer-window buffer t))
	     (if select
		 (progn
		   (raise-frame (select-frame (window-frame w)))
		   (set-mouse-position (selected-frame) 0 -1))
	       w))
       ;;no frames
       (if (setq w (get-buffer-window buffer))
	   (if select (select-window w) w)))
     ;;not visible
     (let ((sw (selected-window))
	   (wlist (gams*window-list)))
       (cond
	((eq (current-buffer) (get-buffer buffer)) nil)
	((one-window-p)
	 (gams*smart-split-window gams-default-pop-window-height)
	 (select-window (next-window nil 1))
	 (switch-to-buffer (get-buffer-create buffer)))
	((= (length wlist) 2)
	 (select-window (get-lru-window))
	 (switch-to-buffer (get-buffer-create buffer)))
	(t   ;more than 2windows
	 (select-window (next-window nil 1))
	 (switch-to-buffer (get-buffer-create buffer))))
       (or select (select-window sw))))))


;;; From epop.el
(defun gams*process-sentinel (proc mess)
  "Display the end of process buffer."
  (cond
   ((memq (process-status proc) '(signal exit))
    (save-excursion
      (let ((sw (selected-window)) w)
	(set-buffer (process-buffer proc))
	(goto-char (point-max))
	(insert
	 (format "\nGAMS process finished at %s\n" (current-time-string)))
	(cond
	 ((and gams:frame-feature-p
	       (setq w (get-buffer-window (current-buffer) t)))
	  (select-frame (window-frame w))
	  (select-window w)
	  (goto-char (point-max))
	  (recenter -1))
	 ((setq w (get-buffer-window (current-buffer)))
	  (select-window w)
	  (goto-char (point-max))
	  (recenter -1)))
	(select-window sw))
      (message "GAMS process has finished.  Type `C-cv' if you want to view a LST file.")))))

(defun gams*start-process-other-window (name commandline)
  "Start command line (via shell) in the next window."
  (let ((sw (selected-window)) p
	(dir default-directory)
	pbuff-name)
    (setq pbuff-name (gams-get-process-buffer))
      
    (gams*showup-buffer pbuff-name t) ;popup buffer and select it.
    (message "Starting GAMS process...")
    (kill-all-local-variables)
    (erase-buffer)
    (cd dir)
    (setq default-directory dir)
    (insert commandline "\n ")
    (set (make-local-variable 'gams:process-command-name) name)
    (set-process-sentinel
     (setq p (start-process
	      name
	      pbuff-name
	      shell-file-name
	      gams:shell-c commandline))
     'gams*process-sentinel)
    (set-marker (process-mark p) (1- (point)))
    (setq major-mode 'gams-process-mode)
;    (use-local-map gams-process-mode-map)
    (select-window sw)))

(defun gams*get-builtin (keyword)
  "Get built-in string specified by KEYWORD in current buffer."
  (save-excursion
    (save-restriction
      (widen)
      (goto-char (point-min))
      (if (search-forward
	   (concat
	    comment-start	   ;buffer local variable in any buffer
	    keyword) nil t)
	  (let ((peol (progn (end-of-line) (point))))
	    (gams*buffer-substring
	     (progn
	       (goto-char (match-end 0))
	       (skip-chars-forward " \t")
	       (point))
	     (if (and comment-end
		      (stringp comment-end)
		      (string< "" comment-end)
		      (re-search-forward
		       (concat (regexp-quote comment-end)
			       "\\|$")
		       peol 1))
		 (match-beginning 0)
	       peol)))))))

(defun gams*update-builtin (keyword newdef)
  "Update built-in KEYWORD to NEWDEF"
  (save-excursion
    (save-restriction
      (widen)
      (goto-char (point-min))
      (if (search-forward (concat comment-start keyword) nil t)
	  (let ((peol (progn (end-of-line) (point))))
	    (goto-char (match-end 0))
	    (skip-chars-forward " \t")
	    (delete-region
	     (point)
	     (if (and comment-end (stringp comment-end)
		      (string< "" comment-end)
		      (search-forward comment-end peol t))
		 (progn (goto-char (match-beginning 0)) (point))
	       peol))
	    (insert newdef))
	(while (and (progn (skip-chars-forward " \t")
			   (looking-at (regexp-quote comment-start)))
		    (not (eobp)))
	  (forward-line 1))
	(open-line 1)
	(insert comment-start keyword newdef comment-end)))))

(defun gams-get-program-filename (&optional nodir noext)
  ""
  (cond
   ((and nodir (null noext)
    (file-name-nondirectory (buffer-file-name (current-buffer)))))
   ((and (null nodir) noext)
    (file-name-sans-extension (buffer-file-name (current-buffer))))
   ((and nodir noext)
    (file-name-nondirectory
     (file-name-sans-extension (buffer-file-name (current-buffer)))))
   (t
    (buffer-file-name (current-buffer)))
    ))

(defun gams-get-process-buffer ()
  ""
  (let ((flag-a gams-multi-process)
	pro-buf-name)
    (if flag-a
	;; Multi-process.
	(get-buffer-create
	 (concat gams*command-process-buffer " on "
		 (gams-get-program-filename t) "*"))
      ;; Not multi-process.
      (get-buffer-create (concat gams*command-process-buffer "*"))
      )))

(defun gams*start-processor (&optional ask)
  "Start GAMS on the current file."
  (let* (prompt
	(builtin "#!")
	(command "compile")
	arg string newarg)
    (setq arg
	  (or
	   ;; if built-in processor specified, use it
	   (and builtin (gams*get-builtin builtin))
	   (concat gams:process-command-name " "
		   (file-name-nondirectory buffer-file-name) " "
		   (gams-opt-return-option))))
    (basic-save-buffer)
    ;(setq arg (concat command " " arg))
    (gams*start-process-other-window
     command
     (cond
      (prompt
       (read-string "Execute: " arg))
      (ask
       (setq newarg (read-string "Edit command if you want:  " arg))
       (if (and builtin
		(not (string= newarg arg))
		(y-or-n-p "Use this command line also in the future? "))
	   (progn
	     (gams*update-builtin builtin newarg)
	     (message "The command line is inserted in the fisrt line in this file!")))
	 newarg)
      (t arg)))))

(defun gams*kill-processor ()
  "Stop (kill) a GAMS process."
  (let ((p (get-buffer-process (gams-get-process-buffer))))
    (if p
	(interrupt-process p)
      (message "GAMS process has already exited."))))


(defun gams-start-menu (&optional ask char)
  "Process starting menu.
Optional second argument CHAR is for non-interactive call from menu."
  (interactive "P")
  (message (format "Start GAMS (%c), Kill GAMS process (%c), Change options (%c)."
		   gams-run-key gams-kill-key gams-option-key))
  (let ((c (or char (read-char))))
    (cond ((equal c gams-run-key)
	   (gams*start-processor ask))
	  ((equal c gams-kill-key)
	   (gams*kill-processor))
	  ((equal c gams-option-key)
	   (gams-option))
	  (t (message "No such choice `%c'" c)))))

(defun gams-recenter ()
  "Recentering."
  (interactive)
  (if (and gams-recenter-font-lock font-lock-mode)
      (cond
       (gams-emacs-21
	(font-lock-mode -1)
	(font-lock-mode 1))
       (gams-emacs-20
	(font-lock-mode -1)
	(font-lock-mode 1))
       ))
  (recenter))

  
;;; View manuals.

(defvar gams-read-docs-history nil "Holds history of dollar control.")
(put 'gams-read-dollar-history 'no-default t)

(defvar gams-read-doc-completion-map nil
  "*Key map for gams-read-docs.")
(if gams-read-doc-completion-map nil
   (setq gams-read-doc-completion-map
	 (copy-keymap minibuffer-local-completion-map))
   (define-key gams-read-doc-completion-map
     " " 'gams-minibuffer-complete)
   (define-key gams-read-doc-completion-map
     "\C-i" 'gams-minibuffer-complete))

(defun gams-read-docs (prompt &optional predicate initial)
  "Read a GAMS dollar control operation with completion."
  (let ((minibuffer-completion-table
	 (append gams-manuals-alist)))
    (read-from-minibuffer
     prompt initial gams-read-doc-completion-map nil
     'gams-read-docs-history)))

(defun gams-view-docs ()
  "View GAMS manuals.

Envoke the pdf file viewer and see GAMS manuals."
  (interactive)
  (unwind-protect
      (let*
	  ((gams-alist gams-manuals-alist)
	   (completion-ignore-case t)
	   key1
	   (source-window (selected-window))
	   guess
	   (statement
	    (progn
	      (setq guess "User-Manual")
	      (gams-read-docs
	       (format "View which manual? (default = %s): " guess))))
	   (statement (if (string= statement "") guess statement))
	   (statement (if gams-flag-dollar "" statement))
	   ;; directory name.
	   (dir-name
	    (if (string-match "/" gams-docs-dir (string-width gams-docs-dir))
		(substring gams-docs-dir 1 (- (string-width gams-docs-dir)))
	      gams-docs-dir))
	   file-name
	   dir-docs
	   (prog-name gams-docs-view-program)
	   (buf (get-buffer-create "*View GAMS manual*"))
	   proc
	   );;let* ends.
	(if (string-match "Solver" statement)
	    (setq dir-docs "/solvers/")
	  (setq dir-docs "/gams/"))
	(setq file-name (concat dir-name dir-docs
				(cdr (assoc statement gams-manuals-alist))
				".pdf"))
	;; Start process.
	(setq proc (start-process "manual" buf prog-name file-name " &"))
	(message "Starting the pdf file viewer...")
	)))


;;;;; Commands for ontext-offtext pair.

;;; Jump between ontext and offtext.
(defun gams-judge-on-off-text ()
  "Judge whether curson is on ontext or offtext.

ontext => return on and point,
offtext => return off and point,
Otherwise => return nil and nil.

If ontext and offtext are commented out, return *on and *off respectively."
  
  (let (point-beg temp-text)
    (save-excursion
      (beginning-of-line)
;;      (skip-chars-backward "^ \t\n")
      (when (looking-at (concat "^\\([" gams-comment-prefix "]?\\)[ \t]*[$]\\(on\\|off\\)text"))
	(setq point-beg (match-beginning 0))
	(setq temp-text
	      (downcase (gams*buffer-substring (match-beginning 2)
					  (match-end 2))))
	(if (string-match gams-comment-prefix (gams*buffer-substring (match-beginning 1)
						  (match-end 1)))
	    (setq temp-text (concat "*" temp-text)))))
    (cons temp-text point-beg)))

(defun gams-search-on-off-text (cons)
  ""
  (let ((type (car cons))
	(point (cdr cons))
	(regexp (concat "^[" gams-comment-prefix "]?[ \t]*$\\(on\\|off\\)text"))
	flag match match-point)
    (save-excursion
      (cond
       ((equal type "on")
	(forward-char 1)
	(when (re-search-forward regexp nil t)
	  (setq match-point (match-beginning 0))
	  (setq match (gams*buffer-substring (match-beginning 1)
					(match-end 1)))))
       ((equal type "*on")
	(forward-char 1)
	(when (re-search-forward regexp nil t)
	  (setq match-point (match-beginning 0))
	  (setq match (concat "*" (gams*buffer-substring (match-beginning 1)
						    (match-end 1))))))
       ((equal type "off")
	(forward-char -1)
	(when (re-search-backward regexp nil t)
	  (setq match-point (match-beginning 0))
	  (setq match (gams*buffer-substring (match-beginning 1)
					(match-end 1)))))
       ((equal type "*off")
	(forward-char -1)
	(when (re-search-backward regexp nil t)
	  (setq match-point (match-beginning 0))
	  (setq match (concat "*" (gams*buffer-substring (match-beginning 1)
						    (match-end 1))))))))
    (cons match match-point)))

(defun gams-jump-on-off-text ()
  "Jump between ontext-offtext.

If you execute this command on ontext (offtext), then you jump to the
corresponding offtext (ontext)."
  (interactive)
  (let* ((temp (gams-judge-on-off-text))
	 (flag (car temp))
	 (point (cdr temp))
	 (cur-po (point))
	 (case-fold-search t)
	 match-flag match-point)
    (when flag
      (setq match-flag (car (gams-search-on-off-text temp)))
      (setq match-point (cdr (gams-search-on-off-text temp))))
  ;; ontext or offtext.
  (cond
   ;;
   ((null flag)
    (message "This command is valid only if the cursor is on either ontext or offtext."))
   ;;
   ((and point match-point
	 (null (equal flag match-flag)))
    (goto-char match-point)
    (if (equal flag "on")
	(message "The corresponding offtext is found!")
      (message "The corresponding ontext is found!")))
   ;;
   ((and point (or (null match-point)
		   (equal flag match-flag)))
    (if (equal flag "on")
	(message "No corresponding offtext exists!")
	    (message "No corresponding ontext exists!")))
    )))

(defun gams-remove-on-off-text ()
  "Remove the pair of ontext-offtext.

If you evoke this command on ontext (offtext), then both ontext
(offtext) and the corresponding offtext (ontext) are removed."
  (interactive)
  (gams-modify-on-off-text t))


(defun gams-comment-on-off-text ()
  "Comment or uncomment the pair of ontext-offtext."
  (interactive)
  (gams-modify-on-off-text))

(defun gams-modify-on-off-text (&optional delete)
  "Modify the ontext-offtext pair.  If DELETE is non-nil, delte the pair.
Otherwise, comment out or uncomment out the pair."
  (save-excursion
    (let* ((temp (gams-judge-on-off-text))
	   (flag-beg (car temp))
	   (po-beg (cdr temp))
	   flag-com)
      (if (null flag-beg)
	  ;; if 
	  (message "This command is valid only if the cursor is on either ontext or offtext.")
	(let* ((temp-end (gams-search-on-off-text (cons flag-beg po-beg)))
	       (beg-end (car temp-end))
	       (po-end (cdr temp-end)))
	  (if (null beg-end)
	      (cond
	       ((or (equal flag-beg "on")
		    (equal flag-beg "*on"))
		(message "No corresponding offtext is found!"))
	       ((or (equal flag-beg "off")
		    (equal flag-beg "*off"))
		(message (format "No corresponding ontext is found!"))))
	    ;; Found.

	    (when (string-match "[*]" flag-beg)
	      (setq flag-com t))
	    
	    ;; If DELETE is non-nil.
	    (if delete
		(progn
		  (if flag-com
		      (message "Can't delete commented ontext-offtext!  First uncoment them.")
		    (message "Delete the pair of ontext-offtext.")
		    (goto-char po-end)
		    (beginning-of-line)
		    (sit-for 1)
		    (delete-region (point)
				   (progn
				     (looking-at "^$\\(on\\|off\\)text")
				     (match-end 0)))
		    (goto-char po-beg)
		    (beginning-of-line)
		    (delete-region (point)
				   (progn
				     (looking-at "^$\\(on\\|off\\)text")
				     (match-end 0)))))
	      ;; Comment or uncomment.
	      (if flag-com
		  ;; Commented ontext offtext.
		  (progn
		    (message "Uncomment the pair of ontext-offtext.")
		    (goto-char po-end)
		    (beginning-of-line)
		    (sit-for 1)
		    (delete-region (point)
				   (progn
				     (looking-at (concat "^[" gams-comment-prefix "][ \t]*"))
				     (match-end 0)))
		    (goto-char po-beg)
		    (beginning-of-line)
		    (delete-region (point)
				   (progn
				     (looking-at (concat "^[" gams-comment-prefix "][ \t]*"))
				     (match-end 0))))
		;; Uncommented ontext-offtext.
		(progn
		  (message "Comment out a pair of ontext-offtext.")
		  (goto-char po-end)
		  (beginning-of-line)
		  (sit-for 1)
		  (insert (concat gams-comment-prefix " "))
		  (goto-char po-beg)
		  (if (> po-beg po-end)
		      (forward-char 2))
		  (beginning-of-line)
		  (insert (concat gams-comment-prefix " ")))))))))))

(defun gams-search-dollar-comment ()
  "Search comment dollar control.
If it is found, return point and matched content."
  (let (match)
    (save-excursion
      (goto-char (point-min))
      (when (re-search-forward "^\\([$]\\)comment[ \t]+\\([^ \t\n]+\\)" nil t)
	(setq match
	      (cons (match-beginning 1)
		    (gams*buffer-substring (match-beginning 2)
				      (match-end 2))))))
    match))

;;;;;;;;;;;;;;;;;
; GAMS modlib.
;;;;;;;;;;;;;;;;;

(defun gams-modlib ()
  "Extract a model from GAMS model library."
  (interactive)
  (let* ((buf "*modlib*")
	 (list-name (directory-files (concat gams-system-directory "modlib") nil ".*[.][0-9]+"))
	 (prog-name (concat gams-system-directory "gamslib"))
	 alist ele)
    (while list-name
      (setq ele (car list-name))
      (setq ele (substring ele 0 (string-match "[.]" ele)))
      (setq alist (cons (list ele) alist))
      (setq list-name (cdr list-name)))
    (setq alist (cons (list "all") alist))
    (setq name (completing-read
		"Input a model name (type \"all\" if you want to extract all models): "
		alist))
    (setq dir (read-file-name
	       "Extract the model to which directory?: "
	       nil default-directory))
    (if (file-directory-p dir)
	(if (null (equal "all" name))
	    (gams-modlib-extract name dir)
	  (while alist
	    (setq name (car (car alist)))
	    (gams-modlib-extract name dir)
	    (setq alist (cdr alist))
	    (message "Extracting all models...  It will take much time.")))
      (message "Input directory name!"))))

(defun gams-modlib-extract (name dir)
  "Extract model library NAME to the directory DIR."
  (let ((cur-dir default-directory)
	(pr-name (concat gams-system-directory "gamslib")))
    (setq default-directory (file-name-as-directory dir))
    (call-process pr-name nil nil nil name)
    (setq default-directory cur-dir)
    (message (format "Extracting %s to %s" name dir))
    ))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Codes for chaging command line options.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defvar gams-user-option-alist nil
  "The list of combinations of options defined by users.")

(defvar gams-user-option-alist-initial nil)
(setq gams-user-option-alist-initial gams-user-option-alist)
      
(defvar gams-option-alist nil
  "The list of combinations of options in which
`gams:process-command-option' and `gams-user-option-alist' are combined.")

(defun gams-opt-make-alist ()
  "Combine `gams:process-command-option' and `gams-user-option-alist'."
  (setq gams-option-alist
	(append
	 (list (cons "default" gams:process-command-option))
	 (reverse gams-user-option-alist))))

;;; initialize.
(gams-opt-make-alist)
(setq gams-current-option-num "default")

(defun gams-opt-view ()
  "Display the content of `gams-option-alist' in a buffer."
  (interactive)
  (let ((temp-alist gams-option-alist)
	(cur-num gams-current-option-num)
	(temp-buf "*Select options*")
	(buffer-read-only nil)
	list-list)
    ;;
    (get-buffer-create temp-buf)
    (pop-to-buffer temp-buf)
    (setq buffer-read-only nil)
    (erase-buffer)
    (goto-char (point-min))
    ;; Insert.
    (while temp-alist
      (goto-char (point-max))
      (setq list-list (car temp-alist))
      (if (equal cur-num (car list-list))
	  (insert "*"))
      (move-to-column 2 t)
      (insert (car list-list))
      (move-to-column 20 t)
      (insert (cdr list-list))
      (insert "\n")
;      (gams-lst-insert-item list-list)
      (setq temp-alist (cdr temp-alist)))
    (goto-char (point-min))
    (setq buffer-read-only t)))

(defun gams-option ()
  "Change the combination of command line options."
  (interactive)
  (let ((cur-buf (current-buffer)))
    ;; Display.
    (gams-opt-view)
    ;; Show key in the minibuffer.
    (gams-opt-show-key)
    ;; Start the mode.
    (gams-opt-select-mode cur-buf)
    ))

(defvar gams-opt-select-mode-map (make-keymap) "keymap for gams-mode")
(let ((map gams-opt-select-mode-map))
  (define-key map "n" 'gams-opt-next)
  (define-key map "p" 'gams-opt-prev)
  (define-key map "\r" 'gams-opt-change)
  (define-key map "q" 'gams-opt-quit)
  (define-key map "a" 'gams-opt-add-new-option)
  (define-key map "d" 'gams-opt-delete))

(defun gams-opt-show-key ()
  (message
    (concat
     "\"*\" => the current, "
     "Key: "     
     "[n]ext, "     
     "[p]rev, "     
     "RET = select, "     
     "[a]dd, "     
     "[d]elete, "     
     "[q]uit.")))

(defun gams-opt-next ()
  "Next line."
  (interactive)
  (next-line 1)
  (gams-opt-show-key))

(defun gams-opt-prev ()
  "Previous line."
  (interactive)
  (next-line -1)
  (gams-opt-show-key))

(defun gams-opt-quit ()
  "Quit."
  (interactive)
  (let ((cur-buf (current-buffer)))
    (switch-to-buffer gams-opt-gms-buffer)
    (kill-buffer cur-buf)
    (delete-other-windows)))

(defun gams-opt-add-new-option-to-alist (option)
  "Add OPTION to the alist `gams-user-option-alist', and update
`gams-option-alist'."
  (let* ((user-alist gams-user-option-alist)
	 (num (number-to-string (1+ (list-length user-alist)))))
    (setq gams-user-option-alist
	  (cons (cons num option) user-alist))
    (gams-opt-make-alist)))

(defun gams-opt-add-new-option ()
  "Add a new option combination."
  (interactive)
  (let (opt)
    (setq opt (read-string "Insert a new option set: "))
    (gams-opt-add-new-option-to-alist opt)
    (gams-opt-view)
    (message (format "Added the new option \"%s\"" opt))))

(defun gams-opt-renumber ()
  "Change the number of option alist."
  (let* ((alist gams-user-option-alist)
	 (num (list-length alist))
	 new-alist)
    (while alist
      (setq new-alist
	    (cons (cons (number-to-string num) (cdr (car alist)))
		  new-alist))
      (setq num (1- num))
      (setq alist (cdr alist)))
    (setq gams-user-option-alist (reverse new-alist))))
	    
(defun gams-opt-delete ()
  "Delete the option combination on the current line."
  (interactive)
  (let ((num (gams-opt-return-option-num)))
    (cond
     ((equal num "default")
      (message "You cannot delete the default combination!"))
     ((equal num nil) nil)
     (t
      (message (format "Do you really delete \"%s\"?  Type `y' if yes." num))
      (let ((key (read-char)))
	(if (null (equal key ?y))
	    nil
	  (setq gams-user-option-alist
		(del-alist num gams-user-option-alist))
	  (message (format "Remove \"%s\" from the registered alist." num))
	  ;; renumbering.
	  (gams-opt-renumber)
	  (gams-opt-make-alist)
	  (when (equal num gams-current-option-num)
	    (setq gams-current-option-num "default"))
	  (gams-opt-view)))))))

(defun gams-opt-return-option ()
  "Return the option combination of the current line."
  (let ((num gams-current-option-num))
    (cdr (assoc num gams-option-alist))))

(defun gams-opt-return-option-num ()
  "Return the number of the option combination on the current line."
  (interactive)
  (save-excursion
    (let (end-po num)
      (save-excursion
	(end-of-line)
	(setq end-po (point)))
      (beginning-of-line)
      (if (re-search-forward "^[*]?[ \t]+\\([^ \t]+\\)[ \t]+" end-po t)
	  (progn  (setq num (gams*buffer-substring (match-beginning 1)
					      (match-end 1)))))
      num)))
      
(defun gams-opt-change ()
  "Set the option combination on the current line to the new option combination."
  (interactive)
  (let ((num (gams-opt-return-option-num))
	(cur-buf (current-buffer)))
    (setq gams-current-option-num num)
    (message (format "GAMS command line option changed to \"%s\""
		     (gams-opt-return-option)))
  (switch-to-buffer gams-opt-gms-buffer)
  (kill-buffer cur-buf)
  (delete-other-windows)))

(defun gams-opt-select-mode (buff)
  "Mode for changing command line options."
  (kill-all-local-variables)
  (setq mode-name "OPTION"
	major-mode 'gams-opt-select-mode)
  (use-local-map gams-opt-select-mode-map)
  (make-local-variable 'gams-opt-gms-buffer)
  (setq gams-opt-gms-buffer buff)
  (setq buffer-read-only t))

(add-hook 'kill-emacs-hook 'gams-register-option)

(defun gams-register-option ()
  "Save the content of `gams-user-option-alist' into the file
`gams-statement-file'."
  (interactive)
  (if (and gams-user-option-alist
	   (null (equal gams-user-option-alist gams-user-option-alist-initial)))
      (progn
	(let* ((temp-buff " *gams-option*")
	       (temp-file gams-statement-file)
	       (temp-alist gams-user-option-alist)
	       (old-alist temp-alist)
	       (alist-name "gams-user-option-alist")
	       new-alist)
	  (save-excursion
	    ;; Switch to the temporary buffer.
	    (get-buffer-create temp-buff)
	    (switch-to-buffer temp-buff)
	    ;;      (set-buffer temp-buff)
	    (erase-buffer)
	    ;; Write the content of the alist.
	    (insert-string (concat "(setq " alist-name " '(\n"))
	    (goto-char (point-max))
	    (while temp-alist
	      (insert
	       (concat
		"(\"" (car (car temp-alist)) "\" . \""
		(cdr (car temp-alist))
		"\")\n"))
	      (goto-char (point-max))
	      (setq temp-alist (cdr temp-alist)))
	    (insert "))\n")
	    ;; Check whether the variable is defined correctly.
	    (eval-buffer)
	    ;; Store the content of buffer
	    (setq temp-cont (gams*buffer-substring (point-min) (point-max)))
	    ;; Delete the list-name part.
	    (switch-to-buffer (find-file-noselect temp-file))
	    ;;      (set-buffer (find-file-noselect temp-file))
	    (goto-char (point-min))
	    ;; Check whether the list-name part exists or not.
	    (if (null (re-search-forward
		       (concat
			"\\(setq\\) " alist-name)
		       nil t))
		;; If it doesn't exists, do nothing.
		nil
	      ;; If it exists, delete it.
	      (let (point-beg point-en)
		(goto-char (match-beginning 1))
		(beginning-of-line)
		(setq point-beg (point))
		(forward-sexp 1)
		(forward-line 1)
		(setq point-en (point))
		(delete-region point-beg point-en)))
	    ;; Insert the content.
	    (goto-char (point-min))
	    (insert temp-cont)
	    ;; Save buffer of gams-statement-file.
	    (save-buffer (get-file-buffer temp-file))
	    (kill-buffer (get-file-buffer temp-file))
	    ;; kill the temporary buffer.
	    (kill-buffer temp-buff)
	    )))))

;;;	From yatex.el

;;; autoload
(defun substitute-all-key-definition (olddef newdef keymap)
  "Replace recursively OLDDEF with NEWDEF for any keys in KEYMAP now
defined as OLDDEF. In other words, OLDDEF is replaced with NEWDEF
where ever it appears."
    (mapcar
     (function (lambda (key) (define-key keymap key newdef)))
     (where-is-internal olddef keymap)))
;;-------------------- Final hook jobs --------------------
(substitute-all-key-definition
 'fill-paragraph 'gams-fill-paragraph gams-mode-map)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code for GAMS-LST mode.
;;;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; key assignment.
(defvar gams-lst-mode-map (make-keymap) "Keymap for gams-lst-mode")
(let ((map gams-lst-mode-map))
  (define-key map gams-lk-3 'gams-lst-view-error)
  (define-key map gams-lk-2 'gams-lst-jump-to-error-file)  
  (define-key map gams-lk-1 'gams-lst-jump-to-input-file)
  (define-key map "q" 'gams-lst-kill-buffer)    
  (define-key map "?" 'gams-lst-help)    

  (define-key map "o" 'gams-outline)

  (define-key map "s" 'gams-lst-solve-summary)
  (define-key map "S" 'gams-lst-solve-summary-back)
  (define-key map "r" 'gams-lst-report-summary)    
  (define-key map "R" 'gams-lst-report-summary-back)    
  (define-key map "v" 'gams-lst-next-var)    
  (define-key map "V" 'gams-lst-previous-var)    
  (define-key map "e" 'gams-lst-next-equ)    
  (define-key map "E" 'gams-lst-previous-equ)    
  (define-key map "p" 'gams-lst-next-par)    
  (define-key map "P" 'gams-lst-previous-par)    

  (define-key map "l" 'gams-lst-query-jump-to-line)    
  (define-key map gams-lk-5 'gams-lst-jump-to-line)    

  (define-key map " " 'scroll-up)    
  (define-key map [delete] 'scroll-down)    
  (define-key map "1" 'gams-lst-widen-window)    
  (define-key map "2" 'gams-lst-split-window)
  (define-key map "m" 'gams-lst-move-frame)    
  (define-key map "w" 'gams-lst-resize-frame)
  (define-key map "z" 'gams-lst-move-cursor)    

  (define-key map gams-lk-4 'gams-lst-jump-to-input-file-2)

  (define-key map "d" 'gams-lst-scroll-1)
  (define-key map "f" 'gams-lst-scroll-down-1)
  (define-key map "g" 'gams-lst-scroll-2)
  (define-key map "h" 'gams-lst-scroll-down-2)
  (define-key map "j" 'gams-lst-scroll-double)
  (define-key map "k" 'gams-lst-scroll-down-double)

  (define-key map "D" 'gams-lst-scroll-page-1)
  (define-key map "F" 'gams-lst-scroll-page-down-1)
  (define-key map "G" 'gams-lst-scroll-page-2)
  (define-key map "H" 'gams-lst-scroll-page-down-2)
  (define-key map "J" 'gams-lst-scroll-page-double)
  (define-key map "K" 'gams-lst-scroll-page-down-double)

  (define-key map "\C-cf" 'gams-choose-font-lock-level)
  
  )

;;; Menu for GAMS-LST mode.
(easy-menu-define 
  gams-lst-menu gams-lst-mode-map "Menu keymap for GAMS-LST mode."
  '("GAMS-LST"
    ["Jump to the error and show its meaning" gams-lst-view-error t]
    ["Jump to the error place in the program file" gams-lst-jump-to-error-file t]
    ["Jump to the input file" gams-lst-jump-to-input-file t]
    ["Close the buffer" gams-lst-kill-buffer t]
    ["Show help" gams-lst-help t]
    "--"
    ["Start the GAMS-OUTLINE mode" gams-outline t]
    "--"
    ["Jump to a line you specify" gams-lst-query-jump-to-line t]    
    ["Jump to a line" gams-lst-jump-to-line t]
    "--"
    ["Jump to the next SOLVER SUMMARY" gams-lst-solve-summary t]    
    ["Jump to the next REPORT SUMMARY" gams-lst-report-summary t]    
    ["Jump to the next VAR entry" gams-lst-next-var t]    
    ["Jump to the next EQU entry" gams-lst-next-equ t]    
    ["Jump to the next PARAMETER entry" gams-lst-next-par t]
    "--"
    ["Choose font-lock level." gams-choose-font-lock-level t]
    ["Fontify block." font-lock-fontify-block t]
    ))


(defun gams-lst-mode ()
  "Major mode for viewing GAMS LST file. 

The following commands are available in the GAMS-LST mode:

\\[gams-lst-view-error]		Jump to the error and show its number and meaning.
\\[gams-lst-jump-to-error-file]		Jump back to the error place in the program file.
\\[gams-lst-jump-to-input-file] 		Jump to the input (GMS) file.
\\[gams-lst-kill-buffer]		Close the buffer.
\\[gams-lst-help]		Display this help.

\\[gams-outline]		Start the GAMS-OUTLINE mode.

\\[gams-lst-solve-summary](\\[gams-lst-solve-summary-back])		Jump to the next (previous) SOLVER SUMMARY.
\\[gams-lst-report-summary](\\[gams-lst-report-summary-back])		Jump to the next (previous) REPORT SUMMARY.
\\[gams-lst-next-var](\\[gams-lst-previous-var])		Jump to the next (previous) VAR entry.
\\[gams-lst-next-equ](\\[gams-lst-previous-equ])		Jump to the next (previous) EQU entry.
\\[gams-lst-next-par](\\[gams-lst-previous-par])		Jump to the next (previous) PARAMETER entry.

\\[gams-lst-query-jump-to-line]		Jump to a line you specify.
\\[gams-lst-jump-to-line]		Jump to a line.

\\[scroll-up]		Scroll up.
\\[scroll-down] or DEL	Scroll down.
\\[gams-lst-widen-window]		Widen the window.
\\[gams-lst-split-window]		Split the window.
\\[gams-lst-move-frame]		Move frame.
\\[gams-lst-resize-frame]		Resize frame.
\\[gams-lst-move-cursor]		Move a cursor to the other window.


[Commands for Scrolling.]

Suppose that there are two windows displayed like

    __________________	  
   |   	      	      |  
   |  LST buffer 1    |  ==>  LST-1.
   |   	      	      |  
   |  CURSOR  here    |  
   |   	      	      |  
   |------------------|  
   |		      | 
   |  LST buffer 2    |  ==>  LST-2.
   |   	      	      |  
   |		      | 
    ------------------

'\\[gams-lst-scroll-1](\\[gams-lst-scroll-down-1])		Scroll the current buffer (LST-1) up (down) one line.
'\\[gams-lst-scroll-2](\\[gams-lst-scroll-down-2])		Scroll the next buffer (LST-2) up (down) one line.
'\\[gams-lst-scroll-double](\\[gams-lst-scroll-down-double])		Scroll two buffers (LST-1 and LST-2) up (down) one line.

Keyboard.

  _____________________________________________________________
  |         |         |         |         |         |         |
  |    d    |    f    |    g    |    h    |    j    |    k    |
  |         |         |         |         |         |         |
  -------------------------------------------------------------

       |         |         |         |         |         |

      UP        DOWN      UP        DOWN      UP        DOWN
         LST-1               LST-2             LST-1 & 2

If only one window exists, the above three commands have the same function
(scroll up/down the current buffer).

The followings are page scroll commands.  Just changed to upper cases.

'\\[gams-lst-scroll-page-1](\\[gams-lst-scroll-page-down-1])		Scroll up (down) the current buffer (LST-1) by a page.
'\\[gams-lst-scroll-page-2](\\[gams-lst-scroll-page-down-2])		Scroll up (down) the next buffer (LST-2) by a page.
'\\[gams-lst-scroll-page-double](\\[gams-lst-scroll-page-down-double])		Scroll up (down) two buffers (LST-1 and LST-2) by a page."

  (interactive)
  (setq major-mode 'gams-lst-mode)
  (setq mode-name "GAMS-LST")
  (use-local-map gams-lst-mode-map)
;  (easy-menu-add todo-menu)
;  (outline-minor-mode 1)
;  (hide-other)
  (setq buffer-read-only t) ;make the buffer read-only.
  
  (make-local-variable 'font-lock-defaults)
  (gams-update-font-lock-keywords "l" gams-lst-font-lock-level)
  (setq font-lock-defaults '(gams-lst-font-lock-keywords t t))

;; Create several buffer local variables for the OUTLINE mode.

  (make-local-variable 'gams-ol-flag)
  (setq gams-ol-flag nil)

  (make-local-variable 'gams-over-alist)
  (setq gams-over-alist nil)

  (make-local-variable 'gams-ol-alist-tempo)
  (setq gams-ol-alist-tempo nil)

  ;;
  (easy-menu-add gams-lst-menu)

  (run-hooks 'gams-lst-mode-hook)

  ;; Turn on font-lock.
  (if (and (null (equal gams-lst-font-lock-keywords nil))
	   font-lock-mode)
      (font-lock-fontify-buffer)
    (if (equal gams-lst-font-lock-keywords nil)
	(font-lock-mode -1)))
);;;


;; gams-lst-mode ends here.


(defun gams-lst-help ()
  "Display help for the GAMS-LST mode."
  (interactive)
  (describe-function 'gams-lst-mode))

(defun gams-lst-kill-buffer ()
  "Close the LST buffer"
  (interactive)
  (let ((ov-buff (concat "*" (file-name-sans-extension
			      (file-name-nondirectory
			       (buffer-file-name))) "-OUTLINE*")))
    (if (get-buffer ov-buff)
	(kill-buffer ov-buff))
  (kill-buffer nil)))

(defun gams-lst-view-error ()
  "Move to the error place.
and show its meaning in another window if error number is displayed."
  (interactive)
  (goto-char (point-min))
  (let (error-num error-place error-mes-place error-column)
    ;; First search syntax error. 
    (if (re-search-forward "\\*\\*\\*\\* [ ]+\\(\\$\\)\\([0-9]+\\)[$]?" nil t)
	(progn
	  (goto-char (match-beginning 1))
	  (setq error-place (point))
	  ;; set `error-num' the found error number. It is nil if no error.
	  (setq error-num (gams*buffer-substring (match-beginning 2)
					    (match-end 2)))
	  (message "Key: `%s' = Jump to the error place, `%s' = Jump to the input file."
		   gams-lk-2 gams-lk-1)
	  ;;
	  (if error-num
	      (progn
		(if (null (re-search-forward "Error Messages" nil t))
;;		    (message "cannot find `Error Messages'!")
		    nil
		  (setq error-mes-place
			(re-search-forward error-num nil t))))
	    ;; if error-num is nil, go to the top of the buffer.
	    (goto-char (point-min)))
	  ;; Display syntax error message.
	  (if error-mes-place
	      (progn
		(delete-other-windows)
		(split-window)
		(goto-char error-place)
		(recenter)
		(other-window 1)
		(goto-char error-mes-place)
		(recenter 0)
		(other-window 1))
	    (recenter)))

      ;; Search another type of errors.
      (if (catch 'found
	    (while (re-search-forward "\\*\\*\\*\\* " nil t)
	      (progn
		(beginning-of-line)
		(setq a-point (point))
		(end-of-line)
		(setq b-point (point))
		(goto-char a-point)

		;; The following lines are not regarded as errors and
		;; skipped.  Is this right behavior?
		(if (not (or (re-search-forward "\\*\\*\\*\\* SOLVER STATUS"
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* MODEL STATUS"
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* REPORT SUMMARY"
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* REPORT FILE SUMMARY"
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* LIST OF STRAY NAMES"
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* STRAY NAME "
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* FILE SUMMARY"
					    b-point t)
			     (re-search-forward "\\*\\*\\*\\* OBJECTIVE VALUE"
					    b-point t)))
		    (throw 'found t)
		  (forward-line 1)))))
	  ;;
	  (progn
	    (goto-char (match-beginning 0))
	    (setq a-point (point))
	    (end-of-line)
	    (setq b-point (point))
	    (goto-char a-point)
	    ;;
	    (if (re-search-forward " at line \\([0-9]+\\)" b-point t)
		(message (format "Error is found!  Type `%s' if you want to jumpt to the error line %s."
				 gams-lk-5 (gams*buffer-substring (match-beginning 1)
							     (match-end 1))))
	    (message "Error is found!"))
	    (goto-char a-point))

	;; Else part.  When no error is found.
	(progn
	  (message "No error message is found!")
	  (goto-char (point-min)))
	))))

;;; 
(defun gams-lst-jump-to-error ()
  "Jump to the error place."
  (interactive)
  (let ((current-point (point)))
    (goto-char (point-min))
    (if	(re-search-forward "\\*\\*\\*\\* [ ]+\\(\\$\\)\\([0-9]+\\)[$]?" nil t)
	(progn
	  (goto-char (match-beginning 1))
	  t)
      (progn
	(goto-char current-point)
	(message "No error is found!")
	nil))))

(defun gams-lst-get-gms ()
  "Return a GMS file name from a the current LST file buffer."
  (let ((file-buffer-lst (buffer-file-name))
	(ext-up (concat "." (upcase gams-lst-gms-extention)))
	(ext-down (concat "." (downcase gams-lst-gms-extention)))
	dir-lst file-noext file-gms file-lst)
    
    ; Store LST file name.
    (setq dir-lst (file-name-directory file-buffer-lst))
    (setq file-lst (file-name-nondirectory file-buffer-lst))
    (setq file-noext (file-name-sans-extension file-lst))

    ; Search GMS file name.  GMS file name is stored in file-gms.
    (cond
     ((file-exists-p
       (concat dir-lst file-noext ext-down))
      (setq file-gms (concat dir-lst file-noext ext-down)))
     ((file-exists-p
       (concat dir-lst file-noext ext-up))
      (setq file-gms (concat dir-lst file-noext ext-up)))
     ((file-exists-p
       (concat dir-lst (upcase file-noext) ext-down))
      (setq file-gms (concat dir-lst (upcase file-noext) ext-down)))
     ((file-exists-p
       (concat dir-lst (upcase file-noext) ext-up))
      (setq file-gms (concat dir-lst (upcase file-noext) ext-up)))
     ((file-exists-p
       (concat dir-lst (downcase file-noext) ext-down))
      (setq file-gms (concat dir-lst (downcase file-noext) ext-down)))
     ((file-exists-p
       (concat dir-lst (downcase file-noext) ext-up))
      (setq file-gms (concat dir-lst (downcase file-noext) ext-up)))
     (t
      (message "GMS file does not exist!")))
    file-gms))

(defun gams-lst-get-input-filename ()
  "Get the input file name associated to the current LST file.

The input file name is extract from FILE SUMMARY field."
  (let (temp-file)
    (save-excursion
      (goto-char (point-min))
      (if (re-search-forward "\\*\\*\\*\\* FILE SUMMARY" nil t)
	  ;; If FILE SUMMARY is found,
	  (progn
	    (setq point-a (match-beginning 0))
	    
	    (if (re-search-forward "^INPUT[ ]+\\(.*\\)" nil t)
		(setq temp-file (gams*buffer-substring (match-beginning 1)
						  (match-end 1)))))
	;; If FILE SUMMARY is not found,
	(setq temp-file (gams-lst-get-gms))
	(message "FILE SUMMARY field does not exits!  The extension is assumed to be gms.")
	(sleep-for 1)))
    ;; Return the input file name.
    temp-file))

(defun gams-lst-save-string ()
  "?"
  (let ((times 3)
	(check 0)
	(current-buffer (buffer-name))
	(work-buffer (get-buffer-create "*temp*")) ; Create temporary buffer
	point-beg point-end list-string string
	a-point b-point)
    ;; save string in list-string
    (while (and (> times 0) (< check 50))
      (forward-line -1)
      (beginning-of-line)
      (setq point-beg (point))
      (end-of-line)
      (setq point-end (point))
      (goto-char point-beg)
      (if (re-search-forward "^[ ]*[0-9]+  " point-end t)
	  (progn
	    (setq list-string
		  (cons
		   (if (equal
			(gams*buffer-substring (match-end 0) point-end) " ")
		       ;; if t, return "" not " ".
		       ""
		     ;; if nil, return the matched.
		     (gams*buffer-substring (match-end 0) point-end))
		   list-string))
	    (setq times (- times 1)))
	(setq check (+ check 1))
	))
;;
    (setq string
	  (concat
	   (car list-string) "\n"
	   (car (cdr list-string)) "\n"
	   (car (cdr (cdr list-string)))))

    ;; Switch to the temporary buffer.
    (set-buffer work-buffer)
    (insert string)
    (goto-char (point-min))

    ;; Replace several strings with regular expression.
    (goto-char (point-min))
    (while (re-search-forward "\\(\\\\\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "[\\\\]"))
    (goto-char (point-min))
    (while (re-search-forward "\\(\\+\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "[\+]"))
    (goto-char (point-min))
    (while (re-search-forward "\\(\\?\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "[\?]"))
    (goto-char (point-min))
    (while (re-search-forward "\\([ ]+\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "[ \t]+"))
    (goto-char (point-min))
    (while (re-search-forward "\\(\\.\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "\."))
    (goto-char (point-min))     
    (while (re-search-forward "\\(\\$\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "\$"))
    (goto-char (point-min))
    (while (re-search-forward "\\(\\*\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "[\*]"))
    (goto-char (point-min))
    (while (re-search-forward "\\(\n\\)" nil t)
      (setq a-point (match-beginning 1))
      (setq b-point (match-end 1))
      (replace-match "[ \t]*\n"))
    ;; Store regular expression to string.
    (setq string (gams*buffer-substring (point-min) (point-max)))
    (insert string)
    (switch-to-buffer current-buffer)
    ;; Delete temporary buffer.
    (kill-buffer work-buffer)
    ;; Return the content of string.
    string))

;;; This function is not used.
(defun gams-lst-view-gms()
  "Jump back to the error place in the program file.

NB: It may not work properly.  It is difficult to implement this function
perfectly...
"
  (interactive)
  (let ((file-gms (gams-lst-get-input-filename))
	string)
    
    ;; Jump to the error place.
    (if (gams-lst-jump-to-error)
	(progn
	  ;; Save the string around error place.
	  (setq string (gams-lst-save-string))
	  (if (null (file-exists-p file-gms))
	      ;;
	      (message "The file `%s' does not exist!" file-gms)
	    ;; open GMS file.
	    (if (get-file-buffer file-gms)
		(switch-to-buffer (get-file-buffer file-gms))
	      (find-file file-gms))
	    (goto-char (point-min))
	    ;; Search the error place.
	    (if (re-search-forward string nil t)
		(progn
		  (forward-line -1)
		  (recenter))
	      (message "Error place is not found!"))
	    )
	  (message "No error is found!")))))

;;; New function.
(defun gams-lst-jump-to-error-file ()
  (interactive)
  (let (point-a point-b line-num file-name error-column temp-col)
    ;;
    (if	(gams-lst-jump-to-error)
	(progn
	  ;; Store column number.
	  (save-excursion
	    (if (re-search-forward "^\\([ ]*[0-9]+[ ][ ]\\)" nil t)
		(setq temp-col (current-column))
	      (setq temp-col 1)))
	  (setq error-column (- (current-column) temp-col))
	  (forward-line 1)
	  (setq point-a (point))
	  (end-of-line)
	  (forward-char 1)
	  (setq point-b (point))
	  (goto-char point-a)
	  ;; Search the file name line.
	  (if (re-search-forward
	       "\\*\\*\\*\\* LINE[ \t]+\\([0-9]+\\)[ ]+IN[ ]+FILE[ ]+\\([^\n]+\\)\n"
	       point-b t)
	      ;; If the file name line is found.
	      (progn
		(setq line-num (gams*buffer-substring (match-beginning 1)
						 (match-end 1)))
		(setq file-name (gams*buffer-substring (match-beginning 2)
						  (match-end 2)))
		(if (file-exists-p file-name)
		    ;;
		    (progn
		      (if (get-file-buffer file-name)
			  (switch-to-buffer (get-file-buffer file-name))
			(find-file file-name))
		     
		      (goto-line (string-to-number line-num))
		      (move-to-column error-column)
		      (recenter))

		  ;;
		  (message "The file `%s' does not exist!" file-name)))
	  
	    ;; If the file name line is not found

	    ;; Jump to the error place.
	    (gams-lst-jump-to-error)
	    (recenter)

	    ;; Save the string around error place.
	    (setq string (gams-lst-save-string))
	    (setq file-name (gams-lst-get-input-filename))

	    ;; open GMS file.
	    (if (file-exists-p file-name)
		;;
		(progn (if (get-file-buffer file-name)
			   (switch-to-buffer (get-file-buffer file-name))
			 (find-file file-name))
		       ;; Search the error place.
		       (goto-char (point-min))
		       (if (re-search-forward string nil t)
			   (progn (recenter)
				  (move-to-column error-column))
			 ;;
			 (message "Error place is not found!")))
	      ;;
	      (message "The file `%s' does not exist!" file-name))))
      ;;
      (message "No error is found!"))))


(defun gams-lst-jump-to-input-file ()
  "Switch to the GMS file buffer."
  (interactive)
  (let ((file-gms (gams-lst-get-input-filename)))

    (if (null (file-exists-p file-gms))
	;; If gms file does not exist.
	(message "The file `%s' does not exist!" file-name)
      ;; If gms file exits.
      (if (get-file-buffer file-gms)
	  (switch-to-buffer (get-file-buffer file-gms))
	(find-file file-gms))
      (recenter))))

(defun gams-lst-jump-to-input-file-2 ()
  "Jump back to the error place in the input file.
"
  (interactive)
  (let ((file-gms (gams-lst-get-input-filename))
	string point-here)
    (forward-line 1)
    ;; Save the string around error place.
    (setq string (gams-lst-save-string))
    ;; open GMS file.
    (if (null (file-exists-p file-gms))
	;; If gms file does not exist.
	(message "The file `%s' does not exist!" file-name)
      ;; If gms file does exists.
      (if (get-file-buffer file-gms)
	  (switch-to-buffer (get-file-buffer file-gms))
	(find-file file-gms))
      
      (setq point-here (point))
      (if string
	  (progn
	    (goto-char (point-min))
	    ;; Search.
	    (save-excursion
	      (if (re-search-forward string nil t)
		  (progn
		    (recenter)
		    (beginning-of-line)
		    (setq point-here (point)))))))
      (goto-char point-here))))

;;;;

(defun gams-lst-jump-item (item &optional flag)
  "Jump to the next (or previous) ITEM (VAR, EQU, SUMMARY etc.)

If FLAG is non-nil, jump to the previous item.
"
  (let ((item-name item)
	(regex-sum "S O L V E      S U M M A R Y")
	(regex-rep "\\*\\*\\*\\* REPORT SUMMARY")
	(regex-var "^---- ")
	(regex-par "[0-9]+ PARAMETER "))
    (if (null flag)
	;; Jump to the next.
	(progn
	  (end-of-line)
	  (if (re-search-forward (cond
				  ((equal item "SUM") regex-sum)
				  ((equal item "REP") regex-rep)
				  ((equal item "PAR") regex-par)
				  (t (concat "^---- " item)))
				 nil t)
	      (progn
		(beginning-of-line)
		(recenter))
	    (message (concat "No more " item " entry"))))
      ;; Jump to the previous.
      (beginning-of-line)
      (if (re-search-backward (cond
			       ((equal item "SUM") regex-sum)
			       ((equal item "REP") regex-rep)
			       ((equal item "PAR") regex-par)
			       (t (concat "^---- " item)))
			      nil t)
	  (progn
	    (beginning-of-line)
	    (recenter))
	(message (concat "No more " item " entry"))))))

(defun gams-lst-solve-summary ()
  "Jump to the next SOLVE SUMMARY"
  (interactive)
  (interactive)
  (gams-lst-jump-item "SUM"))

(defun gams-lst-solve-summary-back ()
  "Jump to the previous SOLVE SUMMARY"
  (interactive)
  (gams-lst-jump-item "SUM" t))

(defun gams-lst-report-summary ()
  "Jump to the next REPORT SUMMARY"  
  (interactive)
  (gams-lst-jump-item "REP"))

(defun gams-lst-report-summary-back ()
  "Jump to the previous REPORT SUMMARY"
  (interactive)
  (gams-lst-jump-item "REP" t))

(defun gams-lst-next-var ()
  "Jump to the next VAR entry"
  (interactive)
  (gams-lst-jump-item "VAR"))

(defun gams-lst-previous-var ()
  "Jump to the previous VAR entry"
  (interactive)
  (gams-lst-jump-item "VAR" t))

(defun gams-lst-next-equ ()
  "Jump to the next EQU entry"
  (interactive)
  (gams-lst-jump-item "EQU"))

(defun gams-lst-previous-equ ()
  "Jump to the previous EQU entry"
  (interactive)
  (gams-lst-jump-item "EQU" t))

(defun gams-lst-next-par ()
  "Jump to the next PARAMETER entry"  
  (interactive)
  (gams-lst-jump-item "PAR"))

(defun gams-lst-previous-par ()
  "Jump to the next PARAMETER entry"  
  (interactive)
  (gams-lst-jump-item "PAR" t))

(defun gams-lst-widen-window ()
  "Make the window fill its frame.  Same as `delete-other-window'."  
  (interactive)
  (delete-other-windows)
  (recenter)
  (message "Winden window."))

(defun gams-lst-split-window ()
  "Split current window into two windows.  Same as `split-window-vertically'."  
  (interactive)
  (split-window-vertically)  
  (recenter)
  (message "Split window."))

(defun gams-lst-query-jump-to-line (line-num)
  "Jump to the line you specify."
  (interactive "sInput line number: ")
  (let (temp-num)
    (setq temp-num
	  (concat "^[ ]*" line-num))
    (goto-char (point-min))
    (re-search-forward temp-num nil t)
    (beginning-of-line)))

(defun gams-lst-jump-to-line ()
  "Jump to the line indicated by the number you are on.

If you execute this command on a line like

**** Exec Error 0 at line 32 .. Division by zero

you can jump to line 32."
  (interactive)
  (let ((cur-point (point))
	end-point
	line-num)
    ;;
    (end-of-line)
    (setq end-point (point))
    ;;	Get the line number.
    (beginning-of-line)
    (if (re-search-forward "at line \\([0-9]+\\)" end-point t)
	(progn
	  (setq line-num
		(concat "^[ ]*"
			(gams*buffer-substring
			 (match-beginning 1)
			 (match-end 1))))
	  ;; Go to the beginning of the buffer
	  (goto-char (point-min))
	  ;; Search line.
	  (re-search-forward line-num nil t)
	  (beginning-of-line)
	  (message "If you want to jump to the GMS file, push `%s'."
		   gams-lk-4))
      ;;
      (goto-char cur-point)
      (message "This command is valid only if the cursor in on a line with line number!")
      )))

(defun gams-lst-move-cursor ()
  "Jump the cursor to the other window."
  (interactive)
  (other-window 1))

;; From the emasc lisp book written by Yuuji Hirose.
(defun gams-lst-resize-frame ()
  "Resize frame by keyboard.

n - Widen vertically
p - Narrow vertically
f - Widen horizontally
b - Narrow horizontally
Any other key - quit

To put Control key simultaneously makes movement faster.
"
  (interactive)
  (let (key
	(width (frame-width))
	(height (frame-height)))
    (catch 'quit
      (while t
	(message "Resize frame by [(C-)npfb] (%dx%d): " width height)
	(setq key (read-char))
	(cond
	 ((eq key ?n) (setq height (+ 1 height)))
	 ((eq key 14) (setq height (+ 5 height)))
	 ((eq key ?p) (setq height (- height 1)))
	 ((eq key 16) (setq height (- height 5)))
	 ((eq key ?f) (setq width (+ 1 width)))
	 ((eq key 6) (setq width (+ 5 width)))
	 ((eq key ?b) (setq width (- width 1)))
	 ((eq key 2) (setq width (- width 5)))
	 (t (throw 'quit t)))
	(modify-frame-parameters
	 nil (list (cons 'width width) (cons 'height height)))))
    (message "End...")))


;;; From the emacs lisp book written by Yuuji Hirose.
(defun gams-lst-move-frame ()
  "Move frame by keyboard.

n - Move upward
p - Move downward
f - Move rightward
b - Move leftward
Any other key - quit

To put Control key simultaneously makes movement faster.
"
  (interactive)
  (let (key
	(top (frame-parameter nil 'top))
	(left (frame-parameter nil 'left)))
    (if (listp top)
	(setq top (car (cdr top))))
    (if (listp left)
	(setq left (car (cdr left))))
    (catch 'quit
      (while t
	(message "Move frame by [(C-)npfb] (%dx%d): " top left)
	(setq key (read-char))
	(cond
	 ((eq key ?n) (setq top (+ 10 top)))
	 ((eq key ?p) (setq top (- top 10)))
	 ((eq key ?f) (setq left (+ 10 left)))
	 ((eq key ?b) (setq left (- left 10)))
	 ((eq key 14) (setq top (+ 20 top)))
	 ((eq key 16) (setq top (- top 20)))
	 ((eq key 6) (setq left (+ 20 left)))
	 ((eq key 2) (setq left (- left 20)))
	 (t (throw 'quit t)))
	(if (and (or (eq key ?p) (eq key 16)) (<= top 5))
	    (progn
;	      (message "Can't move upward anymore!")
	      (setq top 5)))
	(if (and (or (eq key ?b) (eq key 2)) (<= left 5))
	    (progn
;	      (message "Can't move left anymore!")
	      (setq left 5)))
	(modify-frame-parameters
	 nil (list (cons 'top top) (cons 'left left )))))
    (message "End...")))


;;; scroll
(defun gams-lst-count-win ()
  "Count the number of windows and return it."
  (let ((cur-win (selected-window))
	(num 1)
	flag)
    (save-excursion
      (if (one-window-p)
	  nil
	;;
	(catch 'quit
	  (while t
	    (other-window 1)
	    (setq flag (selected-window))
	    (cond
	     ((not (eq flag cur-win))
	      (setq num (+ num 1)))
	     ((eq flag cur-win)
	      (throw 'quit t)))))))
    num))

(defun gams-lst-scroll (&optional down num page)
  "Command for scrolling.

If DOWN is non-nil, scroll down.
NUM mean scroll type (nil, 2, or d).
If PAGE is non-nil, page scroll."
  (interactive)
  (let ((cur-win (selected-window))
	(win-num (gams-ol-count-win))
	;; flag for lst or ov?
	(flag-lst
	 (if (equal "GAMS-LST" mode-name) t nil))
	;; flag for page scroll or not.
	(fl-pa (if page nil 1)))
		      
    (if flag-lst
	;; If LST buffer
	(cond
	 ;; scroll type 1.
	 ((null num)
	  (save-excursion
	    (if down (scroll-down fl-pa)
	      (scroll-up fl-pa))))
	 ;; scroll type 2.
	 ((equal num "2")
	  (cond
	   ((eq win-num 1)
	    (if down
		(scroll-down fl-pa)
	      (scroll-up fl-pa)))
	   ((> win-num 1)
	    (other-window 1)
	    (if down
		(scroll-down fl-pa)
	      (scroll-up fl-pa))
	    (select-window cur-win))
	   (t nil)))
	 ;; scroll type double.
	 ((equal num "d")
	  (cond
	   ((eq win-num 1)
	    (if down
		(scroll-down fl-pa)
	      (scroll-up fl-pa)))
	   ((> win-num 1)
	    (if down
		(scroll-down fl-pa)
	      (scroll-up fl-pa))
	    (other-window 1)
	    (if down
		(scroll-down fl-pa)
	      (scroll-up fl-pa))
	    (select-window cur-win))
	   (t nil))))

      ;; If OV buffer.
      (cond
       ;; scroll type 1.
       ((null num)
	(cond
	 ((eq win-num 1)
	  nil)
	 ((> win-num 1)
	  (save-excursion
	    (other-window 1)
	    (if down
		(scroll-down fl-pa)
	      (scroll-up fl-pa))
	    (select-window cur-win)))))
       ;; scroll type 2.
       ((equal num "2")
	(cond
	 ((eq win-num 1)
	  nil)
	 ((eq win-num 2)
	  (other-window 1)
	  (if down
	      (scroll-down fl-pa)
	    (scroll-up fl-pa))
	  (select-window cur-win))
	 ((eq win-num 3)
	  (other-window 2)
	  (if down
	      (scroll-down fl-pa)
	    (scroll-up fl-pa))
	  (select-window cur-win))
	 (t nil)))
       ;; scroll type double.
       ((equal num "d")
	(cond
	 ((eq win-num 1)
	  nil)
	 ((eq win-num 2)
	  (other-window 1)
	  (if down
	      (scroll-down fl-pa)
	    (scroll-up fl-pa))
	  (select-window cur-win))
	 ((eq win-num 3)
	  (other-window 1)
	  (if down
	      (scroll-down fl-pa)
	    (scroll-up fl-pa))
	  (other-window 1)
	  (if down
	      (scroll-down fl-pa)
	    (scroll-up fl-pa))
	  (select-window cur-win))
	 (t nil))))
      ;;
      (gams-ol-show-key)
      )))

;;; line scroll.
(defun gams-lst-scroll-1 ()
  (interactive)
  (gams-lst-scroll))

(defun gams-lst-scroll-down-1 ()
  (interactive)
  (gams-lst-scroll t))

(defun gams-lst-scroll-2 ()
  (interactive)
  (gams-lst-scroll nil "2"))

(defun gams-lst-scroll-down-2 ()
  (interactive)
  (gams-lst-scroll t "2"))

(defun gams-lst-scroll-double ()
  (interactive)
  (gams-lst-scroll nil "d"))

(defun gams-lst-scroll-down-double ()
  (interactive)
  (gams-lst-scroll t "d"))

;;; Page scroll
(defun gams-lst-scroll-page-1 ()
  (interactive)
  (gams-lst-scroll nil nil t))

(defun gams-lst-scroll-page-down-1 ()
  (interactive)
  (gams-lst-scroll t nil t))

(defun gams-lst-scroll-page-2 ()
  (interactive)
  (gams-lst-scroll nil "2" t))

(defun gams-lst-scroll-page-down-2 ()
  (interactive)
  (gams-lst-scroll t "2" t))

(defun gams-lst-scroll-page-double ()
  (interactive)
  (gams-lst-scroll nil "d" t))

(defun gams-lst-scroll-page-down-double ()
  (interactive)
  (gams-lst-scroll t "d" t))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code for GAMS-TEMPLATE.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;(autoload 'gams-template "gams-temp" "Start GAMS-TEMPLATE" t)

;;; Customizable variables for GAMS-TEMPLATE mode.

(defcustom gams-template-file "~/.gams-template"
  "*The name of a file used to store templates."
  :type 'file
  :group 'gams)
  
(defcustom gams-save-template-change nil
  "Nil means that save the content of `gams-user-template-alist' into
`gams-template-file' only when you quit Emacs.  If non-nil, save
`gams-user-template-alist' every time you made changes.  If your Emacs
often crashes, you may had better set it to non-nil."
  :type 'boolean
  :group 'gams)

(defcustom gams-template-mark "%c"
  "*The mark that indicates the point of cursor in a template."
  :type 'string
  :group 'gams)

(defcustom gams-template-cont-color t
  "*Non-nil means colorization of *Template Content* buffer."
  :type 'boolean
  :group 'gams)

;;; Customizable variables end here.

;;;;; Codes

(if (not gams-save-template-change)
    (add-hook 'kill-emacs-hook 'gams-write-alist-to-file))

(defvar gams-template-file-already-loaded nil)

(defvar gams-user-template-alist nil)
(defvar gams-temp-buffer "*Template List*")
(defvar gams-temp-edit-buffer "*Template Edit*")
(defvar gams-temp-cont-buffer "*Template Content*")
(defvar gams-prog-file-buff nil)

(defun gams-template ()
  "Start the GAMS-TEMPLATE mode."
  (interactive)
  (if (and (file-exists-p gams-template-file)
	   (null gams-template-file-already-loaded))
      (progn (load-file gams-template-file)
	     (defvar gams-user-template-alist-init gams-user-template-alist)
	     (setq gams-template-file-already-loaded t)))
  (let* ((temp-buffer (get-buffer-create gams-temp-buffer))
	 (cur-buf (current-buffer)))
    ;; Store window configuration.
    (setq gams-temp-window (current-window-configuration))
    (pop-to-buffer temp-buffer)
    (gams-template-mode cur-buf)
    ))

;; Key assignment of GAMS-TEMPLATE mode.
(setq gams-template-mode-map (make-keymap))
(let ((map gams-template-mode-map))
  (define-key map " "     'gams-temp-show-cont)
  (define-key map "\r"    'gams-temp-exit)
  (define-key map "q"     'gams-temp-quit)
  (define-key map "a"     'gams-temp-add)
  (define-key map "d"     'gams-temp-delete)
  (define-key map "e"     'gams-temp-reedit)
  (define-key map "r"     'gams-temp-rename)
  (define-key map "u"     'gams-temp-up)
  (define-key map "j"     'gams-temp-down)
  (define-key map "g"     'gams-temp-gms)
  (define-key map "s"     'gams-temp-scroll)
  (define-key map "S"     'gams-temp-scdown)
  (define-key map "h"     'gams-temp-help)
  (define-key map "o"     'gams-write-alist-to-file)
  (define-key map "p"     'gams-temp-prev)
  (define-key map "n"     'gams-temp-next)
  (define-key map [up]     'gams-temp-prev)
  (define-key map [down]     'gams-temp-next))

;;; Menu for GAMS-TEMPLATE mode.
(easy-menu-define 
  gams-template-mode-menu gams-template-mode-map "Menu keymap for GAMS-TEMPLATE mode."
  '("GAMS-TEMPLATE"
    ["Show a content of a template" gams-temp-show-cont t]
    ["Insert a template" gams-temp-exit t]
    ["Quit TEMPLATE mode" gams-temp-quit t]
    ["Add a new template" gams-temp-add t]
    "--"    
    ["Delete a template" gams-temp-delete t]
    ["Re-edit a template" gams-temp-reedit t]
    ["Rename a template" gams-temp-rename t]
    ["Move a template up" gams-temp-up t]
    ["Move a template down" gams-temp-down t]
    ["Show gms file" gams-temp-gms t]
    "--"
    ["Scroll up Content buffer" gams-temp-scroll t]
    ["Scroll down Content buffer" gams-temp-scdown t]
    "--"
    ["Show help" gams-temp-help t]
    ["Save" gams-write-alist-to-file t]
    "--"
    ["Show the previous template" gams-temp-prev t]
    ["Show the next template" gams-temp-next t]
    ))

;; GAMS-TEMPLATE mode.
(defun gams-template-mode (&optional buff-name)
  "The GAMS-TEMPLATE mode (a mode for template handling).

BUFF-NAME is the name of the current LST file buffer.

The following commands are available in this mode.

\\[gams-temp-show-cont]		Show a content of a template.
\\[gams-temp-exit]		Insert a template.
\\[gams-temp-quit]		Quit.
\\[gams-temp-add]		Add a new template.

\\[gams-temp-delete]		Delete a template.
\\[gams-temp-reedit]		Re-edit a template.
\\[gams-temp-rename]		Rename a template.
\\[gams-temp-up]		Move a template up.
\\[gams-temp-down]		Move a template down.

\\[gams-temp-gms]		Show the gms file.
\\[gams-temp-scroll](\\[gams-temp-scdown])		Scroll up (down) *Template Content* buffer.
\\[gams-temp-help]		Show this help.
\\[gams-write-alist-to-file]		Save the content of gams-user-template-alist.

\\[gams-temp-prev]		Show the previous template.
\\[gams-temp-next]		Show the next template."
  (let ((temp-buff gams-prog-file-buff))
    (kill-all-local-variables)
    (setq mode-name "GAMS-TEMPLATE"
	  major-mode 'gams-template-mode)
    (use-local-map gams-template-mode-map)
    ;; Make a buffer local variable.
    (if (null temp-buff)
	(progn
	  ;; Set the gms file buffer to gams-prog-file-buff.  
	  (make-local-variable 'gams-prog-file-buff)
	  (setq gams-prog-file-buff buff-name))
      (make-local-variable 'gams-prog-file-buff)
      (setq gams-prog-file-buff temp-buff))
    (setq buffer-read-only nil)
    ;;
    (gams-temp-show-list)
    (gams-temp-show-cont)
    ;; 
    (if gams-user-template-alist
	(gams-temp-select-key)
      (gams-temp-show-message))
    ;;
    (setq buffer-read-only t)
    ;; menu.
    (easy-menu-add gams-template-mode-menu)
    ))

(defun gams-temp-select-key ()
  "Show key assignments in the GAMS-TEMPLATE mode."
  (message
   (format "[h]elp, [p]rev, [n]ext, SPACE = show, [g]ms, [q]uit, RET = insert, [a]dd. ")))

(defun gams-temp-show-list ()
  "Insert template list in the *Template List* buffer."
  (save-excursion
    (let ((temp-alist gams-user-template-alist)
	  temp-ele temp-ele-name temp-ele-cont
	  (buffer-read-only nil))
      (erase-buffer)
      (goto-char (point-min))
      (if temp-alist
	  ;; If gams-user-template-alist is not empty.
	  (progn
	    ;; Insert elements of gams-user-template-alist.
	    (while temp-alist
	      (setq temp-ele (car temp-alist))
	      (setq temp-ele-name (car temp-ele))
	      (setq temp-ele-cont (cdr temp-ele))
	      (beginning-of-line)
	      (move-to-column 2 t) 
	      (insert (concat "[" temp-ele-name "]\n"))
	      (setq temp-alist (cdr temp-alist)))
	    ;; Narrow the region.
	    (narrow-to-region (point-min)
			      (- (point-max) 1))
	    (goto-char (point-min)))
	(gams-temp-show-message)))))

(defun gams-temp-show-message ()
  (message
   (concat "No template is registered!"
	   "  `a' = add, `q' = quit, `h' = help.")))

(defun gams-temp-show-cont ()
  "Show the content of a template in the *Template Content* buffer. "
  (interactive)
  (let ((curr-buf (current-buffer))
	(temp-buf (get-buffer-create gams-temp-cont-buffer))
	(temp-na (gams-temp-get-name)))
    (if gams-user-template-alist
	(if temp-na
	    (progn
	      (pop-to-buffer temp-buf)
	      (let ((buffer-read-only nil))
		(erase-buffer)
		(goto-char (point-min))
		(setq template (assoc temp-na gams-user-template-alist))
		(insert (cdr template))
		;; Change the Mode.
		(gams-temp-cont-mode)
		(goto-char (point-min))
		(pop-to-buffer curr-buf)
		(setq buffer-read-only t)
		(gams-temp-select-key)
		)))
      (gams-temp-show-message)
      )))

(defun gams-temp-cont-mode ()
  "The mode for *Template Content* buffer."
  (kill-all-local-variables)
  (setq major-mode 'gams-temp-cont-mode)
  (setq mode-name "Content")
  (mapcar
   'make-local-variable
   '(gams-comment-prefix
     gams-eolcom-symbol
     gams-inlinecom-symbol-start
     gams-inlinecom-symbol-end))
  (when gams-template-cont-color
    ;; Make `gams-eolcom-symbol' a buffer-local variable.
    (let (temp)
      (if (setq temp (gams-search-dollar-com t))
	  (setq gams-eolcom-symbol temp)
	(setq gams-eolcom-symbol nil)))
    ;; Make `gams-inlinecom-symbol-start' and `gams-inlinecom-symbol-end'
    (let (temp)
      (if (setq temp (gams-search-dollar-com))
	  (progn (setq gams-inlinecom-symbol-start (car temp))
		 (setq gams-inlinecom-symbol-end (cdr temp)))
	(setq gams-inlinecom-symbol-start nil)))
    ;; Font-lock
    (make-local-variable 'font-lock-defaults)
    (make-local-variable 'font-lock-keywords)
    (gams-update-font-lock-keywords "g" gams-font-lock-level)
    (setq font-lock-keywords gams-font-lock-keywords)
    (setq font-lock-defaults '(font-lock-keywords t t))
    (setq font-lock-mark-block-function 'gams-font-lock-mark-block-function)
    ;; Turn on font-lock.
    (if (and (null (equal gams-font-lock-keywords nil))
	     font-lock-mode)
	(font-lock-fontify-buffer)
      (if (equal gams-font-lock-keywords nil)
	  (font-lock-mode -1)))
    (setq buffer-read-only t))
  )

(defun gams-temp-get-name ()
  "Get a name of a template on the current line."
  (interactive)
  (save-excursion
    (let (point-a temp-na)
      (end-of-line)
      (setq point-a (point))
      (beginning-of-line)
      (when (re-search-forward "[   ]+[[]\\(.*\\)[]]" point-a t)
	(setq temp-na (gams*buffer-substring (match-beginning 1)
					     (match-end 1))))
      temp-na)))

(defun gams-temp-scroll ()
  "Scroll up *Template Content* buffer."
  (interactive)
  (scroll-other-window 1)
  (gams-temp-select-key)
  (interactive))
  
(defun gams-temp-scdown ()
  "Scroll down *Template Content* buffer."
  (interactive)
  (scroll-other-window-down 1)
  (gams-temp-select-key)
  (interactive))
  
(defun gams-temp-help ()
  "Display help for GAMS-TEMPLATE mode."
  (interactive)
  (describe-function 'gams-template-mode))

(defun gams-temp-quit ()
  "Quit the GAMS-TEMPLATE mode."
  (interactive)
  (if gams-save-template-change
      (gams-write-alist-to-file))
  (pop-to-buffer gams-prog-file-buff)
  (kill-buffer gams-temp-cont-buffer)
  (kill-buffer gams-temp-buffer)
  (delete-other-windows)
  ;; Restore window configurations.
  (set-window-configuration gams-temp-window))

(defun gams-temp-next ()
  "Display the next template."
  (interactive)
  (let ((sig-max-num (length gams-user-template-alist)))
    (if gams-user-template-alist
	(progn
	  (when (null (equal sig-max-num (count-lines (point-min) (+ 1 (point)))))
	    (next-line 1))
	  (gams-temp-show-cont)
	  (setq buffer-read-only t))
      (gams-temp-show-message))))

(defun gams-temp-prev ()
  "Display the previous template."
  (interactive)
  (if gams-user-template-alist
      (progn
	(if (null (equal 1 (count-lines (point-min) (+ (point) 1))))
	    (next-line -1))
	(gams-temp-show-cont)
	(setq buffer-read-only t))
    (gams-temp-show-message)))

(defun gams-temp-gms ()
  "Show the gms file."
  (interactive)
  (let ((temp-buf (current-buffer)))
    (pop-to-buffer gams-prog-file-buff)
    (pop-to-buffer temp-buf)
    (gams-temp-select-key)))

(defun gams-temp-internal (temp)
  (let (point-a)
    (if temp
	(if (string= temp "")
	    nil
	  (narrow-to-region (point-min)
			    (setq point-a (point)))
	  (insert temp)
	  (gams-temp-replace point-a (point-max))
	  (widen)
	(set-buffer-modified-p (buffer-modified-p))))))

(defun gams-temp-exit ()
  "Insert a template into a buffer."
  (interactive)
  (let* ((temp-name (gams-temp-get-name))
	 (temp-cont (cdr (assoc temp-name gams-user-template-alist))))
    ;; Back to the program file buffer.
    (switch-to-buffer gams-prog-file-buff)
    (delete-other-windows)
    ;; Insert a template.
    (gams-temp-internal temp-cont)
    (kill-buffer gams-temp-cont-buffer)
    (kill-buffer gams-temp-buffer)
    ;; restore window configurations.
    (set-window-configuration gams-temp-window)))

(defun gams-temp-add ()
  "Add a new template."
  (interactive)
  ;; kill template buffers.
  (kill-buffer gams-temp-cont-buffer)
  (gams-edit-template))

(defun gams-temp-reedit ()
  "Re-edit already registered templates."
  (interactive)
  (let ((temp-name (gams-temp-get-name))
	(temp-line (count-lines (point-min) (+ (point) 1)))
	key)
    (gams-temp-show-cont)
    ;; Go to "*Template Content*" buffer.
    (switch-to-buffer gams-prog-file-buff)
    (pop-to-buffer (get-buffer-create gams-temp-cont-buffer))
    (when (get-buffer gams-temp-edit-buffer)
      (kill-buffer gams-temp-edit-buffer))
    (rename-buffer gams-temp-edit-buffer)
    ;; Switch to gams-edit-template mode.
    (gams-edit-template temp-name)
    (switch-to-buffer gams-temp-buffer)
    (goto-line temp-line)
    (gams-temp-show-cont)))

(defun gams-temp-rename ()
  "Rename already registered templates."
  (interactive)
  (let* ((buffer-read-only nil)
	 (temp-alist gams-user-template-alist)
	 (old-name (gams-temp-get-name))
	 (new-name (read-input "Insert a new name: " old-name))
	 (line-num (count-lines (point-min) (+ 1 (point)))))
    (when temp-alist
      ;; Replace the old name with the new name.
      (setcar (assoc old-name temp-alist) new-name)
      ;; If gams-save-template-change is non-nil, save.
      (when gams-save-template-change
	(gams-write-alist-to-file))
      (gams-temp-show-list)
      (goto-line line-num)
      (gams-temp-show-cont))))

(defun gams-temp-delete ()
  "Delete existing templates."
  (interactive)
  (when gams-user-template-alist
    (let ((temp-name (gams-temp-get-name))
	  (line-num (count-lines (point-min) (+ 1 (point))))
	  key)
      ;; Delete.
      (message (format "Do you really want to delete `%s'?  Type `y' if yes." temp-name))
      (setq key (read-char))
      (when (equal key ?y)
	(forward-line 1)
	(gams-template-processing "del" temp-name)
	(gams-temp-show-list)
	(goto-line (- line-num 1))
	(gams-temp-show-cont))
      )))

(defun gams-temp-up ()
  "Move up a template."
  (interactive)
  (when gams-user-template-alist
    (let ((temp-name (gams-temp-get-name))
	  (temp-alist gams-user-template-alist)
	  (line-num (count-lines (point-min)
				 (+ 1 (point)))))
      (if (equal 1 line-num)
	  nil
	;;
	(setq gams-user-template-alist
	      (gams-temp-alist-change temp-alist temp-name)))
      (gams-temp-show-list)
      (goto-line (- line-num 1))
      (gams-temp-show-cont)
      )))

(defun gams-temp-down ()
  "Move down a template."
  (interactive)
  (when gams-user-template-alist
    (let ((temp-name (gams-temp-get-name))
	  (temp-alist gams-user-template-alist)
	  (line-num (count-lines (point-min)
				 (+ 1 (point))))
	  (sig-max-num (length gams-user-template-alist)))
      (if (equal sig-max-num line-num)
	  nil
	;;
	(setq gams-user-template-alist
	      (gams-temp-alist-change temp-alist temp-name t)))
      (gams-temp-show-list)
      (goto-line (+ line-num 1))
      (gams-temp-show-cont)
      )))

;; Editing templates.
(defun gams-temp-add-key ()
  (message
   (format "Edit a template!  C-xC-s = save and exit, C-cC-s = save, C-xk = quit, C-xh = help")))

; key assignment.
(defvar gams-template-edit-map (make-keymap) "keymap for gams-template-edit")
(let ((map gams-template-edit-map))
  (define-key map "\C-ck" 'gams-insert-statement)

  (define-key map "\C-cd" 'gams-insert-dollar-control)
  (define-key map "(" 'gams-insert-parens)
  (define-key map "\"" 'gams-insert-double-quotation)
  (define-key map "`" 'gams-insert-single-quotation)

  (define-key map "\C-co" 'gams-insert-comment)
  (define-key map "\t" 'gams-insert-tab)

  (define-key map "\C-xh" 'gams-edit-template-help)
  (define-key map "\C-x\C-s" 'gams-save-template)
  (define-key map "\C-c\C-s" 'gams-save-and-exit-template)
  (define-key map "\C-xk" 'gams-quit-template))

;;; Menu for GAMS-TEMPLATE-EDIT mode. 
(easy-menu-define 
  gams-template-edit-menu gams-template-edit-map "Menu keymap for GAMS-TEMPLATE-EDIT mode."
  '("TEMPLATE-EDIT"
    ["Save the template" gams-save-template t]
    ["Save the template and exit" gams-save-and-exit-template t]
    ["Show help" gams-edit-template-help t]
    ["Quit TEMPLATE-EDIT mode" gams-quit-template t]
    "--"
    ["Insert GAMS statement" gams-insert-statement t]
    ["Insert GAMS dollar control" gams-insert-dollar-control t]
    ["Insert parenthesis" gams-insert-parens t]
    ["Insert double quotations" gams-insert-double-quotation t]
    ["Insert single quotations" gams-insert-single-quotation t]
    ["Insert a comment template" gams-insert-comment t]
    ))



(defun gams-edit-template (&optional file)
  "Edit a template.

FILE is a file name.  It is used for gams-temp-reedit.

'\\[gams-save-template] - Save a template.
'\\[gams-save-and-exit-template] - Save a template and exit.
'\\[gams-quit-template] - Quit.
'\\[gams-edit-template-help] - Show this help.

'\\[gams-insert-statement] - Insert GAMS statement with completion.
'\\[gams-insert-dollar-control] - Insert GAMS statement (dollar control option).
'\\[gams-insert-parens] - Insert parenthesis.
'\\[gams-insert-double-quotation] - Insert double quotations.
'\\[gams-insert-single-quotation] - Insert single quotations.

'\\[gams-insert-comment] - Insert comment template."
  (interactive)
  (delete-other-windows)
  (pop-to-buffer gams-temp-edit-buffer)
  (kill-all-local-variables)
  (setq major-mode 'gams-template-edit)
  (setq mode-name "TEMPLATE-EDIT")
  (use-local-map gams-template-edit-map)
  (setq fill-prefix "\t\t")
  (mapcar
   'make-local-variable
   '(fill-column
     fill-prefix
     indent-line-function
     comment-start
     comment-start-skip
     gams-comment-prefix
     gams-eolcom-symbol
     gams-inlinecom-symbol-start
     gams-inlinecom-symbol-end
     ))
  (setq fill-column gams-fill-column
	fill-prefix gams-fill-prefix
	comment-end "")
  ;; key.
  (when gams-insert-dollar-control-on
    (define-key gams-mode-map "$" 'gams-insert-dollar-control))
  ;; indent.
  (when gams-indent-on
    (setq indent-line-function 'gams-indent-line)
    (define-key gams-template-edit-map "\C-m" 'gams-newline-and-indent)
    (substitute-all-key-definition
     'newline-and-indent 'gams-newline-and-indent gams-template-edit-map))
  ;; Make `gams-comment-prefix' a buffer-local variable.
  (let (temp)
    (if (setq temp (gams-search-dollar-comment))
	(setq comment-prefix temp
	      gams-comment-prefix temp
	      comment-start temp
	      comment-start-skip (concat "^[" temp "]+[ \t]*"))
      (setq comment-prefix gams-comment-prefix-default
	    gams-comment-prefix gams-comment-prefix-default
	    comment-start-skip (concat "^[" gams-comment-prefix-default "]+[ \t]*")
	    comment-start gams-comment-prefix-default)))
  ;; Make `gams-eolcom-symbol' a buffer-local variable.
  (let (temp)
    (if (setq temp (gams-search-dollar-com t))
	(setq gams-eolcom-symbol temp)
      (setq gams-eolcom-symbol nil)))
  ;; Make `gams-inlinecom-symbol-start' and `gams-inlinecom-symbol-end'
  (let (temp)
    (if (setq temp (gams-search-dollar-com))
	(progn (setq gams-inlinecom-symbol-start (car temp))
	       (setq gams-inlinecom-symbol-end (cdr temp)))
      (setq gams-inlinecom-symbol-start nil)))
  ;; Create the alist of statements.  Is this necessary?
  ;; See `gams-statement-update'.
  (setq gams-statement-alist
	(gams-statement-to-alist gams-statement-up gams-statement-upcase))
  ;; Create the alist of dollar control options.  Is this necessary?
  ;; See `gams-statement-update'.  
  (if gams-use-mpsge
      ;; Use mpsge.
      (progn
	(setq gams-dollar-control-alist
	      (gams-statement-to-alist
	       (append gams-dollar-control-up gams-statement-mpsge)
	       gams-dollar-control-upcase)))
    ;; Not use mpsge
    (setq gams-dollar-control-alist
	  (gams-statement-to-alist gams-dollar-control-up gams-dollar-control-upcase)))
  ;; Font-lock
  (make-local-variable 'font-lock-defaults)
  (setq font-lock-defaults '(gams-font-lock-keywords t t))
  ;; Update.
  (gams-statement-update)
  ;; set file name used for 
  (make-local-variable 'gams-add-template-file)
  (setq gams-add-template-file file)
  (setq buffer-read-only nil)
  ;; TEST.
  (set-buffer-modified-p nil)
  (current-buffer)
  (gams-temp-add-key)
  (easy-menu-add gams-template-edit-menu)
  (recursive-edit)
  (kill-buffer gams-temp-edit-buffer)    
  (switch-to-buffer gams-temp-buffer)
  (gams-temp-show-list)
  (gams-temp-show-cont)
  );; gams-edit-template ends here.

(defun gams-edit-template-help ()
  "Show help."
  (interactive)
  (describe-function 'gams-edit-template))

(defun gams-save-and-exit-template ()
  ""
  (interactive)
  (gams-save-template)
  (exit-recursive-edit))

(defun gams-save-template ()
  "Register a template."
  (interactive)
  (save-excursion
    (let* ((temp-name (read-input
		       "Enter a name of this template: "
		       gams-add-template-file))
	   (temp-alist gams-user-template-alist)
	   list-tmp over-flag)
      (if (string= temp-name "")
	  (error "Need to specify a name of this template!")
	(setq list-tmp
	      (list temp-name
		    (gams*buffer-substring (point-min) (point-max))))
	;; The same name is already used?
	(if (assoc temp-name temp-alist)
	    ;; Already used.
	    ;; Overwrite it?
	    (if (setq over-flag
		      (y-or-n-p
		       "This template name is already exists. Do you want to override it?: "))
		;; Yes
		(gams-template-processing "red"
					  (car list-tmp)
					  (car (cdr list-tmp)))
	      ;; No. Do nothing.
	      nil)
	  ;; The same name is not registered. 
	  (gams-template-processing "reg"
				    (car list-tmp)
				    (car (cdr list-tmp)))
	  )))))
  
(defun gams-quit-template ()
  ""
  (interactive)
  (exit-recursive-edit))

(defun gams-search-default-temp ()
  (let ((ret nil)
	(functions sig-search-functions))
    (while functions
      (if (setq ret (funcall (car functions)))
	  (setq functions nil)
	(setq functions (cdr functions))))
    (or ret sig-default-name)))

(defun gams-register-template-edit (tem-cont)
  "Escape double quoatation and backslash."
  (let ((temp-buff "*gams temp buff")
	string)
    (save-excursion
      (get-buffer-create temp-buff)
      (switch-to-buffer temp-buff) ;; Just for debug.
      (erase-buffer)
      (goto-char (point-min))
      (insert tem-cont)
      ;; Replace several strings with regular expression.
      (goto-char (point-min))
      (while (re-search-forward "\\(\\\\\\)" nil t)
	(setq a-point (match-beginning 1))
	(setq b-point (match-end 1))
	(replace-match "\\\\\\\\"))
      (goto-char (point-min))
      (while (re-search-forward "\\(\"\\)" nil t)
	(setq a-point (match-beginning 1))
	(setq b-point (match-end 1))
	(replace-match "\\\\\""))
      ;; Store regular expression to string.
      (setq string (gams*buffer-substring (point-min) (point-max)))
      ;; Delete temporary buffer.
      (kill-buffer temp-buff)
      ;; Return the content of string.
      string)))

(defun gams-temp-write-alist ()
  "Update `gams-user-template-alist'."
  (let ((temp-list gams-user-template-alist))
    (erase-buffer)
    (insert-string (concat "(setq gams-user-template-alist '(\n"))
    (goto-char (point-max))
    (while temp-list
      (insert (concat "(\"" (car (car temp-list)) "\" . \""
		      (gams-register-template-edit (cdr (car temp-list)))
		      "\")\n"))
      (goto-char (point-max))
      (setq temp-list (cdr temp-list)))
    (insert "))\n")
    (eval-buffer)))

(defun gams-template-processing (type name &optional cont)
  "Process a template in a temporary buffer.

TYPE is a sting.
reg = register a new template.
del = delete.
red = re-edit."
  (let ((cur-buff (current-buffer))
	(temp-buff " *gams-temporary*")
	(temp-file gams-template-file)
	temp-cont)
    ;; Move to the temporary buffer
    (get-buffer-create temp-buff)
    (switch-to-buffer temp-buff)
    ;; Cases:
    (cond
    ;; register
     ((equal type "reg")
      (setq gams-user-template-alist
	    (append (list (cons name cont))
		    gams-user-template-alist)))
    ;; delete
     ((equal type "del")
      (setq gams-user-template-alist
	    (delete
	     (assoc name gams-user-template-alist)
	     gams-user-template-alist)))
    ;; red
     ((equal type "red")
      (setcdr (assoc name gams-user-template-alist) cont)))
    ;; reedit. not yet.
    ;; Write the content of gams-user-template-alist in the temporary
    ;; buffer.
    (gams-temp-write-alist)
    ;; If gams-save-template-change is non-nil, save the temporary buffer
    ;; as gams-template-file.
    (if gams-save-template-change
	(write-file gams-template-file))
    (kill-buffer (get-file-buffer gams-template-file))
    (switch-to-buffer cur-buff)
    ))

(defun gams-write-alist-to-file ()
  "Save the content of `gams-user-template-alist' into the file
`gams-user-template-alist'."
  (interactive)
  (save-excursion
    (if gams-user-template-alist
	(if (null (eq gams-user-template-alist gams-user-template-alist-init))
	    (progn
	      (set-buffer (get-buffer-create " *gams-temporary*"))
	      (gams-temp-write-alist)
	      (write-file gams-template-file)
	      (kill-buffer (get-file-buffer gams-template-file)))))))
  
(defun gams-temp-alist-change (alist ele &optional flag)
  "Reorder `gams-user-template-alist'.

ELE is car part.
If FLAG is t, move down."
  (interactive)
  (let ((temp-alist alist)
	(car-p ele)
	alist-a
	alist-b
	list-a
	list-b)
    ;; Judge whether alist include ele.
    (if (setq alist-b
	      (member (assoc car-p temp-alist)
		      temp-alist))
	;; Included.
	(progn
	  (cond
	  ;; If flag is nil
	   ((null flag)
	    ;; If ele is the first element, do nothing.
	    (if (null (equal temp-alist alist-b))
		;; If ele is the second or later element 
		(progn
		  ;; 
		  (setq list-a (car alist-b))
		  (setq alist-b (cdr alist-b))
		  ;;
		  (setq temp-alist (reverse temp-alist))
		  (setq alist-a
			(member (assoc car-p temp-alist)
				temp-alist))
		  (setq alist-a	(cdr alist-a))
		  (setq list-b (car alist-a))
		  (setq alist-a (cdr alist-a))
		  (setq alist-a (append (list list-a) alist-a))
		  (setq alist-a (reverse alist-a))
		  (setq alist-b (append (list list-b) alist-b))
		  (setq temp-alist (append alist-a alist-b))
		  )))
	   ;; If flag is t
	   (flag
	    ;; If ele is the last element, do nothing.
	    (if	(null (equal alist-b (nth (- (length temp-alist) 1) temp-alist)))
		(progn
		  ;; alist-b
		  (setq list-a (car alist-b))
		  (setq list-b (car (cdr alist-b)))
		  (setq alist-b (cdr (cdr alist-b)))
		  (setq alist-b (append (list list-a) alist-b))
		  (setq alist-b	(append (list list-b) alist-b))
		  ;; alist-a
		  (setq temp-alist (reverse temp-alist))
		  (setq alist-a	(member (assoc car-p temp-alist) temp-alist))
		  (setq alist-a	(cdr alist-a))
		  (setq alist-a (reverse alist-a))
		  ;; New alist.
		  (setq temp-alist (append alist-a alist-b))
		  ))))))
    temp-alist))

(defun gams-temp-replace (begin end)
  "Replace a mark with cursor in the inserted template.

BEGIN and END are points."
  (interactive)
  (let ((mark gams-template-mark))
    (goto-char begin)
    (if (re-search-forward (format "\\(%s\\)" mark) end t)
	(progn
	  (goto-char (match-beginning 0))
	  (replace-match ""))
      (goto-char end))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code for the GAMS-OUTLINE mode.
;;;	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;(autoload 'gams-outline "gams-ol" "Start GAMS-OUTLINE" t)

;;; Variables for GAMS-OUTLINE mode.

(defcustom gams-ol-height 15
  "*The height of the OUTLINE buffer with one LST buffer."
  :type 'number
  :group 'gams)

(defcustom gams-ol-height-two 8
  "*The height of the OUTLINE buffer with two LST buffers."
  :type 'number
  :group 'gams)

(defcustom gams-ol-view-item
      '(("SUM" . t)
	("VAR" . t)
	("EQU" . t)
	("PAR" . t)
	("SET" . t)
	("VRI" . t)
	("LOO" . t)
	("OTH" . t)
	("COM" . t))
  "The default alist of viewable items.

Each list consists of a pair of the item name and its flag.  Non-nil of
flag means the item is viewable by default.

The order of items has the meaning in this alist.  Items are listed in the
SELECT-ITEM buffer according to this order.  So, if you want to show MAR
on the top, you must write MAR at the fisrt in this alist.
"
  :type '(repeat (cons :tag "option" (string :tag "item") (boolean :tag "flag")))
  :group 'gams)

;;; Key for gams-outline.

(defcustom gams-olk-1 "?"
  "*Key for `gams-ol-help'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-olk-2 "N"
  "*Key for `gams-ol-view-next'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-olk-3 "P"
  "*Key for `gams-ol-view-prev'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-olk-4 "t"
  "*Key for `gams-ol-select-item'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-olk-5 " "
  "*Key for `gams-ol-view-base'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-olk-6 "q"
  "*Key for `gams-ol-quit'."
  :type 'string
  :group 'gams-keys)

(defcustom gams-olk-7 "m"
  "*Key for `gams-ol-mark'."
  :type 'string
  :group 'gams-keys)

;;; Codes for outlineing LST files.  

(defun gams-ol-create-list (alist)
  "Create a list of car part from ALIST."
  (let ((temp-alist (reverse alist))
	new-list)
    (while temp-alist
      (setq new-list (append (list (car (car temp-alist))) new-list))
      (setq temp-alist (cdr temp-alist)))
    new-list))

(setq gams-ol-item
      (gams-ol-create-list gams-ol-view-item))
      
(defun gams-ol-store-point (&optional flag)
  "Store points of re-search-forward results.

If FLAG is non-nil, it means the item is VARIABLE."
  (let
      (par-type2
       par-name2
       par-exp2)
    (if flag
	(setq par-type2 "VRI")
      (setq  par-type2
	     (substring (upcase
			 (gams*buffer-substring
			  (match-beginning 1)
			  (match-end 1)))
			0 3)))
    (setq par-name2 (gams*buffer-substring
		      (match-beginning 2)
		      (match-end 2)))
    (setq par-exp2 (gams*buffer-substring
			 (match-beginning 3)
			 (match-end 3)))
    (list par-type2 par-name2 par-exp2)))

  
(defun gams-outline ()
  "Evoke the GAMS-OUTLINE mode."
  (interactive)
  (let ((buf-f-name (buffer-file-name))
	(buffname (concat "*"
			  (file-name-sans-extension
			   (file-name-nondirectory
			    (buffer-file-name))) "-OUTLINE*"))
	(lst-file-buf (current-buffer)))
    ;; Judge whether OV buffer is already created or not.
    (if (or (null (get-buffer buffname))
	    (null gams-ol-flag))
	;; OV buffer is not created or out of date.
	(progn
	  (setq gams-ol-flag t)
	  (get-buffer-create buffname)
	  (gams-ol-show buffname
			(gams-ol-convert (gams-ol-make-alist)))
	  ;; Switch to the OV buffer.
	  (switch-to-buffer buffname)
	  (recenter)
	  ;; Start gams-ol-mode.
	  (gams-ol-mode lst-file-buf))
      ;; Switch to the OV buffer.
      (switch-to-buffer buffname)
      (recenter)
    )))

(defun gams-ol-get-alist (&optional buffer)
  "Return the value of `gams-over-alist' in the current LST buffer.

If BUFFER is non-nil, the current buffer is OV buffer, not LST buffer."
  (let (alist
	(cur-buf (if buffer (current-buffer) nil)))
    ;; The current buffer is LST buffer or OV buffer?
    (if cur-buf
	;; If OV buffer, switch to LST buffer.
	(progn
	  (set-buffer gams-ol-lst)
	  (setq alist gams-over-alist)
	  (switch-to-buffer cur-buf))
      ;; LST buffer.
      (setq alist gams-over-alist))
    ;; Return the value of alist.
    alist))
    
; key assignment.
(defvar gams-ol-mode-map (make-keymap) "Keymap for GAMS-OUTLINE mode")
(let ((map gams-ol-mode-map))
  (define-key map gams-olk-5 'gams-ol-view-base)
  (define-key map gams-olk-2 'gams-ol-view-next)
  (define-key map gams-olk-3 'gams-ol-view-prev)
  (define-key map gams-olk-4 'gams-ol-select-item)

  (define-key map gams-olk-7 'gams-ol-mark)
  (define-key map "u" 'gams-ol-unmark)
  (define-key map "y" 'gams-ol-jump-mark)
  
  (define-key map "i" 'gams-ol-back-to-lst)
  (define-key map gams-olk-1 'gams-ol-help)
  (define-key map gams-olk-6 'gams-ol-view-quit)
  
  (define-key map "l" 'recenter)
  (define-key map [return] 'scroll-up)
  (define-key map [delete] 'scroll-down)
  (define-key map "1" 'delete-other-windows)
  (define-key map "n" 'gams-ol-next)
  (define-key map "p" 'gams-ol-prev)

  (define-key map "d" 'gams-lst-scroll-1)
  (define-key map "f" 'gams-lst-scroll-down-1)
  (define-key map "g" 'gams-lst-scroll-2)
  (define-key map "h" 'gams-lst-scroll-down-2)
  (define-key map "j" 'gams-lst-scroll-double)
  (define-key map "k" 'gams-lst-scroll-down-double)

  (define-key map "D" 'gams-lst-scroll-page-1)
  (define-key map "F" 'gams-lst-scroll-page-down-1)
  (define-key map "G" 'gams-lst-scroll-page-2)
  (define-key map "H" 'gams-lst-scroll-page-down-2)
  (define-key map "J" 'gams-lst-scroll-page-double)
  (define-key map "K" 'gams-lst-scroll-page-down-double)

  (define-key map "o" 'gams-ol-narrow-one-line)
  (define-key map "l" 'gams-ol-widen-one-line)
  (define-key map "w" 'gams-lst-resize-frame)
  (define-key map "e" 'gams-lst-move-frame)

  (define-key map "\C-cf" 'gams-choose-font-lock-level)
  )

;;; Menu for GAMS-OUTLINE mode.
(easy-menu-define 
  gams-ol-mode-menu gams-ol-mode-map "Menu keymap for GAMS-OUTLINE mode."
  '("GAMS-OUTLINE"
    ["Show the current item" gams-ol-view-base t]
    ["Show the next item" gams-ol-view-next t]
    ["Show the previous item" gams-ol-view-prev t]
    ["Select viewable items" gams-ol-select-item t]
    "--"
    ["Mark an item" gams-ol-mark t]
    ["Unmark an item" gams-ol-unmark t]
    ["Jump to the marked item" gams-ol-jump-mark t]
    "--"
    ["Switch back to the LST buffer" gams-ol-back-to-lst t]
    ["Show help" gams-ol-help t]
    ["Quit OUTLINE mode" gams-ol-view-quit t]
    "--"
    ["Widen the window with one line" gams-ol-widen-one-line t]
    ["Narrow the window with one line" gams-ol-narrow-one-line t]
    ["Widen the window" delete-other-windows t]
    ["Recentering" recenter t]
    ["Scroll up" scroll-up t]
    ["Scroll down" scroll-down t]
    ["Next line" gams-ol-next t]
    ["Previous line" gams-ol-prev t]
    ["Resize frame" gams-lst-resize-frame t]
    ["Move frame" gams-lst-move-frame t]
    "--"
    ["Choose font-lock level." gams-choose-font-lock-level t]
    ["Fontify block." font-lock-fontify-block t]
    ))


(defun gams-ol-mode (lst-file-buf)
"The GMS-OUTLINE mode.

\\[gams-ol-view-base]		Show the content of the item on the current line.
\\[gams-ol-view-next]		Show the content of the next item.
\\[gams-ol-view-prev]		Show the content of the previous item.
\\[gams-ol-select-item]		Select viewable items.

\\[gams-ol-mark]		Mark an item.
\\[gams-ol-unmark]		Unmark an item.
\\[gams-ol-jump-mark]		Jump to the marked line.

\\[gams-ol-back-to-lst]		Switch back to the LST buffer.
\\[gams-ol-help]		Show this help.
\\[gams-ol-view-quit]		Quit.

\\[gams-ol-widen-one-line]		Widen the window with one line.
\\[gams-ol-narrow-one-line]		Narrow the window with one line.
\\[delete-other-windows]		Widen the window.
\\[recenter]		Recenter.
\\[scroll-up] or RET	Scroll up the OUTLINE buffer.
\\[scroll-down] or DEL	Scroll down the OUTLINE buffer.
\\[delete-other-windows]		Widen the OUTLINE window.
\\[gams-ol-next]		Next line.
\\[gams-ol-prev]		Previous line.
\\[gams-lst-resize-frame]		Resize frame.
\\[gams-lst-move-frame]		Move frame.

Commands for Scrolling

Commands for scrolling are almost the same as the ones in the GAMS-LST mode.

Suppose that there are three windows displayed like

    __________________	  
   |   	      	      |  
   |  OUTLINE buffer  |  ==>  OV-1
   |  CURSOR  here    |  
   |   	      	      |  
   |------------------|
   |   	      	      |  
   |  LST buffer 1    |  ==>  LST-1.
   |   	      	      |  
   |------------------|  
   |		      | 
   |  LST buffer 2    |  ==>  LST-2.
   |   	      	      |  
    ------------------

\\[gams-lst-scroll-1](\\[gams-lst-scroll-down-1])		Scroll the next buffer (LST-1) up (down) one line.
\\[gams-lst-scroll-2](\\[gams-lst-scroll-down-2])		Scroll the other next buffer (LST-2) up (down) one line.
\\[gams-lst-scroll-double](\\[gams-lst-scroll-down-double])		Scroll two LST buffers (LST-1 and LST-2) up (down) one line.

Keyboard.

  _____________________________________________________________
  |         |         |         |         |         |         |
  |    d    |    f    |    g    |    h    |    j    |    k    |
  |         |         |         |         |         |         |
  -------------------------------------------------------------

       |         |         |         |         |         |

      UP        DOWN      UP        DOWN      UP        DOWN
         LST-1               LST-2             LST-1 & 2


If only two window exists (e.g. OV-1 and LST-1),

\\[gams-lst-scroll-1] or '\\[gams-lst-scroll-2] or '\\[gams-lst-scroll-double]  ==> Scroll LST-1 up a line.
\\[gams-lst-scroll-down-1] or '\\[gams-lst-scroll-down-2] or '\\[gams-lst-scroll-down-double]  ==> Scroll LST-1 down a line.

The followings are page scroll commands.  Just changed to upper cases.

\\[gams-lst-scroll-page-1](\\[gams-lst-scroll-page-down-1])		Scroll the next buffer (LST-1) up (down) a page.
\\[gams-lst-scroll-page-2](\\[gams-lst-scroll-page-down-2])		Scroll the other next buffer (LST-2) up (down) a page.
\\[gams-lst-scroll-page-double](\\[gams-lst-scroll-page-down-double])		Scroll two buffers (LST-1 and LST-2) up (down) a page."
  (interactive)

  (setq major-mode 'gams-ol-mode)
  (setq mode-name "GAMS-OUTLINE")
  (use-local-map gams-ol-mode-map)

  (setq buffer-read-only t)

  (make-local-variable 'font-lock-defaults)
  (make-local-variable 'font-lock-keywords)
  (gams-update-font-lock-keywords "o" gams-ol-font-lock-level)
  (setq font-lock-keywords gams-ol-font-lock-keywords)
  (setq font-lock-defaults '(font-lock-keywords t t))
;  (font-lock-fontify-buffer)

  ;; Store the LST buffer name in a local variable.
  (make-local-variable 'gams-ol-lst)
  (setq gams-ol-lst lst-file-buf)

  ;; Create the local variable gams-ol-mark-flag.  gams-ol-mark-flag is
  ;; assigned non-nil if an item is marked in the OUTLINE buffer.
  (make-local-variable 'gams-ol-mark-flag)
  (setq gams-ol-mark-flag nil)

  ;; Menu
  (easy-menu-add gams-ol-mode-menu)

  ;;
  (if gams-emacs
      (when global-font-lock-mode
	(font-lock-mode t))
    (font-lock-mode t))

  ;; Run hook
  (run-hooks 'gams-ol-mode-hook)

  ;; Turn on font-lock.
  (if (and (null (equal gams-ol-font-lock-keywords nil))
	   font-lock-mode)
      (if gams-emacs
	  (font-lock-fontify-buffer))
    (if (equal gams-ol-font-lock-keywords nil)
	(font-lock-mode -1)))
)

(defun gams-ol-count-line ()
  "Calculate the current line number in the OUTLINE buffer."
  (let ((point-a (point))
	(count 1))
    (goto-char (point-min))
    (while
	(re-search-forward "[\n\C-m]" point-a t)
      (setq count (+ 1 count)))
    count))
    
(defun gams-ol-view-quit ()
  "Quit the GAMS-OUTLINE mode."
  (interactive)
  (let ((cur-buf (current-buffer)))
    ;; Unmark the marked item.
    (gams-ol-unmark)
    (if (buffer-live-p (get-buffer gams-ol-lst))
	(switch-to-buffer gams-ol-lst)
      (message "No correspoding LST buffer!")
      (sleep-for 1))
    (kill-buffer cur-buf)
    (delete-other-windows)))

(defun gams-ol-help ()
  "Show help in the GAMS-OUTLINE mode."
  (interactive)
  (describe-function 'gams-ol-mode))

(defun gams-ol-back-to-lst ()
  "Switch to the LST file buffer."
  (interactive)
  ;; Unmark.
  (gams-ol-unmark)
  (switch-to-buffer gams-ol-lst)
  (recenter))

(defun gams-ol-view-base ()
  "Show the content of the item on the current line in the another window."
  (interactive)
  (let ((line-num (gams-ol-count-line))
	list-par ele-par point-par
	(cur-buf (current-buffer))
	(flag gams-ol-mark-flag))
    (setq list-par (assoc line-num (gams-ol-get-alist t)))
    (setq ele-par (car list-par))
    (setq point-par (car (cdr list-par)))
    (if (null list-par)
	nil
      ;; If list-par is not nil.
      (if (one-window-p t)
	  ;; If only one window.
	  (if (null flag)
	      (progn
		(split-window
		 (selected-window)
		 (+ 1 gams-ol-height))
		(other-window 1)
		(set-window-buffer (selected-window) gams-ol-lst)		
		(goto-char point-par)
		(recenter 1)
		(pop-to-buffer cur-buf))
	    (split-window
	     (selected-window)
	     (+ 1 gams-ol-height-two))
	    (other-window 1)
	    (set-window-buffer (selected-window) gams-ol-lst)
	    (split-window
	     (selected-window)
	     (/ (window-height) 2))
	    (goto-char (car (cdr (assoc flag (gams-ol-get-alist)))))
	    (recenter 1)
	    (other-window 1)
	    (goto-char point-par)
	    (recenter 1)
	    (pop-to-buffer cur-buf))
	;; If two or more windows exit.
	(delete-other-windows)
	(if (null flag)
	    (progn
	      (split-window
	       (selected-window)
	       (+ 1 gams-ol-height))
	      (other-window 1)
	      (set-window-buffer (selected-window) gams-ol-lst) ;
	      (goto-char point-par)
	      (recenter 1)
	      (other-window 1))
	  ;; 3 windows.
	  (split-window
	   (selected-window)
	   (+ 1 gams-ol-height-two))
	  (other-window 1)
	  (set-window-buffer (selected-window) gams-ol-lst) ;
	  (split-window
	   (selected-window)
	   (/ (window-height) 2))
	  (goto-char (car (cdr (assoc flag (gams-ol-get-alist)))))
	  (recenter 1)
	  (other-window 1)
	  (goto-char point-par)
	  (recenter 1)
	  (pop-to-buffer cur-buf))
	);; If ends.
      (gams-ol-show-key)
      )))

(defun gams-ol-show-key ()
  "Show the basic keybindings in the GAMS-OUTLINE mode."
  (interactive)
  (message
   (format "%s = help, %s = show, [%s]oggle, [%s]ark, d,f,g,h,j,k = scroll, [%s]uit."
	   gams-olk-1
	   gams-olk-5
	   gams-olk-4
	   gams-olk-7
	   gams-olk-6)))

(defun gams-ol-next ()
  "Move to the next line."
  (interactive)
  (next-line 1)
  (gams-ol-show-key))

(defun gams-ol-prev ()
  "Move to the previous line."
  (interactive)
  (next-line -1)
  (gams-ol-show-key))

(defun gams-ol-view-next ()
  "Show the content of the item on the next line."
  (interactive)
  (next-line 1)
  (gams-ol-view-base))
  
(defun gams-ol-view-prev ()
  "Show the content of the item on the previous line."
  (interactive)
  (next-line -1)
  (gams-ol-view-base))

(defun gams-ol-mark ()
  "Mark an item."
  (interactive)
  (let ((cur-buff (current-buffer))
	(buffer-read-only nil)
	(line-num (gams-ol-count-line))
	(flag gams-ol-mark-flag)
	(com (save-excursion
	       (beginning-of-line)
	       (if (looking-at "COM:") t nil))))
    (when (null com)
      ;; Delete mark if flag is non-nil.
      (if flag
	  (progn
	    (save-excursion
	      (goto-line flag)
	      (beginning-of-line)
	      (delete-char 1)
	      (insert " "))))
      ;;
      (when (null com)
	(beginning-of-line)
	(delete-char 1)
	(insert "*")
	(beginning-of-line)
	(setq gams-ol-mark-flag line-num)))
    (gams-ol-show-key)))

(defun gams-ol-count-win ()
  "Count the number of windows."
  (interactive)
  (let ((cur-win (selected-window))
	(num 1)
	flag)
    (save-excursion
      (if (one-window-p)
	  nil
	(catch 'quit
	  (while t
	    (other-window 1)
	    (setq flag (selected-window))
	    (cond
	     ((not (eq flag cur-win))
	      (setq num (+ num 1)))
	     ((eq flag cur-win)
	      (throw 'quit t)))))))
    num))
      
(defun gams-ol-unmark ()
  "Unmark the marked item."
  (interactive)
  (let ((buffer-read-only nil)
	line-num flag)
    (if gams-ol-mark-flag
	(save-excursion
	  (goto-char (point-min))
	  (if (re-search-forward "^* " nil t)
	      (progn (beginning-of-line)
		     (delete-char 1)
		     (insert " ")
		     (setq gams-ol-mark-flag nil)))))
    (gams-ol-show-key)))

(defun gams-ol-jump-mark()
  "Jumpt to the marked items."
  (interactive)
  (let ((line-num gams-ol-mark-flag))
    (if line-num
	(goto-line line-num))))

(defun gams-ol-make-alist ()
  "Make the alist of all items from the LST buffer.

The alist includes non-viewable items."
  (interactive)
  (let (point-a	point-b
	(par-index 0)			; Index of item.
	par-point			; Point of item.
	par-list
	flag-a
	(par-alist nil)
	(lst-buf (current-buffer)))
    (goto-char (point-min))
    ;;
    (while
	;; Search items.
	(re-search-forward
	 (concat "^\\(----\\|               S O L V E      S U M M A R Y"
		 "\\|[*][*][*][*] REPORT SUMMARY :\\|"
		 "               L O O P S\\)") nil t)
      ;; Store the match.
      (setq flag-a (gams*buffer-substring (match-beginning 1)
				     (match-end 1)))
      ;; If an item is found.
      (cond
       ;; The case for VAR, EQU, SET, PAR, COM.
       ((equal flag-a "----")
	(save-excursion
	  (forward-line 1)
	  (setq point-b (point)))
	(cond
	 ;; set.
	 ((re-search-forward "[ ]+[0-9]*[ ]*\\(set\\)[ ]+\\([^ ]+\\)[ ]+\\(.*\\)" point-b t)
	  (beginning-of-line)
	  (setq par-point (point))
	  (end-of-line)
	  ;; 
	  (setq par-index (1+ par-index))

	  (setq par-list (gams-ol-store-point))
	  (setq par-alist
		(cons
		 (append (list par-index par-point) par-list) par-alist)))
	 ;; parameter.
	 ((re-search-forward "[ ]+[0-9]*[ ]*\\(parameter\\)[ ]+\\([^ ]+\\)[ ]+[=]?[ ]*[0-9.E-]*[ ]*\\(.*\\)" point-b t)
	  (beginning-of-line)
	  (setq par-point (point))
	  (end-of-line)
	  (setq par-index (1+ par-index))
	  (setq par-list (gams-ol-store-point))
	  ;; Make alist.
	  (setq par-alist
		(cons
		 (append (list par-index par-point) par-list) par-alist))
	  ;; Subprocess
	  (let (point-c point-e)
	    (while
		(progn
		  (setq point-c (point))
		  (re-search-forward "\\(\n\n\n\\|\f\\)" nil t)
		  (setq point-e (point))
		  (goto-char point-c)
		  (re-search-forward "^[ ]+\\(parameter\\)[ ]+\\([^ ]+\\)[ ]+[=]?[ ]*[0-9.E-]*[ ]*\\(.*\\)" point-e t))
	      (beginning-of-line)
	      (setq par-point (point))
	      (end-of-line)
	      (setq par-index (1+ par-index))
	      (setq par-list (gams-ol-store-point))
	      (setq par-alist
		    (cons
		     (append (list par-index par-point) par-list) par-alist))
	      )))
	 ;; VARIABLE.
	 ((re-search-forward "[ ]+[0-9]*[ ]*\\(variable\\)[ ]+\\([^ ]+\\)[ ]+\\(=[ ]+[0-9.-]+[ ]+\\(.*\\)\\|\\(.*\\)\\)" point-b t)
	  (beginning-of-line)
	  (setq par-point (point))
	  (end-of-line)
	  (setq par-index (1+ par-index))
	  (setq par-list (gams-ol-store-point t))
	  (setq par-alist
		(cons
		 (append (list par-index par-point) par-list) par-alist))
	  ;; subprocess
	  (let (point-c point-e)
	    (while
		(progn
		  (setq point-c (point))
		  (re-search-forward "\\(\n\n\n\\|\f\\)" nil t)
		  (setq point-e (point))
		  (goto-char point-c)
		  (re-search-forward "^[ ]+\\(variable\\)[ ]+\\([^ ]+\\)[ ]+\\(=[ ]+[0-9.-]+[ ]+\\(.*\\)\\|\\(.*\\)\\)" point-e t))
	      (beginning-of-line)
	      (setq par-point (point))
	      (end-of-line)
	      (setq par-index (1+ par-index))
	      (setq par-list (gams-ol-store-point t))
	      (setq par-alist
		    (cons
		     (append (list par-index par-point) par-list) par-alist)))))
	 ;; VAR.
	 ((re-search-forward "[ ]+\\(VAR\\)[ ]+\\([^ ]+\\)[ ]+\\(.*\\)" point-b t)
	  (beginning-of-line)
	  (setq par-point (point))
	  (end-of-line)
	  (setq par-index (1+ par-index))
	  (setq par-list (gams-ol-store-point))
	  (setq par-alist
		(cons
		 (append (list par-index par-point) par-list) par-alist)))
	 ;; EQU.
	 ((re-search-forward "[ ]+\\(EQU\\)[ ]+\\([^ ]+\\)[ ]+\\(.*\\)" point-b t)
	  (beginning-of-line)
	  (setq par-point (point))
	  (end-of-line)
	  (setq par-index (1+ par-index))
	  (setq par-list (gams-ol-store-point))
	  (setq par-alist
		(cons
		 (append (list par-index par-point) par-list) par-alist)))
	 ;; COM.
	 ((re-search-forward "[ ]+[0-9]+[ ]com:\\(.*\\)" point-b t)
	  (let (mark-a)
	    (setq mark-a (gams*buffer-substring (match-beginning 1)
					   (match-end 1)))
	    (beginning-of-line)
	    (setq par-point (point))
	    (end-of-line)
	    (setq par-index (1+ par-index))
	    (setq par-alist
		  (cons
		   (list par-index par-point "COM" mark-a) par-alist))))
	 ;; OTHER.
	 ((re-search-forward "[ ]+[0-9]+[ ]\\(.*\\)" point-b t)
	  (let (mark-a)
	    (setq mark-a (gams*buffer-substring (match-beginning 1)
						(match-end 1)))
	    (beginning-of-line)
	    (setq par-point (point))
	    (end-of-line)
	    (setq par-index (1+ par-index))
	    (setq par-alist
		  (cons
		   (list par-index par-point "OTH" "" mark-a) par-alist))))))
       ;; REPORT SUMMARY
       ((equal flag-a "**** REPORT SUMMARY :")
	(let (list-a rep-cont)
	  (setq rep-cont (gams-ol-report-sum))
	  (setq point-a (point))
	  (forward-line 1)
	  (setq point-b (point))
	  (goto-char point-a)
	  (end-of-line)
	  (setq par-index (1+ par-index))
	  (setq par-alist
		(cons
		 (list par-index point-a "SUM" "REPORT SUMMARY" rep-cont) par-alist))))
       ;; LOOP
       ((equal flag-a "               L O O P S")
	(let (point-a
	      point-y
	      par-type3 par-name3 par-exp3)
	  (save-excursion
	    (end-of-line)
	    (setq point-y (point)))
	  (while
	      (re-search-forward "[ ]+\\([^ ]+\\)[ ]+\\([^ ]+\\)" point-y t)
	    (setq  par-type3 "LOO")
	    (setq  par-name3 (gams*buffer-substring
			      (match-beginning 1)
			      (match-end 1)))
	    (setq  par-exp3 (gams*buffer-substring
			     (match-beginning 2)
			     (match-end 2)))
	    (save-excursion
	      (beginning-of-line)
	      (setq point-a (point)))
	    (setq par-index (1+ par-index))
	    (setq par-alist
		  (cons
		   (list par-index point-a par-type3 par-name3 par-exp3) par-alist))
	    ;;
	    (forward-line 1)
	    (save-excursion
	      (end-of-line)
	    (setq point-y (point))))
	  ))
       ;; Others.
       (t
	(let (list-a)
	  (setq point-a (point))
	  (forward-line 1)
	  (setq point-b (point))
	  (goto-char point-a)
	  (end-of-line)
	  (setq par-index (1+ par-index))
	  (setq par-alist
		  (cons
		   (list par-index point-a "SUM" "SOLVER SUMMARY"
			 (gams-ol-solve-sum))
		   par-alist))
	  ))))
    (setq gams-over-alist par-alist)
    ;; Return alist.
    gams-over-alist))

(defun gams-ol-solve-sum ()
  "Extract SOLVER STATUS and MODEL STATUS."
  (let (point-b var-1 var-2 var-3)
    (save-excursion
      (setq point-b (+ (point) 600))	; 600 is sufficient?
      (re-search-forward "\\*\\*\\*\\* SOLVER STATUS[ ]+\\([0-9]*\\)\\(.*\\)[ ]*$" point-b t)
      (setq var-1 (gams*buffer-substring (match-beginning 1)
				    (match-end 1)))
      (when (equal var-1 "")
	  (setq var-1 (gams*buffer-substring (match-beginning 2)
					(match-end 2))))
      (re-search-forward "\\*\\*\\*\\* MODEL STATUS[ ]+\\([0-9]*\\)\\(.*\\)[ ]*$" point-b t)
      (setq var-2 (gams*buffer-substring (match-beginning 1)
				    (match-end 1)))
      (when (equal var-2 "")
	  (setq var-2 (gams*buffer-substring (match-beginning 2)
					(match-end 2))))
      ;; Remove the spaces in the line end.
      (cond
       (gams-emacs-21
	(setq var-1 (replace-regexp-in-string "[ ]+$" "" var-1))
	(setq var-2 (replace-regexp-in-string "[ ]+$" "" var-2)))
       (gams-emacs-20
	(setq var-1 (gams-replace-regexp-in-string "[ ]+$" "" var-1))
	(setq var-2 (gams-replace-regexp-in-string "[ ]+$" "" var-2))))
      (setq var-3 (concat "SOLVER STATUS = " var-1 ", " "MODEL STATUS = " var-2)))
    var-3))

(defun gams-ol-report-sum ()
  "Extract the content of REPORT SUMMARY."
  (let (cont var-1 var-2 var-3 var-4 var-5)
    (save-excursion
      (re-search-forward "\\([0-9]+\\)[ \t]+NONOPT" nil t)
      (setq var-1 (gams*buffer-substring (match-beginning 1)
					 (match-end 1)))
      (forward-line 1)
      (re-search-forward "\\([0-9]+\\)[ \t]+INFEASIBLE" nil t)
      (setq var-2 (gams*buffer-substring (match-beginning 1)
					 (match-end 1)))
      (forward-line 1)
      (re-search-forward "\\([0-9]+\\)[ \t]+UNBOUNDED" nil t)
      (setq var-3 (gams*buffer-substring (match-beginning 1)
					 (match-end 1)))
      (forward-line 1)
      (re-search-forward "\\([0-9]+\\)[ \t]+REDEFINED" nil t)
      (setq var-4 (gams*buffer-substring (match-beginning 1)
					 (match-end 1)))
      (forward-line 1)
      (re-search-forward "\\([0-9]+\\)[ \t]+ERRORS" nil t)
      (setq var-5 (gams*buffer-substring (match-beginning 1)
					 (match-end 1))))
    (setq cont
	  (concat "[" var-1 ", "
		  var-2 ", "
		  var-3 ", "
		  var-4 ", "
		  var-5 "]"))
    cont))

;;; If Emacs 20, define `gams-replace-regexp-in-string'.  This code is
;;; `replace-regexp-in-string' from subr.el in the Emacs 21 distribution.
(if gams-emacs-20
    (defun gams-replace-regexp-in-string (regexp rep string &optional
					    fixedcase literal subexp start)
      "Replace all matches for REGEXP with REP in STRING.

This code is from subr.el in Emacs 21 distribution.

Return a new string containing the replacements.

Optional arguments FIXEDCASE, LITERAL and SUBEXP are like the
arguments with the same names of function `replace-match'.  If START
is non-nil, start replacements at that index in STRING.

REP is either a string used as the NEWTEXT arg of `replace-match' or a
function.  If it is a function it is applied to each match to generate
the replacement passed to `replace-match'; the match-data at this
point are such that match 0 is the function's argument.

To replace only the first match (if any), make REGEXP match up to \\'
and replace a sub-expression, e.g.
  (replace-regexp-in-string \"\\(foo\\).*\\'\" \"bar\" \" foo foo\" nil nil 1)
    => \" bar foo\"
"

      ;; To avoid excessive consing from multiple matches in long strings,
      ;; don't just call `replace-match' continually.  Walk down the
      ;; string looking for matches of REGEXP and building up a (reversed)
      ;; list MATCHES.  This comprises segments of STRING which weren't
      ;; matched interspersed with replacements for segments that were.
      ;; [For a `large' number of replacments it's more efficient to
      ;; operate in a temporary buffer; we can't tell from the function's
      ;; args whether to choose the buffer-based implementation, though it
      ;; might be reasonable to do so for long enough STRING.]
      (let ((l (length string))
	    (start (or start 0))
	    matches str mb me)
	(save-match-data
	  (while (and (< start l) (string-match regexp string start))
	    (setq mb (match-beginning 0)
		  me (match-end 0))
       ;; If we matched the empty string, make sure we advance by one char
	    (when (= me mb) (setq me (min l (1+ mb))))
	    ;; Generate a replacement for the matched substring.
	    ;; Operate only on the substring to minimize string consing.
	    ;; Set up match data for the substring for replacement;
	    ;; presumably this is likely to be faster than munging the
	    ;; match data directly in Lisp.
	    (string-match regexp (setq str (substring string mb me)))
	    (setq matches
		  (cons (replace-match (if (stringp rep)
					   rep
					 (funcall rep (match-string 0 str)))
				       fixedcase literal str subexp)
			(cons (substring string start mb) ; unmatched prefix
			      matches)))
	    (setq start me))
	  ;; Reconstruct a string from the pieces.
	  (setq matches (cons (substring string start l) matches)) ; leftover
	  (apply #'concat (nreverse matches))))))

(defvar gams-ol-view-item-2
  '(("SUM" . t)
    ("VAR" . t)
    ("EQU" . t)
    ("PAR" . t)
    ("SET" . t)
    ("VRI" . t)
    ("LOO" . t)
    ("OTH" . t)
    ("COM" . t)))

;; (defun gams-ol-convert (alist)
;;   "?"
;;   (interactive)
;;   (if (equal gams-ol-view-item gams-ol-view-item-2)
;;       ;;
;;       (setq gams-ol-alist-tempo alist)
;;     ;;    
;;     (let ((temp-alist (reverse alist))
;; 	  (list-count 1)
;; 	  temp-element temp-alist-2 temp-list)
;;       (while temp-alist
;; 	(setq temp-list (car temp-alist))
;; 	(setq temp-element (car (cdr (cdr temp-list))))
;; 	;; If temp-element must be displayed or not?
;; 	(if (cdr (assoc temp-element gams-ol-view-item))
;; 	    ;; Display
;; 	    (progn
;; 	      (setcar temp-list list-count)
;; 	      (setq temp-alist-2
;; 		    (cons temp-list temp-alist-2))
;; 	      (setq list-count (+ 1 list-count)))
;; 	  ;; Not display.
;; 	  nil)
;; 	(setq temp-alist (cdr temp-alist)))
;;       (setq gams-ol-alist-tempo temp-alist-2))
;;     gams-ol-alist-tempo))

(defun gams-ol-convert (alist)
  "Convert `gams-over-alist' to the alist with only viewable items."
  (interactive)
  (let ((temp-alist (reverse alist))
	(list-count 1)
	temp-element temp-alist-2 temp-list)
    (while temp-alist
      (setq temp-list (car temp-alist))
      (setq temp-element (car (cdr (cdr temp-list))))
      ;; If temp-element must be displayed or not?
      (if (cdr (assoc temp-element gams-ol-view-item))
	  ;; Display
	  (progn
	    (setcar temp-list list-count)
	    (setq temp-alist-2
		  (cons temp-list temp-alist-2))
	    (setq list-count (+ 1 list-count)))
	;; Not display.
	nil)
      (setq temp-alist (cdr temp-alist)))
    (setq gams-ol-alist-tempo temp-alist-2))
  gams-ol-alist-tempo)

(defun gams-ol-show (buffname alist)
  "?.

BUFFNAME is the OV buffer name.
ALIST is the alist of all items."
  (interactive)
  (let ((temp-alist alist)
	(lst-buf (current-buffer))
	list-list
	point-end)
    (switch-to-buffer buffname)
    (setq buffer-read-only nil)
    (setq fl-flag font-lock-mode)
    ;; Deactivate font-lock to make the process faster.
    (if fl-flag
	(font-lock-mode -1))
    (setq truncate-lines t)
    (erase-buffer)
    (goto-char (point-min))
    ;; Insert.
    (if (null temp-alist)
	(insert "No viewable item in GAMS-LST-OUTLINE mode!  Type `q' to quit or type `t' to toggle!")
      (while temp-alist
	(goto-char (point-min))
	(insert "\n")	
	(setq list-list (car temp-alist))
	(gams-lst-insert-item list-list)
	(setq temp-alist (cdr temp-alist)))
      (goto-char (point-min))
      (delete-char 1)
      (if fl-flag
	  (font-lock-mode 1))
      )))

(defun gams-lst-insert-item (list-list)
  "Insert item into the OUTLINE buffer."
  (interactive)
  (let ((list-type (car (cdr (cdr list-list))))
	(list-name (car (cdr (cdr (cdr list-list)))))
	(list-cont (car (cdr (cdr (cdr (cdr list-list)))))))
    (if (equal list-type "COM")
	;; COM.
	(insert (concat "COM:" " " list-name))
      ;; Not COM.
      (move-to-column 2 t)
      (insert list-type)
      (insert "  ")
      (insert list-name)
      (if list-cont
	  (progn
	    (move-to-column 26 t)
	    (insert list-cont))))
    ))
  
(setq gams-ol-item-buffer "*GAMS-SELECT-ITEM*")

(defun gams-ol-select-item ()
  "Evoke the SELECT-ITEM mode."
  (interactive)
  (let ((cur-buf (current-buffer))
	(temp-buf gams-ol-item-buffer)
	(item-list gams-ol-item)
	temp-item
	(temp-num 1)
	(flag nil))
    (pop-to-buffer (get-buffer-create temp-buf))
    (erase-buffer)
    (goto-char (point-min))
    (while item-list
      (setq temp-item (car item-list))
      (if (gams-ol-check-included temp-item t)
	  (setq flag t)
	(setq flag nil))
      (goto-char (point-max))
      (insert
       (concat " " " ["
	       (if flag "+" "-")
	       "] " temp-item "\n"))
      (setq item-list (cdr item-list))
      (setq temp-num (+ temp-num 1)))
    (goto-char (point-max))
    (gams-ol-select-key)
    (goto-char (point-min))
    (gams-ol-select-mode cur-buf)))

;;; key assignment for SELECT-ITEM mode.
(defvar gams-os-on "j")
(defvar gams-os-on-prev "i")
(defvar gams-os-off "h")
(defvar gams-os-off-prev "u")
(defvar gams-os-on-all "d")
(defvar gams-os-off-all "f")
(defvar gams-os-quit "\r")
(defvar gams-os-sum "s")
(defvar gams-os-var "v")
(defvar gams-os-equ "e")
(defvar gams-os-vri "r")
(defvar gams-os-set "t")
(defvar gams-os-par "p")
(defvar gams-os-loo "l")
(defvar gams-os-oth "o")
(defvar gams-os-com "c")

(defvar gams-ol-select-mode-map (make-keymap) "Keymap.")
(let ((map gams-ol-select-mode-map)
      (temp-list (reverse gams-ol-item))
      temp-name
      (count 9))
  (define-key map " " 'gams-ol-toggle)
  (define-key map gams-os-on 'gams-ol-toggle-on)
  (define-key map gams-os-off 'gams-ol-toggle-off)
  (define-key map gams-os-on-prev 'gams-ol-toggle-on-prev)
  (define-key map gams-os-off-prev 'gams-ol-toggle-off-prev)
  (define-key map gams-os-quit 'gams-ol-select-quit)
  (define-key map gams-os-on-all 'gams-ol-toggle-all-on)
  (define-key map gams-os-off-all 'gams-ol-toggle-all-off)

  (define-key map gams-os-var 'gams-ol-toggle-var)
  (define-key map gams-os-equ 'gams-ol-toggle-equ)
  (define-key map gams-os-vri 'gams-ol-toggle-vri)
  (define-key map gams-os-set 'gams-ol-toggle-set)
  (define-key map gams-os-par 'gams-ol-toggle-par)
  (define-key map gams-os-sum 'gams-ol-toggle-sum)
  (define-key map gams-os-loo 'gams-ol-toggle-loo)
  (define-key map gams-os-oth 'gams-ol-toggle-oth)
  (define-key map gams-os-com 'gams-ol-toggle-com)
  )

;;; Menu for OUTLINE-SELECT mode.
(easy-menu-define 
  gams-ol-select-mode-menu gams-ol-select-mode-map "Menu keymap for OUTLINE-SELECT mode."
  '("OUTLINE-SELECT"
    ["Toggle" gams-ol-toggle t]
    ["Toggle on (next)" gams-ol-toggle-on t]
    ["Toggle off (next)" gams-ol-toggle-off t]
    ["Toggle on (previous)" gams-ol-toggle-on-prev t]
    ["Toggle off (previous)" gams-ol-toggle-off-prev t]
    ["Toggle on all" gams-ol-toggle-all-on t]
    ["Toggle off all" gams-ol-toggle-all-off t]
    "--"
    ["Quit SELECT mode" gams-ol-select-quit t]
    "--"
    ["Toggle VAR" gams-ol-toggle-var t]
    ["Toggle EQU" gams-ol-toggle-equ t]
    ["Toggle VRI" gams-ol-toggle-vri t]
    ["Toggle SET" gams-ol-toggle-set t]
    ["Toggle PAR" gams-ol-toggle-par t]
    ["Toggle SUM" gams-ol-toggle-sum t]
    ["Toggle LOO" gams-ol-toggle-loo t]
    ["Toggle OTH" gams-ol-toggle-oth t]
    ["Toggle COM" gams-ol-toggle-com t]
    ))

(defun gams-ol-select-key ()
    (insert (concat "\n"
		    "Key:\n"
		    (format "[SPC]    = Toggle\n")
		    (format "[%s/%s]    = Toggle on\n"
			    gams-os-on gams-os-on-prev)
		    (format "[%s/%s]    = Toggle off\n"
			    gams-os-off gams-os-off-prev)
		    (format "[%s]      = Toggle on all\n" gams-os-on-all)
		    (format "[%s]      = Toggle off all\n" gams-os-off-all)
		    (format "[RET]    = Quit.\n\n")
		    (format "[%s] = SUM, " gams-os-sum)
		    (format "[%s] = VAR, " gams-os-var)
		    (format "[%s] = EQU, " gams-os-equ)
		    (format "[%s] = PAR, " gams-os-par)
		    (format "[%s] = SET,\n" gams-os-set)
		    (format "[%s] = VRI, " gams-os-vri)
		    (format "[%s] = LOO, " gams-os-loo)
		    (format "[%s] = OTH, " gams-os-oth)
		    (format "[%s] = COM." gams-os-com))))

(defun gams-ol-select-mode (buffname)
  "Start the SELECT-ITEM mode.

BUFFNAME is the OUTLINE buffer name."
  (interactive)
  (setq major-mode 'gams-ol-select-mode)
  (setq mode-name "GAMS-SELECT-ITEM")
  (use-local-map gams-ol-select-mode-map)
  (setq buffer-read-only t)
;  (make-local-variable 'font-lock-defaults)
;  (setq font-lock-defaults '(gams-ol-font-lock-keywords t t))
;  (font-lock-fontify-buffer)
  (make-local-variable 'gams-ol-olbuff)
  (setq gams-ol-olbuff buffname)
  ;; Make local variable.  `gams-ol-item-flag' is a buffer local
  ;; variable. When the SELECT buffer is created, `gams-ol-item-flag' is
  ;; given the same content as `gams-ol-view-item'.
  ;; `gams-ol-item-flag' may be modified but `gams-ol-view-item'
  ;; reserve its initial value.
  (make-local-variable 'gams-ol-item-flag)
  (setq gams-ol-item-flag
	(gams-ol-check-func gams-ol-view-item))
  )
;; gams-ol-select-mode ends here.

(defun gams-ol-check-func (alist)
  "Copy the ALIST to the new alist."
  (let ((temp-alist (reverse alist))
	temp-list
	temp-item
	res-alist)
    (while temp-alist
      (setq temp-item (car temp-alist))
      (if (cdr temp-item)
	  (setq res-alist
		(append
		 (list (cons (car temp-item) t)) res-alist))
	(setq res-alist
	      (append
	       (list (cons (car temp-item) nil)) res-alist)))
      (setq temp-alist (cdr temp-alist)))
    res-alist))

(defun gams-ol-select-judge ()
  "Judge the item on the line and return its value."
  (let (point-end temp-item)
    (save-excursion
      (end-of-line)
      (setq point-end (point))
      (beginning-of-line)
      (if (re-search-forward
	   "\\([+]\\|[-]\\)[]][ ]+\\([A-Z][A-Z][A-Z]\\)$" point-end t)
	  (setq temp-item (gams*buffer-substring
			   (match-beginning 2)
			   (match-end 2))))
    temp-item)))

(defun gams-ol-toggle (&optional on off prev)
  "Toggle check.

If on in non-nil, toggle on. If off is non-nil, toggle off.
If prev is non-nil, move up after toggle."
  (interactive)
  (let* ((buffer-read-only nil)
	(item (gams-ol-select-judge))
	(flag (gams-ol-check-included item)))
    (if (null item)
	;; if no item on the current line, Do nothing.
	nil
      ;; if any item on the current line.
      (beginning-of-line)
      (move-to-column 3)
      (cond
       ;; Just toggle.
       ((and (null on) (null off))
	;; Delete.
	(delete-char 1)
	(if flag
	    ;; If checked.
	    (insert "-")
	  ;; Not checked.
	  (insert "+"))
	(gams-ol-check-toggle item))
       ;; Toggle on.
       ((and on (null off))
	(if flag
	    nil
	  ;; Delete.
	  (delete-char 1)
	  (insert "+")
	  (gams-ol-check-toggle item)))
       ;; Toggle off.
       ((and (null on) off)
	(if (null flag)
	    nil
	  ;; Delete.
	  (delete-char 1)
	  (insert "-")
	  (gams-ol-check-toggle item)))))
    ;; forward or backward?
    (if prev
	(forward-line -1)
      (forward-line 1))
    ))

(defun gams-ol-toggle-on ()
  "Toggle on the item on the current line."
  (interactive)
  (gams-ol-toggle t))

(defun gams-ol-toggle-on-prev ()
  "Toggle on the item on the current line."
  (interactive)
  (gams-ol-toggle t nil t))

(defun gams-ol-toggle-all-on ()
  "Toggle on all items."
  (interactive)
  (let ((times 9))
    (save-excursion
      (goto-char (point-min))
      (while (> times 0)
	(gams-ol-toggle t)
	(setq times (- times 1))))))

(defun gams-ol-toggle-all-off ()
  "Toggle off all the items."
  (interactive)
  (let ((times 9))
    (save-excursion
      (goto-char (point-min))
      (while (> times 0)
	(gams-ol-toggle nil t)
	(setq times (- times 1))))))

(defun gams-ol-toggle-off ()
  "Toggle off the item on the current line."
  (interactive)
  (gams-ol-toggle nil t))

(defun gams-ol-toggle-off-prev ()
  "Toggle off the item on the current line."
  (interactive)
  (gams-ol-toggle nil t t))

(defun gams-ol-toggle-func (item)
  "item is an item name."
  (goto-char (point-min))
  (goto-char (re-search-forward (concat "] " item) nil t))
  (beginning-of-line)
  (gams-ol-toggle))

(defun gams-ol-toggle-var ()
  (interactive)
  (gams-ol-toggle-func "VAR"))

(defun gams-ol-toggle-equ ()
  (interactive)
  (gams-ol-toggle-func "EQU"))

(defun gams-ol-toggle-vri ()
  (interactive)
  (gams-ol-toggle-func "VRI"))

(defun gams-ol-toggle-par ()
  (interactive)
  (gams-ol-toggle-func "PAR"))

(defun gams-ol-toggle-set ()
  (interactive)
  (gams-ol-toggle-func "SET"))

(defun gams-ol-toggle-loo ()
  (interactive)
  (gams-ol-toggle-func "LOO"))

(defun gams-ol-toggle-sum ()
  (interactive)
  (gams-ol-toggle-func "SUM"))

(defun gams-ol-toggle-oth ()
  (interactive)
  (gams-ol-toggle-func "OTH"))

(defun gams-ol-toggle-com ()
  (interactive)
  (gams-ol-toggle-func "COM"))

(defun gams-ol-select-quit ()
  "Quit the SELECT-ITEM mode."
  (interactive)
  (let ((cur-buff (current-buffer))
	(ov-buff gams-ol-olbuff)
	(item gams-ol-item-flag)
	temp-buf)
    (if (buffer-live-p ov-buff)
	;; If OUTLINE buffer exits.
	(progn
	  (switch-to-buffer ov-buff)
	  (kill-buffer cur-buff)
	  (delete-other-windows)
	  (if (equal item gams-ol-view-item)
	      ;; If no change has been made to gams-ol-view-item.
	      nil
	    ;; If any change has been made.
	    ;; Switch to the LST buffer.
	    (switch-to-buffer gams-ol-lst)
	    ;; Store the lst buffer name.
	    (setq temp-buf (current-buffer))
	    (setq gams-ol-view-item item)
	    (gams-ol-show ov-buff (gams-ol-convert (gams-ol-get-alist)))
	    (switch-to-buffer ov-buff)
	    (setq gams-ol-mark-flag nil)
	    ;; give lst buffer name.
	    (gams-ol-mode temp-buf))
	  (gams-ol-show-key))
      ;; If OUTLINE buffer does not exists.
      (message "No OUTLINE buffer exists!")
      (sleep-for 1)
      (kill-buffer cur-buff))))

(defun gams-ol-check-included (item &optional flag)
  "Judge whether the item is checked or not.
If the flag is non-nil, use `gams-ol-view-item'.
"
  (let ((temp-alist
	 (if flag gams-ol-view-item gams-ol-item-flag)))
    (if (cdr (assoc item temp-alist))
	t
      nil)))

(defun gams-ol-check-toggle (item)
  "Toggle the check of the item."
  (let ((temp-alist gams-ol-item-flag))
    (if (gams-ol-check-included item)
	;; If checked.
	(setcdr (assoc item temp-alist) nil)
      ;; If not checked.
      (setcdr (assoc item temp-alist) t))
    gams-ol-view-item
    gams-ol-item-flag))

(defun gams-ol-chage-window-one-line (&optional narrow)
  "Widen (narrow) a OUTLINE mode buffer one line.
If NARROW is non-nil, narrow the window."
  (interactive)
  (let ((key (this-command-keys))
	(win-num (gams-ol-count-win)))
    (if narrow
	(cond
	 ((equal win-num 1)
	  nil)
	 ((equal win-num 2)
	  (setq gams-ol-height (max 5 (- gams-ol-height 1))))
	 (t
	  (setq gams-ol-height-two (max 5 (- gams-ol-height-two 1)))))
      (cond
       ((equal win-num 1)
	nil)
       ((equal win-num 2)
	(when (>= (window-height (next-window)) 8)
	  (setq gams-ol-height (+ gams-ol-height 1))))
       (t
	(when (>= (window-height (next-window)) 8)
	  (setq gams-ol-height-two (+ gams-ol-height-two 1))))))
    (gams-ol-view-base)))

(defun gams-ol-widen-one-line ()
  "Widen a OUTLINE mode buffer one line."
  (interactive)
  (gams-ol-chage-window-one-line))

(defun gams-ol-narrow-one-line ()
  "Narrow a OUTLINE mode buffer one line."
  (interactive)
  (gams-ol-chage-window-one-line t))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;	Code for indentation.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Variables for indentation.
(defcustom gams-indent-on t
  "If it is non-nil, automatic indentation for GAMS mode works.
If it is nil, no special indentation and TAB key insert TAB."
  :type 'boolean
  :group 'gams)

(defcustom gams-indent-number 8
  "Indent number for general statemets."
  :type 'number
  :group 'gams)

(defcustom gams-indent-number-loop 8
  "Indent number in loop type environment."
  :type 'number
  :group 'gams)

(defcustom gams-indent-number-mpsge 8
  "Indent number in MPSGE type environment."
  :type 'number
  :group 'gams)

(defvar gams-indent-number-slash 4)

;;;;; Functions for indentation.

(defvar gams-regexp-declaration
      (concat
       "\\("
       "parameter\\|set\\|scalar\\|table\\|alias\\|acronym\\|\\(free\\|positive\\|negative\\|binary\\|integer\\)*[ ]*variable\\|equation\\|model"
       "\\)[s]?[ \t\n(]+")
      "Regular expression for declaration type statements.")

(defvar gams-regexp-loop
  (concat (regexp-opt (list "loop" "while" "if" "for" "elseif") t)
	  "[ \t\n]*(")
  "Regular expression for loop type statements.")

(defvar gams-regexp-mpsge
  (concat "[$][ \t]*"
	  (regexp-opt gams-statement-mpsge t))
  "Regular expression for mpsge type statements")

(defvar gams-regexp-equation
  (concat "[^.]\\([.][.][^.]\\)")
  "Regular expression for equation definition.")

;;; 
(defvar gams-regexp-other
  (regexp-opt
	(list "abort" "display" "option[s]?" "file" "solve") t))


;;; Line type.
(defun gams-judge-line (&optional type)
  "Judge the current line numbers.
TYPE 
nil	=>	declaration type.
mpsge	=>	mpsge type
loop	=>	loop type.
equ	=>	equation type.
other	=>	other type.

Return a list of real line, effective line, and another line."
  (let* (flag-a flag-b
	(regexp
	 (cond ((equal type "mpsge")
		(setq flag-a t)
		(concat "^[ \t]*" gams-regexp-mpsge))
	       ((equal type "other")
		(concat "^[ \t]*[$][a-zA-Z]+"
			"\\|"
			";[ \t]*\\("
			gams-eolcom-symbol
			"\\|"
			gams-inlinecom-symbol-start
			"\\)?"
			))
	       ((equal type "loop")
		(setq flag-b t)
		(concat "^[ \t]*" gams-regexp-loop))
	       ((equal type "equ") gams-regexp-equation)
	       (t (concat "^[ \t]*" gams-regexp-declaration))))
	(cur-po (point))
	(count 2) (effective 2)
	back temp-flag res po-beg)
    (save-excursion
      (beginning-of-line)
      (if (re-search-backward regexp nil t)
	  (progn
	    (forward-line 1)
	    (setq po-beg (point))
	    (goto-char cur-po)
	    (forward-line -1)
	    ;;
	    (while (>= (point) po-beg)
	      ;;
	      (if (equal (gams-check-line-type flag-a flag-b) nil)
		  (progn (if (null temp-flag)
			     (progn (setq back (- count 1))
				    (setq temp-flag t)))
			 (setq effective (+ 1 effective))))
	      (forward-line -1)
	      (setq count (+ 1 count)))
	    (if (null back) (setq back (- count 1)))
	    (setq res (list count effective back)))))
    res))

;;; Judge the type of declaration line.
(defun gams-judge-decl-type (line)
  "Judge the type of declaration line.

If it includes only declaration, return nil.  If it includes other
components (identifiers etc.), return the column number of identifier.  If
it includes one slash, return the column number of the word after slash.

LINE indicates the number of line to back to."
  (save-excursion
    (let (po-end col-num)
      (forward-line (* -1 line))
      (save-excursion
	(end-of-line)
	(setq po-end (point)))
      (looking-at gams-regexp-declaration)
      (goto-char (match-end 1))
;      (goto-char (match-end 0))
      (if (gams-judge-slash-in-line)
	  ;; Declaration line includes slash.
	  (progn (re-search-forward "/" nil t)
		 (skip-chars-forward "[ \t]")
		 (setq col-num (current-column)))
	;; No slash.
	(skip-chars-backward "[ \t\n]")
	(if (re-search-forward "\\([ \t]+\\)\\([^ \t]+\\)" po-end t)
	    ;; Identifier is found.
	    (progn
	      (goto-char (match-beginning 2))
	      (setq col-num (current-column)))
	  ;; No identifier is found.
	  (setq col-num gams-indent-number)))
      col-num)))

(defun gams-calculate-indent-previous (&optional line)
  "Return the indent number of the previous line
which is not an empty line.

LINE is the line number to go back."
  (let ((start-column (current-column))
	(point-here (point))
	indent)
    (beginning-of-line)
    (save-excursion
      (if (or (if line (forward-line (* -1 line)) nil)
	      (re-search-backward (concat "^[^" gams-comment-prefix "\n]") nil t))
	  (let ((end (save-excursion (forward-line 1) (point))))
	    (move-to-column start-column)
	    ;; Is start-column inside a tab on this line?
	    (if (> (current-column) start-column)
		(backward-char 1))
	    (or (looking-at "[ \t]")
		(skip-chars-forward "^ \t" end))
	    (skip-chars-forward " \t" end)
	    (setq indent (current-column)))))
;;	    (or (= (point) end) (setq indent (current-column))))))
    indent))

;; Handle slash.
(defun gams-judge-slash-in-line (&optional previous)
  "Judge the line include slash.

Return t if the line contains one slash.
Return nil if the line contains no slash.
Return nil if the line contains two slashes.

If PREVIOUS is non-nil, the line is the previous line."
  (let (po-end flag (count 0))
    (save-excursion
      (when previous
	(forward-line -1)
	;; back to non-empty line.
	(while (gams-check-line-type) (forward-line -1)))
      ;;
      (save-excursion
	(end-of-line) (setq po-end (point)))
      ;; 
      (while (re-search-forward "/" po-end t)
	(when (and (null (gams-judge-in-comment))
		   (null (gams-judge-in-quote)))
	  (setq count (+ count 1))))
      (when (and (> count 0) (oddp count)) (setq flag t)))
    flag))

(defun gams-judge-slash-end (begin)
  "Judge the point is in slash pair or no.
Return t if it is not in."
  (let ((count 1) (cur-po (point)) flag)
    (save-excursion
      (goto-char begin)
      (while (re-search-forward "/" cur-po t)
	(when (and (null (gams-judge-in-comment))
		   (null (gams-judge-in-quote)))
	  (setq count (+ 1 count))))
      (when (and (> count 0) (oddp count)) (setq flag t)))
    flag))

;;; if the current point is in slash pair, search the first slash.

(defun gams-return-first-slash ()
  "Return the column number of the word after the last slash.

set   test   sample set
      /  a
         ^ return this point."
  (let (col)
    (save-excursion
      (forward-char -1)
      (catch 'found
	(while t
	  (if (re-search-backward "/" nil t)
	      (if (null (gams-judge-in-comment))
		  (throw 'found t)))))
      (if (looking-at "/[ \t]*\\([^ \t]+\\)")
	  (progn (goto-char (match-beginning 1))
		 (setq col (current-column)))
	(setq col (+ gams-indent-number-slash (current-column)))))
    col))


;;; 

(defun gams-return-previous-slash ()
  "Return the column number of the word after the last slash."
  (let ((cur-po (point))
	(count 2)
	col po-slash flag-slash)
    (save-excursion
      (catch 'found
	(while t
	  (if (re-search-backward "/" nil t)
	      (if (null (gams-judge-in-comment))
		  (progn
		    (setq count (1- count))
		    (if (equal count 0)
			(throw 'found t)))))))
      (setq po-slash (point))
      (beginning-of-line)
      (if (looking-at "^[ \t]+/")
	  ;;
	  (setq col (gams-calculate-indent-previous))
	;;
	(when (looking-at gams-regexp-declaration)
	  (goto-char (match-end 0)))
	(skip-chars-forward "[ \t]")
	(setq col (current-column)))
      col)))

(defun gams-calculate-indent-decl (&optional begin table)
  "Calculate the number of indent in declaration type.
"
  (let* ((temp (gams-judge-line))
	 (line (car (cdr temp)))
	 (re-line (car temp))
	 (pre-line (car (cdr (cdr temp))))
	 indent-num)
    (beginning-of-line)
    (if table
	nil
      (cond
       ;; First line.
       ((equal line 1))	;; no indent.
       ;; Second line.
       ((equal line 2)
	(setq indent-num (gams-judge-decl-type (- re-line 1))))
       ;; After third line.
       (t (if (gams-judge-slash-in-line t)
	      ;; the previous line includes slash.
	      (if (null (gams-judge-slash-end begin))
		  ;; in slash pair
		  (setq indent-num (gams-return-first-slash))
		;; not in slash pair.
		(setq indent-num (gams-return-previous-slash)))
	    ;; the previous line includes no slash.
	    (setq indent-num (gams-calculate-indent-previous pre-line))
	    (when (equal "s" (gams-check-line-type nil nil t))
	      (setq indent-num (+ gams-indent-number-slash indent-num)))))))
    indent-num))

(defun gams-calculate-indent-mpsge ()
  "Calculate the number of indent in mpsge type."
  (let (indent-num)
    (if (looking-at "[ \t]*[+]")
	;; the line starts with +.  No indent.
	(setq indent-num nil)
      ;; Other line.
      (let* ((temp (gams-judge-line "mpsge"))
	     (cur-line (car (cdr temp)))
	     (line (car (cdr (cdr temp)))))
	(cond
	 ;; First.
	 ((equal cur-line 1)
	  (setq indent-num nil))
	 ;; Second.
	 ((equal cur-line 2)
	  (setq indent-num gams-indent-number-mpsge))
	 ;; Line after third.
	 (t (setq indent-num (gams-calculate-indent-previous line))))))
    indent-num))

(defun gams-judge-equ-type (line)
  "Examine the type of equation definition line.

If the line ends with .., return nil.  Otherwise, return the column-number
of ..  LINE is line number."
  (save-excursion
    (let (po-end col-num)
      (forward-line (* -1 line))
      (end-of-line)
      (setq po-end (point))
      (beginning-of-line)
      (looking-at gams-regexp-equation)
      (goto-char (match-end 0))
      (skip-chars-backward "[ \t\n]")
      (if (re-search-forward "\\([ \t]+\\)\\([^ \t]+\\)" po-end t)
	  (progn
	    (goto-char (match-beginning 2))
	    (setq col-num (current-column)))
	(setq col-num gams-indent-number))
      col-num)))

(defun gams-calculate-indent-equation (&optional new)
  "Calculate the indent number in equation type."
  (let* ((temp (gams-judge-line "equ"))
	 (re-line (car temp))
	 (ef-line (car (cdr temp)))
	 (ba-line (car (cdr (cdr temp))))
	 indent-num)
    (cond
     ;; The first line.
     ((equal ef-line 1)
      (setq indent-num nil))
     ;; The second line.
     ((equal ef-line 2)
      (if new
	  (setq indent-num (gams-judge-equ-type ba-line))
	(setq indent-num nil)))
     ;; Other.
     (t
      (if new
	  (setq indent-num (gams-calculate-indent-previous ba-line))
	(setq indent-num nil))))
    indent-num))

(defun gams-calculate-indent-other (&optional new)
  "Calculate the number of indent of other types."
  (let ((line (car (cdr (gams-judge-line "other"))))
	indent-num)
    (save-excursion
      (cond
       ((equal line 2)
	(setq indent-num 0))
       ((equal line 3)
	(if new
	    (setq indent-num gams-indent-number)
	  (setq indent-num nil)))
       (t
	(if new
	    (setq indent-num (gams-calculate-indent-previous))
	  (setq indent-num nil)))))
    indent-num))

(defun gams-check-line-type (&optional plus dollar slash paren)
  "Judge the type of the current line.

Return c if the current line is * commented line.
Return e if the current line is empty.
Return p if the current line starts with + and if plus is non-nil.
Return d if the current line starts with dollar control and if DOLLAR is non-nil.
Return s if the current line starts with slash and if slash is non-nil.
Return k if the current line starts with ); and if paren is non-nil.
Otherwise nil."
  (let (flag)
    (save-excursion
      (beginning-of-line)
      (cond
       ;; commented line.
       ((looking-at (concat "^[" gams-comment-prefix "]")) (setq flag "c"))
       ;; empty line.
       ((looking-at "[ \t]*$") (setq flag "e"))
       ;; Starts +
       ((if plus (looking-at "^[+]") nil) (setq flag "p"))
       ;; Starts +
       ((if dollar (looking-at "^[$][a-zA-Z]*") nil)
	(setq flag "d"))
       ;; Starts /
       ((if slash (looking-at "^[ \t]*/") nil)
	(setq flag "s"))
       ;; Starts );
       ((if slash (looking-at "^[ \t]*);") nil)
	(setq flag "k"))
       (t)))
    flag))

(defun gams-check-dollar-line (&optional mpsge)
  "Return t if the current line starts with dollar control.  Otherwise nil.

IF MPSGE is non-nil, MPSGE type commands are excluded."
  (let ((reg (if mpsge "[^:]" nil))
	flag)
    (save-excursion
      (beginning-of-line)
      (skip-chars-forward "[ \t]")
      (when (looking-at (concat "[$][ \t]*[a-zA-Z]+[0-9]*" reg))
	;; dollar control is found.
	(setq flag t)))
    flag))

(defun gams-judge-loop-beg ()
  "Return the point of ( that matches );.
If it does not exits, return nil."
  (let ((count-left 0) (count-right 1) match-po)
    (save-excursion
      (catch 'found
	(while t
	  (re-search-backward "\\([(]\\|[)]\\)" nil t)
	  (when (null (gams-check-line-type))
	    (if (equal ")" (gams*buffer-substring (match-beginning 1)
						  (match-end 1)))
		;; right
		(setq count-right (+ 1 count-right))
	      ;; left 
	      (setq count-left (+ 1 count-left))
	      (when (equal count-left count-right)
		;; match
		(setq match-po (point))
		(throw 'found t)))))))
    match-po))

(defun gams-judge-loop-end (beg end)
  "Return the point of ) that matches loop(.
If the current point is in loop environment, return nil.
BEG is the begin point of loop."
  (let ((count-left 1) (count-right 0) match-po)
    (save-excursion
      (goto-char beg)
      (while (re-search-forward "\\([(]\\|[)]\\)" end t)
	(when (null (gams-check-line-type))
	  (if (equal "(" (gams*buffer-substring (match-beginning 1)
						(match-end 1)))
	      ;; left 
	      (setq count-left (+ 1 count-left))
	    ;; right
	    (setq count-right (+ 1 count-right))
	    (when (equal count-left count-right)
	      ;; match
	      (setq match-po (point)))))))
    match-po))
  
(defun gams-calculate-indent-loop-end ()
  "Calculate the number of indent for loop."
  (let ((po (gams-judge-loop-beg)))
    (save-excursion
      (goto-char po)
      (beginning-of-line)
      (skip-chars-forward " \t")
      (current-column))))

(defun gams-judge-parenthesis-close ()
  "Return t if the line starts with closing parenthesis."
  (save-excursion
    (if (looking-at "[ \t]*)[ \t]*;")
	t nil)))

(defun gams-calculate-indent-loop (beg &optional in semi)
  "Calculate the number of indent in loop type."
  (let ((cur-po (point))
	indent-num flag po-beg po-match)
    (if (gams-judge-parenthesis-close)
	(setq indent-num (gams-calculate-indent-loop-end))
    ;; If the current point is out of loop environment, in is nil.
      (if (null in)
	  ;; Out of loop.  Go back to the loop type statement which matces );
	  ;; and copy the indent number there.
	  (save-excursion
	    (while (>= (point) beg)
	      (goto-char (gams-judge-loop-beg)))
	    (beginning-of-line)
	    (if (looking-at (concat "^\\([ \t]*\\)" gams-regexp-loop))
		(progn (goto-char (match-beginning 2))
		       (setq indent-num (current-column)))
	      ;; If ); does not match loop type statement.
	      (goto-char cur-po)
	      (setq indent-num (gams-calculate-indent-other))))
	;; Inside loop environment.
	(let* ((temp (gams-judge-line "loop"))
	       (line-r (car temp))
	       (line-e (car (cdr temp)))
	       (line-b (car (cdr (cdr temp)))))
	  (cond
	   ;; The first line after loop.
	   ((equal line-e 2)
	    ;; The second line after loop.
	    (save-excursion
	      (forward-line (* -1 (- line-r 1)))
	      (setq indent-num (+ gams-indent-number-loop
				  (progn (skip-chars-forward "[ \t]")
					 (current-column))))))
	   ;; Other line.
	   (t (setq indent-num (gams-calculate-indent-previous line-b)))))))
    indent-num))

;;;
(defun gams-judge-in-on-off-text ()
  "Judge whether the current line is in ontext-offtext pair.

Return t if in.  Otherwise nil.  Note that when you are in MPSGE block,
return nil."
  (let ((cur-po (point))
	flag-beg po-beg flag-end po-end flag)
    (save-excursion
      (when (re-search-backward "^$\\(on\\|off\\)text" nil t)
	(setq flag-beg (downcase (gams*buffer-substring (match-beginning 1)
							(match-end 1))))
	(setq po-beg (match-beginning 0))
	(when (equal flag-beg "on")
	  ;; If ontext found, search offtext.
	  (goto-char cur-po)
	  (when (re-search-forward "^$\\(on\\|off\\)text" nil t)
	    (setq flag-end (downcase (gams*buffer-substring (match-beginning 1)
							    (match-end 1))))
	    (setq po-end (match-end 0))
	    (when (equal flag-end "off")
	      ;; If offtext found, then check whether MPSGE block or not.
	      (if (progn (goto-char po-beg)
			 (re-search-forward "$model" po-end t))
		  ;; If model found.  The current line is in MPSGE block.
		  ;; Do return nil.
		  nil
		;; Not in MPSGE block.
		(setq flag t)))))))
    flag))

;;; Calculate the necessary indent line.
(defun gams-calculate-indent (&optional column)
  "Calculate necessary indent number and return it.

If any change is unnecessary for the current line, return nil.  When this
command is evoked by `gams-newline-and-indent', the column number COLUMN
is supplied.  Otherwise, COLUMN is nil."
  (let (indent-num)
    (save-excursion
      (if (gams-judge-in-on-off-text)
	  ;; If the current point is in an ontext-offtext pair, do
	  ;; nothing.
	  nil
	;; Not in ontext-offtext pair.
	(let* ((cur-po (save-excursion (beginning-of-line) (point)))
	       ;; Check the current line starts with a dollar control.
	       (dol (gams-check-dollar-line t))
	       ;; Check the type of the current line.
	       (type (gams-check-line-type))
	       ;; Other local variables.
	       com times flag flag-loop flag-table temp-match po-match)
	  ;; Judge 
	  (cond
	   ;; Judge whether the current line is Not commented line.
	   ((not (equal "c" type)))
	   ;; The line starts with * but it is multiplication symbol if
	   ;; COLUMN is non-nil.
	   ((and (equal "c" type) (or (equal column nil)
				      (equal column 0)))
	    (setq com t))
	   ;; 
	   (t (setq times t)))
	  ;; Judge whether the current line is a commented line or dollar
	  ;; line.o
	  (if (or com dol)
	      ;; If commented-line or dollar control line, indent is zero.
	      (setq indent-num 0)
	    ;; If neither commented line nor dollar control line
	    (if times
		;; If the current line starts with * and this commented is
		;; evoked by `gams-newline-and-indent', insert a space
		;; temporarily.
		(insert " "))
	    ;; Examine the current line type.
	    (if (re-search-backward
		 (concat gams-regexp-equation
			 "\\|^[ \t]*\\("
			 gams-regexp-declaration
			 "\\|"
			 gams-regexp-loop
			 "\\|"
			 gams-regexp-other
			 "\\|"
			 gams-regexp-mpsge
			 "\\|$offtext\\|$ontext\\)") nil t)
		;; If the regexp is matched.
		(progn
		  ;; Save the matched string and points.
		  (setq temp-match (gams*buffer-substring
				    (setq po-match-beg (match-beginning 0))
				    (setq po-match (match-end 0))))
		  ;; If the matched end point is larger than the cur-po,
		  ;; set the cur-po to matched point.
		  (when (>= po-match cur-po) (setq cur-po po-match))
		  ;; Go to the current point (cur-po).
		  (goto-char cur-po)
		  ;; Various cases:
		  (cond
		   ;; Declaration type (parameter, set, variables etc.)
		   ((string-match gams-regexp-declaration temp-match)
		    ;; If the matched is table type, set flag-table to t.
		    (when (string-match "table" temp-match)
		      (setq flag-table t))
		    ;; Cases: If there are some statements and ; before
		    ;; cur-po, the declaration already ends.
		    (goto-char po-match)
		    (if (and (setq flag (re-search-forward "[^ \t\n]" cur-po t))
			     (re-search-forward ";" cur-po t))
			;; If declaration ends.
			(progn (goto-char cur-po)
			       (setq indent-num (gams-calculate-indent-other column)))
		      ;; Otherwise, we cannot judge whether the declaration
		      ;; ends or not.
		      
		      ;; If this command is evoked by `newline-indent',
		      ;; then always indented.
		      
		      ;; If the next line starts with a reserved word,
		      ;; then the declaration already ends.
		      (goto-char cur-po)
		      ;; Forward line until a non-empty line is found.
		      (while (and (null (eobp)) (gams-check-line-type))
			(forward-line 1))
		      (skip-chars-forward "[ \t\n]")
		      (if (and (null column) ; no indent.
			       flag	; there are some statements before
					; the current point.
			       (looking-at gams-statement-regexp-base-2))
			  ;; If the next line starts with a reserved word,
			  ;; no indent is necessary.
			  (setq indent-num 0)
			;; newline-indent or in declaration.  Indent.
			(goto-char cur-po)
			(setq indent-num (gams-calculate-indent-decl po-match flag-table)))))
		   
		   ;; Loop type environment.
		   ((string-match gams-regexp-loop temp-match)
		    ;;
		    (setq flag-loop (gams-judge-loop-end po-match cur-po))
		    (if (null flag-loop)
			;; loop does not end.
			(setq indent-num (gams-calculate-indent-loop po-match t t))
		      ;; loop end.
		      (setq indent-num (gams-calculate-indent-loop po-match))))
		   
		   ;; Others.
		   ((string-match gams-regexp-other temp-match)
		    ;; Calculate indent of the matched.
		    (goto-char po-match)
		    (forward-word -1)
		    (if (= (current-column) 0)
			;; If column number is 0, not in loop block.
			(progn (goto-char cur-po)
			       (setq indent-num (gams-calculate-indent-other column)))
		      ;; In loop.
		      (re-search-backward gams-regexp-loop nil t)
		      (setq temp-match (gams*buffer-substring (match-beginning 1)
							      (match-end 1)))
		      (setq flag-loop (gams-judge-loop-end po-match cur-po))
		      (goto-char cur-po)
		      (if (null flag-loop)
			  ;; loop does not end
			  (setq indent-num (gams-calculate-indent-loop po-match t t))
			;; loop ends.
			(setq indent-num (gams-calculate-indent-loop po-match)))))
		   
		   ;; MPSGE block.
		   ((string-match gams-regexp-mpsge temp-match)
		    (setq indent-num (gams-calculate-indent-mpsge)))
		   
		   ;; Equation definition.
		   ((string-match "[.][.]" temp-match)
		    (goto-char po-match)
		    ;; Cases: If there is ; before cur-po, the equation
		    ;; definition already ends.
		    (if (re-search-forward ";" cur-po t)
			;; ends.
			(setq indent-num 0)
		      ;; does not end.
		      (goto-char cur-po)
		      (setq indent-num (gams-calculate-indent-equation column))))
		   
		   ;; ontext or offtext.
		   ((string-match "^[$]\\(ontext\\|offtext\\)" temp-match)
		    (setq indent-num (gams-calculate-indent-other column)))
		   
		   ;; All others.
		   (t (setq indent-num (gams-calculate-indent-other column))))
		  ))))))
    indent-num))

;;; Functions for indentation.  From indent.el

(defun gams-newline-and-indent ()
  "Insert a newline, then indent.
Indentation is done using `gams-indent-line'."
  (interactive "*")
  (let ((column (current-column)))
    (delete-horizontal-space)
    (newline)
    (funcall 'gams-indent-line column)))

(defun gams-remove-indent (beg end)
  "Remove all the indents in a specified region.
The indent in a line that starts with * is not removed."
  (interactive "r")
  (let (po-a)
    (save-excursion
      (goto-char beg)
      (while (null (eobp))
	(save-excursion (end-of-line)
			(setq po-a (point)))
	(if (re-search-forward "^[ \t]+\\([*]?\\)" po-a t)
	    (if (null (equal "*" (gams*buffer-substring (match-beginning 1)
							(match-end 1))))
		(delete-region (match-beginning 0)
			       (match-end 0)))
	  (forward-line 1))))))

(defun gams-indent-line (&optional column)
  "Indent a line.

If this command is evoked by `gams-newline-and-indent', the column number
is provided by COLUMN."
  (interactive)
  (if column (gams-indent-function column)
    (gams-indent-function)))

(defun gams-indent-function (&optional column unindented-ok)
  "Indentation function in GAMS mode."
  (if (and abbrev-mode
	   (eq (char-syntax (preceding-char)) ?w))
      (expand-abbrev))
  (let* ((cur-column (current-column))
	 (indent-num (gams-calculate-indent column))
	 (cur-indent
	  (save-excursion
	    (beginning-of-line)
	    (skip-chars-forward "[ \t]")
	    (current-column))))
    (beginning-of-line)
    (cond
     ((null indent-num)
      (move-to-column cur-column))
     ((and (equal cur-indent indent-num)
	   (equal indent-num 0))
      (move-to-column cur-column))
     ((equal cur-indent indent-num)
      (move-to-column indent-num))
     (t
      (re-search-forward "^[ \t]*" nil t)
      (delete-region (match-beginning 0)
		     (match-end 0))
      (indent-to indent-num)))))

;;; Functions for eol and inline comment.

(defun gams-search-dollar-comment ()
  "Search comment dollar control option.
If it is found, return the matched content."
  (let (match)
    (save-excursion
      (goto-char (point-min))
      (when (re-search-forward "^\\([$]\\)comment[ \t]+\\([^ \t\n]+\\)" nil t)
	(setq match (gams*buffer-substring (match-beginning 2)
					   (match-end 2)))))
    match))

(defun gams-search-dollar-com (&optional eol)
  "Search inline or eolcom dollar control option.  If it is found, return the
  matched content.  If EOL is non-nil, search eol dollar control option."
  (let ((regexp-1 (if eol "eolcom" "inlinecom"))
	(regexp-2 (if eol "\\([^ \t\n]+\\)[ \t\n]?"
		    "\\([^ \t\n]+\\)[ \t]\\([^ \t\n]+\\)"))
	match po-beg cont)
    (save-excursion
      (goto-char (point-min))
      (catch 'found
	(while t
	  (if (re-search-forward regexp-1 nil t)
	      (progn (setq po-beg (match-end 0))
		     (beginning-of-line)
		     (if (looking-at "^[$]")
			 (progn (goto-char po-beg)
				(skip-chars-forward "[ \t]")
				(looking-at regexp-2)
				(setq cont
				      (if eol (gams*buffer-substring (match-beginning 1)
								     (match-end 1))
					(cons
					 (gams*buffer-substring (match-beginning 1)
								(match-end 1))
					 (gams*buffer-substring (match-beginning 2)
								(match-end 2)))))
				(throw 'found t))
		       (goto-char po-beg)))
	    (throw 'found t)))))
    cont))

;;; from newcomment.el

(defvar gams-comment-use-syntax 'undecided)
(defvar gams-comment-add 0)
(defun gams-comment-search-forward (limit &optional noerror)
  "Find a comment start between point and LIMIT.
Moves point to inside the comment and returns the position of the
comment-starter.  If no comment is found, moves point to LIMIT
and raises an error or returns nil of NOERROR is non-nil."
  (if (not gams-comment-use-syntax)
      (if (re-search-forward comment-start-skip limit noerror)
	  (or (match-end 1) (match-beginning 0))
	(goto-char limit)
	(unless noerror (error "No comment")))
    (let* ((pt (point))
	   ;; Assume (at first) that pt is outside of any string.
	   (s (parse-partial-sexp pt (or limit (point-max)) nil nil nil t)))
      (when (and (nth 8 s) (nth 3 s))
	  ;; The search ended inside a string.  Try to see if it
	  ;; works better when we assume that pt is inside a string.
	  (setq s (parse-partial-sexp
		   pt (or limit (point-max)) nil nil
		   (list nil nil nil (nth 3 s) nil nil nil nil)
		   t)))
      (if (not (and (nth 8 s) (not (nth 3 s))))
	  (unless noerror (error "No comment"))
	;; We found the comment.
	(let ((pos (point))
	      (start (nth 8 s))
	      (bol (line-beginning-position))
	      (end nil))
	  (while (and (null end) (>= (point) bol))
	    (if (looking-at comment-start-skip)
		(setq end (min (or limit (point-max)) (match-end 0)))
	      (backward-char)))
	  (goto-char (or end pos))
	  start)))))


;;; From newcomment.el.
(defun gams-comment-kill (arg)
  "Kill the comment on this line, if any.
With prefix ARG, kill comments on that many lines starting with this one."
  (interactive "P")
  (dotimes (_ (prefix-numeric-value arg))
    (save-excursion
      (beginning-of-line)
      (let ((cs (gams-comment-search-forward (line-end-position) t)))
	(when cs
	  (goto-char cs)
	  (skip-syntax-backward " ")
	  (setq cs (point))
	  (comment-forward)
	  (kill-region cs (if (bolp) (1- (point)) (point)))
	  (indent-according-to-mode))))
    (if arg (forward-line 1))))
	      
;;;;; Code for comment indent.

;;;; Comment indent
(substitute-all-key-definition
 'comment-dwim 'gams-comment-dwim gams-mode-map)

(defun gams-comment-dwim (arg)
  "Insert end-of-line comment."
  (interactive "*P")
  (gams-comment-dwim-internal arg))

(defun gams-comment-dwim-inline (arg)
  "Insert inline comment."
  (interactive "*P")
  (gams-comment-dwim-internal arg t))

(defun gams-comment-dwim-internal (arg &optional inline)
  "Insert end-of-line or inline comment.
If INLINE is non-nil, inline comment."
  (let ((flag (if inline nil t))
	pref type temp)
    (if flag
	;; MPSGE or eol.
	(progn (setq type nil)
	       (let ((mpsge (if (gams-judge-in-mpsge) t nil)))
		 (if mpsge
		     (setq pref "!")
		   (progn
		     (if gams-eolcom-symbol
			 (setq pref gams-eolcom-symbol)
		       ;; 
		       (message (concat "The end-of-line column symbol is not defined!"
					"  Do you want to define it?  Type y if yes."))
		       (if (equal (read-char) ?y)
			   (progn
			     (setq pref
				   (read-string "Insert end-of-line comment symbol: "
						gams-eolcom-symbol-default))
			     (setq gams-eolcom-symbol pref)
			     (gams-insert-comment-symbol-def pref))
			 ;; do nothing.
			 nil))))))
      ;; inline.
      (if gams-inlinecom-symbol-start
	  (progn (setq pref (concat gams-inlinecom-symbol-start
				    " "
				    gams-inlinecom-symbol-end))
		 (setq type (string-width gams-inlinecom-symbol-end)))

	(message (format (concat "The inline column symbol is not defined!" "  Do you want to define it?  Type y if yes.")))
	(if (equal (read-char) ?y)
	    ;;
	    (let (pref1 pref2)
	      (setq pref1
		    (read-string "Insert inline comment start symbol: "
				 gams-inlinecom-symbol-start-default))
	      (setq pref2
		    (read-string "Insert inline comment end symbol: "
				 gams-inlinecom-symbol-end-default))
	      (setq pref (concat pref1 " " pref2))
	      (setq gams-inlinecom-symbol-start pref1)
	      (setq gams-inlinecom-symbol-end pref2)
	      (gams-insert-comment-symbol-def pref t)
	      (setq type (string-width pref2))))))
    (when pref
	(gams-comment-dwim-insert arg pref type))
    ))

(defun gams-insert-comment-symbol-def (symbol &optional inline)
  "Insert inlinecom or eolcom dollar control option at the fisrt line in
the file."
  (let ((dollar (if inline "$inlinecom" "$eolcom")))
    (save-excursion
      (goto-char (point-min))
      (insert (concat dollar " " symbol "\n"))
      (sit-for 1)
      (message (format
		(concat (if inline "$inlinecome" "$eolcom")
			" was inserted at the first line."))))))

;;; This command is almost the same as gams-judge-in-on-off-text.
(defun gams-judge-in-mpsge ()
  "Judge whether the current line is in MPSGE block.
Return t if in."
  (let ((cur-po (point))
	flag-beg po-beg flag-end po-end flag)
    (save-excursion
      ;;
      (when (re-search-backward "^$\\(on\\|off\\)text" nil t)
	(setq flag-beg (downcase (gams*buffer-substring (match-beginning 1)
							(match-end 1))))
	(setq po-beg (match-beginning 0))
	(when (equal flag-beg "on")
	  ;; If ontext found, search offtext.
	  (goto-char cur-po)
	  (when (re-search-forward "^$\\(on\\|off\\)text" nil t)
	    (setq flag-end (downcase (gams*buffer-substring (match-beginning 1)
						       (match-end 1))))
	    (setq po-end (match-end 0))
	    (when (equal flag-end "off")
	      ;; If offtext found, then check whether MPSGE block or not.
	      (when (progn (goto-char po-beg)
			   (re-search-forward "$model" po-end t))
		  ;; If model found.  The current line is in MPSGE block.
		  ;; Do return nil.
		(setq flag t)))))))
    flag))

;;; From newcomment.el
(defun gams-comment-indent-function ()
  (if (looking-at "!")
      (current-column)
    (if (looking-at "!")
	(let ((tem (or (calculate-lisp-indent) (current-column))))
	  (if (listp tem) (car tem) tem))
      (skip-chars-backward " \t")
      (max (if (bolp) 0 (1+ (current-column)))
	   comment-column))))

(defun gams-comment-indent (pref &optional continue)
  "Indent this line's comment to comment column, or insert an empty comment.
If CONTINUE is non-nil, use the `comment-continue' markers if any."
  (interactive "*")
; (comment-normalize-vars)
  (let* ((comment-start pref)
	 (empty (save-excursion (beginning-of-line)
				(looking-at "[ \t]*$")))
	 (starter (or (and continue comment-continue)
		      (and empty block-comment-start) comment-start))
	 (ender (or (and continue comment-continue "")
		    (and empty block-comment-end) comment-end)))
    (unless starter (error "No comment syntax defined"))
    (beginning-of-line)
    (let* ((eolpos (line-end-position))
	   (begpos (gams-comment-search-forward eolpos t))
	   cpos indent)
      ;; An existing comment?
      (if begpos (setq cpos (point-marker))
	  ;; If none, insert one.
	  (save-excursion
	    ;; Some comment-indent-function insist on not moving comments that
	    ;; are in column 0, so we first go to the likely target column.
	    (indent-to comment-column)
	    (setq begpos (point))
	    (insert starter)
	    (setq cpos (point-marker))
	    (insert ender)))
      (goto-char begpos)
      ;; Compute desired indent.
      (setq indent (save-excursion (funcall comment-indent-function)))
      (if (not indent)
	  ;; comment-indent-function refuses delegates to indent.
	  (indent-according-to-mode)
	;; Avoid moving comments past the fill-column.
	(setq indent
	      (min indent
		   (+ (current-column)
		      (- fill-column
			 (save-excursion (end-of-line) (current-column))))))
	(if (= (current-column) indent)
	    (goto-char begpos)
	  ;; If that's different from current, change it.
	  (skip-chars-backward " \t")
	  (delete-region (point) begpos)
	  (indent-to (if (bolp) indent
		       (max indent (1+ (current-column)))))))
      (goto-char cpos)
      (set-marker cpos nil))))

(defun gams-comment-dwim-insert (arg pref type)
  (interactive "*P")
;  (comment-normalize-vars)
  (if (and mark-active transient-mark-mode)
      (let ((beg (min (point) (mark)))
	    (end (max (point) (mark))))
	(if (save-excursion ;; check for already commented region
	      (goto-char beg)
	      (comment-forward (point-max))
	      (<= end (point)))
	    (uncomment-region beg end arg)
	  (comment-region beg end arg)))
    (if (save-excursion (beginning-of-line) (not (looking-at "\\s-*$")))
	;; FIXME: If there's no comment to kill on this line and ARG is
	;; specified, calling comment-kill is not very clever.
	(if arg
	    (gams-comment-kill (and (integerp arg) arg))
	  (gams-comment-indent pref)
	  (if type
	      (backward-char (+ 1 type))
	    (insert " ")))
      (let ((add (if arg (prefix-numeric-value arg)
		   (if (= (length comment-start) 1) gams-comment-add 0))))
	;; Some modes insist on keeping column 0 comment in column 0
	;; so we need to move away from it before inserting the comment.
	(indent-according-to-mode)
	(insert (comment-padright comment-start add))
	(save-excursion
	  (unless (string= "" comment-end)
	    (insert (comment-padleft comment-end add)))
	  (indent-according-to-mode))))))

;;; Load hook.
(defvar gams-mode-load-hook nil
  "*List of functions to be called when gams.el is loaded.")
(run-hooks 'gams-mode-load-hook)

;;; provide.

(provide 'gams)

;; (load "./gams-new.el")

;;; GAMS.EL ends here
;Local variables:
;mode: emacs-lisp
;syntax: elisp
;End:
